<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
<xsl:stylesheet xmlns:xs="http://www.w3.org/2001/XMLSchema"
                xmlns:xsd="http://www.w3.org/2001/XMLSchema"
                xmlns:saxon="http://saxon.sf.net/"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:schold="http://www.ascc.net/xml/schematron"
                xmlns:iso="http://purl.oclc.org/dsdl/schematron"
                xmlns:xhtml="http://www.w3.org/1999/xhtml"
                xmlns:hl7="urn:hl7-org:v3"
                xmlns:cda="urn:hl7-org:v3"
                xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
                version="2.0"><!--Implementers: please note that overriding process-prolog or process-root is 
    the preferred method for meta-stylesheets to use where possible. -->
<xsl:param name="archiveDirParameter"/>
   <xsl:param name="archiveNameParameter"/>
   <xsl:param name="fileNameParameter"/>
   <xsl:param name="fileDirParameter"/>
   <xsl:variable name="document-uri">
      <xsl:value-of select="document-uri(/)"/>
   </xsl:variable>

   <!--PHASES-->


<!--PROLOG-->
<xsl:output method="text"/>

   <!--XSD TYPES FOR XSLT2-->


<!--KEYS AND FUNCTIONS-->


<!--DEFAULT RULES-->


<!--MODE: SCHEMATRON-SELECT-FULL-PATH-->
<!--This mode can be used to generate an ugly though full XPath for locators-->
<xsl:template match="*" mode="schematron-select-full-path">
      <xsl:apply-templates select="." mode="schematron-get-full-path"/>
   </xsl:template>

   <!--MODE: SCHEMATRON-FULL-PATH-->
<!--This mode can be used to generate an ugly though full XPath for locators-->
<xsl:template match="*" mode="schematron-get-full-path">
      <xsl:apply-templates select="parent::*" mode="schematron-get-full-path"/>
      <xsl:text>/</xsl:text>
      <xsl:choose>
         <xsl:when test="namespace-uri()=''">
            <xsl:value-of select="name()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>*:</xsl:text>
            <xsl:value-of select="local-name()"/>
            <xsl:text>[namespace-uri()='</xsl:text>
            <xsl:value-of select="namespace-uri()"/>
            <xsl:text>']</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="preceding"
                    select="count(preceding-sibling::*[local-name()=local-name(current())                                   and namespace-uri() = namespace-uri(current())])"/>
      <xsl:text>[</xsl:text>
      <xsl:value-of select="1+ $preceding"/>
      <xsl:text>]</xsl:text>
   </xsl:template>
   <xsl:template match="@*" mode="schematron-get-full-path">
      <xsl:apply-templates select="parent::*" mode="schematron-get-full-path"/>
      <xsl:text>/</xsl:text>
      <xsl:choose>
         <xsl:when test="namespace-uri()=''">@<xsl:value-of select="name()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>@*[local-name()='</xsl:text>
            <xsl:value-of select="local-name()"/>
            <xsl:text>' and namespace-uri()='</xsl:text>
            <xsl:value-of select="namespace-uri()"/>
            <xsl:text>']</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:template>

   <!--MODE: SCHEMATRON-FULL-PATH-2-->
<!--This mode can be used to generate prefixed XPath for humans-->
<xsl:template match="node() | @*" mode="schematron-get-full-path-2">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="name(.)"/>
         <xsl:if test="preceding-sibling::*[name(.)=name(current())]">
            <xsl:text>[</xsl:text>
            <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
            <xsl:text>]</xsl:text>
         </xsl:if>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>
   <!--MODE: SCHEMATRON-FULL-PATH-3-->
<!--This mode can be used to generate prefixed XPath for humans 
	(Top-level element has index)-->
<xsl:template match="node() | @*" mode="schematron-get-full-path-3">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="name(.)"/>
         <xsl:if test="parent::*">
            <xsl:text>[</xsl:text>
            <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
            <xsl:text>]</xsl:text>
         </xsl:if>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>

   <!--MODE: GENERATE-ID-FROM-PATH -->
<xsl:template match="/" mode="generate-id-from-path"/>
   <xsl:template match="text()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.text-', 1+count(preceding-sibling::text()), '-')"/>
   </xsl:template>
   <xsl:template match="comment()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.comment-', 1+count(preceding-sibling::comment()), '-')"/>
   </xsl:template>
   <xsl:template match="processing-instruction()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.processing-instruction-', 1+count(preceding-sibling::processing-instruction()), '-')"/>
   </xsl:template>
   <xsl:template match="@*" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.@', name())"/>
   </xsl:template>
   <xsl:template match="*" mode="generate-id-from-path" priority="-0.5">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:text>.</xsl:text>
      <xsl:value-of select="concat('.',name(),'-',1+count(preceding-sibling::*[name()=name(current())]),'-')"/>
   </xsl:template>

   <!--MODE: GENERATE-ID-2 -->
<xsl:template match="/" mode="generate-id-2">U</xsl:template>
   <xsl:template match="*" mode="generate-id-2" priority="2">
      <xsl:text>U</xsl:text>
      <xsl:number level="multiple" count="*"/>
   </xsl:template>
   <xsl:template match="node()" mode="generate-id-2">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>n</xsl:text>
      <xsl:number count="node()"/>
   </xsl:template>
   <xsl:template match="@*" mode="generate-id-2">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="string-length(local-name(.))"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="translate(name(),':','.')"/>
   </xsl:template>
   <!--Strip characters--><xsl:template match="text()" priority="-1"/>

   <!--SCHEMA SETUP-->
<xsl:template match="/">
      <xsl:apply-templates select="/" mode="M5"/>
      <xsl:apply-templates select="/" mode="M6"/>
   </xsl:template>

   <!--SCHEMATRON PATTERNS-->


<!--PATTERN -->
<xsl:template match="text()" priority="-1" mode="M5"/>
   <xsl:template match="@*|node()" priority="-2" mode="M5">
      <xsl:apply-templates select="*" mode="M5"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000Overdracht Acute Fase bericht-->


	<!--RULE tmp-r-680246-384746-371316-349306-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']"
                 priority="1447"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.90.63'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.90.63']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.90.63'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.90.63'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.90.63']/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.90.63'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.90.63'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.90.63'])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&gt;=1 and not(hl7:id/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:id is mandatory [min 1x]. (count(hl7:id)&gt;=1 and not(hl7:id/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:id komt te vaak voor [max 1x]. (count(hl7:id)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:statusCode)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:statusCode komt te vaak voor [max 1x]. (count(hl7:statusCode)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:subject)&gt;=1 and not(hl7:subject/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:subject is mandatory [min 1x]. (count(hl7:subject)&gt;=1 and not(hl7:subject/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:subject)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:subject komt te vaak voor [max 1x]. (count(hl7:subject)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:author)&gt;=1 and not(hl7:author/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:author is mandatory [min 1x]. (count(hl7:author)&gt;=1 and not(hl7:author/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:author)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:author komt te vaak voor [max 1x]. (count(hl7:author)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:reason[hl7:conditionEvent[hl7:code[(@code='38341003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='45757002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='44247006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='21522001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.63') or (@code='183695003' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI']]])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:reason[hl7:conditionEvent[hl7:code[(@code='38341003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='45757002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='44247006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='21522001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.63') or (@code='183695003' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI']]] is required [min 1x]. (count(hl7:reason[hl7:conditionEvent[hl7:code[(@code='38341003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='45757002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='44247006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='21522001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.63') or (@code='183695003' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI']]])&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation2[hl7:careProvisionEvent/hl7:pertinentInformation2/hl7:actList/hl7:code[@code='VERLIND']])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:pertinentInformation2[hl7:careProvisionEvent/hl7:pertinentInformation2/hl7:actList/hl7:code[@code='VERLIND']] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation2[hl7:careProvisionEvent/hl7:pertinentInformation2/hl7:actList/hl7:code[@code='VERLIND']])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation2[hl7:careProvisionEvent/hl7:pertinentInformation2/hl7:actList/hl7:code[@code='OBSTANAM']])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:pertinentInformation2[hl7:careProvisionEvent/hl7:pertinentInformation2/hl7:actList/hl7:code[@code='OBSTANAM']] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation2[hl7:careProvisionEvent/hl7:pertinentInformation2/hl7:actList/hl7:code[@code='OBSTANAM']])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='364332008' and @codeSystem='2.16.840.1.113883.6.96')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='364332008' and @codeSystem='2.16.840.1.113883.6.96')]]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='364332008' and @codeSystem='2.16.840.1.113883.6.96')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='59291004' and @codeSystem='2.16.840.1.113883.6.96')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='59291004' and @codeSystem='2.16.840.1.113883.6.96')]]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='59291004' and @codeSystem='2.16.840.1.113883.6.96')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='129019007' and @codeSystem='2.16.840.1.113883.6.96')]]])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='129019007' and @codeSystem='2.16.840.1.113883.6.96')]]] is required [min 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='129019007' and @codeSystem='2.16.840.1.113883.6.96')]]])&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='129019007' and @codeSystem='2.16.840.1.113883.6.96')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='129019007' and @codeSystem='2.16.840.1.113883.6.96')]]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='129019007' and @codeSystem='2.16.840.1.113883.6.96')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='NEGSE' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='NEGSE' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='NEGSE' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='266096002' and @codeSystem='2.16.840.1.113883.6.96')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='266096002' and @codeSystem='2.16.840.1.113883.6.96')]]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='266096002' and @codeSystem='2.16.840.1.113883.6.96')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='161664006' and @codeSystem='2.16.840.1.113883.6.96')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='161664006' and @codeSystem='2.16.840.1.113883.6.96')]]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='161664006' and @codeSystem='2.16.840.1.113883.6.96')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='39156-5' and @codeSystem='2.16.840.1.113883.6.1')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='39156-5' and @codeSystem='2.16.840.1.113883.6.1')]]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='39156-5' and @codeSystem='2.16.840.1.113883.6.1')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='75367002' and @codeSystem='2.16.840.1.113883.6.96')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='75367002' and @codeSystem='2.16.840.1.113883.6.96')]]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='75367002' and @codeSystem='2.16.840.1.113883.6.96')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='883-9' and @codeSystem='2.16.840.1.113883.6.1')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='883-9' and @codeSystem='2.16.840.1.113883.6.1')]]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='883-9' and @codeSystem='2.16.840.1.113883.6.1')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='978-7' and @codeSystem='2.16.840.1.113883.6.1')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='978-7' and @codeSystem='2.16.840.1.113883.6.1')]]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='978-7' and @codeSystem='2.16.840.1.113883.6.1')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='312457003' and @codeSystem='2.16.840.1.113883.6.96')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='312457003' and @codeSystem='2.16.840.1.113883.6.96')]]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='312457003' and @codeSystem='2.16.840.1.113883.6.96')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='948-0' and @codeSystem='2.16.840.1.113883.6.1')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='948-0' and @codeSystem='2.16.840.1.113883.6.1')]]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='948-0' and @codeSystem='2.16.840.1.113883.6.1')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='165806002' and @codeSystem='2.16.840.1.113883.6.96')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='165806002' and @codeSystem='2.16.840.1.113883.6.96')]]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='165806002' and @codeSystem='2.16.840.1.113883.6.96')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='364320009'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='364320009'] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='364320009'])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='236973005'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='236973005'] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='236973005'])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:organizer[hl7:code/@code='12131-9']])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:pertinentInformation3[hl7:organizer[hl7:code/@code='12131-9']] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:organizer[hl7:code/@code='12131-9']])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-390660-158318-888304-667145-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.90.63']"
                 priority="1446"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@root)='2.16.840.1.113883.2.4.6.10.90.63'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.90.63' hebben. (string(@root)='2.16.840.1.113883.2.4.6.10.90.63' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-284120-382280-882595-742671-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:id"
                 priority="1445"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-156947-189070-397730-314580-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:statusCode"
                 priority="1444"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='active')"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de elementwaarde MOET zijn code 'active'. (@nullFlavor or (@code='active') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-589675-671667-169667-374309-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:subject"
                 priority="1443"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='SBJ'"/>
         <xsl:otherwise>
            <xsl:message>(Vrouwacuut): de waarde van @typeCode MOET 'SBJ' zijn. (string(@typeCode)='SBJ' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900729-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:patient)&gt;=1 and not(hl7:patient/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Vrouwacuut): element hl7:patient is mandatory [min 1x]. (count(hl7:patient)&gt;=1 and not(hl7:patient/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900729-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:patient)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Vrouwacuut): element hl7:patient komt te vaak voor [max 1x]. (count(hl7:patient)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900729-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-476355-733676-474732-814368-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:subject/hl7:patient"
                 priority="1442"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='PAT'"/>
         <xsl:otherwise>
            <xsl:message>(Vrouwacuut): de waarde van @classCode MOET 'PAT' zijn. (string(@classCode)='PAT' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900729-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Vrouwacuut): element hl7:id komt te vaak voor [max 1x]. (count(hl7:id)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900729-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:statusCode[@code='active'])&gt;=1 and not(hl7:statusCode[@code='active']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Vrouwacuut): element hl7:statusCode[@code='active'] is mandatory [min 1x]. (count(hl7:statusCode[@code='active'])&gt;=1 and not(hl7:statusCode[@code='active']/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900729-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:statusCode[@code='active'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Vrouwacuut): element hl7:statusCode[@code='active'] komt te vaak voor [max 1x]. (count(hl7:statusCode[@code='active'])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900729-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:patientPerson)&gt;=1 and not(hl7:patientPerson/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Vrouwacuut): element hl7:patientPerson is mandatory [min 1x]. (count(hl7:patientPerson)&gt;=1 and not(hl7:patientPerson/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900729-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:patientPerson)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Vrouwacuut): element hl7:patientPerson komt te vaak voor [max 1x]. (count(hl7:patientPerson)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900729-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-376328-197414-936689-701457-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:subject/hl7:patient/hl7:id"
                 priority="1441"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@root)='2.16.840.1.113883.2.4.6.3' or not(@root)"/>
         <xsl:otherwise>
            <xsl:message>(Burgerservicenummer): @root MOET de waarde '2.16.840.1.113883.2.4.6.3' hebben. (string(@root)='2.16.840.1.113883.2.4.6.3' or not(@root) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900028-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-622931-918928-329711-887169-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:subject/hl7:patient/hl7:statusCode[@code='active']"
                 priority="1440"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='active')"/>
         <xsl:otherwise>
            <xsl:message>(Vrouwacuut): de elementwaarde MOET zijn code 'active'. (@nullFlavor or (@code='active') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900729-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-642108-599929-612279-166574-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:subject/hl7:patient/hl7:patientPerson"
                 priority="1439"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='PSN'"/>
         <xsl:otherwise>
            <xsl:message>(Vrouwacuut): de waarde van @classCode MOET 'PSN' zijn. (string(@classCode)='PSN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900729-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@determinerCode)='INSTANCE'"/>
         <xsl:otherwise>
            <xsl:message>(Vrouwacuut): de waarde van @determinerCode MOET 'INSTANCE' zijn. (string(@determinerCode)='INSTANCE' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900729-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:name)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(Vrouwacuut): element hl7:name is required [min 1x]. (count(hl7:name)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900729-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:name)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Vrouwacuut): element hl7:name komt te vaak voor [max 1x]. (count(hl7:name)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900729-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:birthTime)&gt;=1 and not(hl7:birthTime/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Vrouwacuut): element hl7:birthTime is mandatory [min 1x]. (count(hl7:birthTime)&gt;=1 and not(hl7:birthTime/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900729-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:birthTime)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Vrouwacuut): element hl7:birthTime komt te vaak voor [max 1x]. (count(hl7:birthTime)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900729-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:languageCommunication)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Vrouwacuut): element hl7:languageCommunication komt te vaak voor [max 1x]. (count(hl7:languageCommunication)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900729-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-420732-634798-169014-134484-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:subject/hl7:patient/hl7:patientPerson/hl7:name"
                 priority="1438"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@use)='L' or string(@use)='OR' or string(@use)='L OR' or string(@use)='OR L'"/>
         <xsl:otherwise>
            <xsl:message>(NaamORofL): de waarde van @use MOET één van de volgende codes bevatten: L', 'OR', 'L OR', 'OR L. (string(@use)='L' or string(@use)='OR' or string(@use)='L OR' or string(@use)='OR L' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900916-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount"
                    select="count(hl7:given|hl7:prefix|hl7:family|hl7:delimiter|hl7:suffix)"/>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-319873-880274-926239-956259-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:subject/hl7:patient/hl7:patientPerson/hl7:name/hl7:given"
                 priority="1437"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-587730-670859-757669-861601-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:subject/hl7:patient/hl7:patientPerson/hl7:name/hl7:prefix"
                 priority="1436"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT warning-->
<xsl:choose>
         <xsl:when test="@qualifier"/>
         <xsl:otherwise>
            <xsl:message>(NaamORofL): 
                            <xsl:text/>
               <xsl:value-of select="name(..)"/>
               <xsl:text/>/<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>/@qualifier ontbreekt. Deze prefix zal als titel worden geïnterpreteerd. (@qualifier / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900916-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-455595-779332-642693-695106-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:subject/hl7:patient/hl7:patientPerson/hl7:name/hl7:family"
                 priority="1435"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-355076-938189-860717-185168-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:subject/hl7:patient/hl7:patientPerson/hl7:name/hl7:delimiter"
                 priority="1434"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-819324-355069-438879-173722-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:subject/hl7:patient/hl7:patientPerson/hl7:name/hl7:suffix"
                 priority="1433"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-972970-394703-620289-713826-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:subject/hl7:patient/hl7:patientPerson/hl7:birthTime"
                 priority="1432"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-532110-210835-361714-117281-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:subject/hl7:patient/hl7:patientPerson/hl7:languageCommunication"
                 priority="1431"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:languageCode[(@code='nl-NL' and @codeSystem='2.16.840.1.113883.6.121')])&gt;=1 and not(hl7:languageCode[(@code='nl-NL' and @codeSystem='2.16.840.1.113883.6.121')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TaalvaardigheidNederlandsetaal): element hl7:languageCode[(@code='nl-NL' and @codeSystem='2.16.840.1.113883.6.121')] is mandatory [min 1x]. (count(hl7:languageCode[(@code='nl-NL' and @codeSystem='2.16.840.1.113883.6.121')])&gt;=1 and not(hl7:languageCode[(@code='nl-NL' and @codeSystem='2.16.840.1.113883.6.121')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900727-2012-05-03T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:languageCode[(@code='nl-NL' and @codeSystem='2.16.840.1.113883.6.121')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TaalvaardigheidNederlandsetaal): element hl7:languageCode[(@code='nl-NL' and @codeSystem='2.16.840.1.113883.6.121')] komt te vaak voor [max 1x]. (count(hl7:languageCode[(@code='nl-NL' and @codeSystem='2.16.840.1.113883.6.121')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900727-2012-05-03T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:proficiencyLevelCode[(@code='G' and @codeSystem='2.16.840.1.113883.5.61') or (@code='P' and @codeSystem='2.16.840.1.113883.5.61') or (@code='N' and @codeSystem='2.16.840.1.113883.5.61') or @nullFlavor='NI'])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(TaalvaardigheidNederlandsetaal): element hl7:proficiencyLevelCode[(@code='G' and @codeSystem='2.16.840.1.113883.5.61') or (@code='P' and @codeSystem='2.16.840.1.113883.5.61') or (@code='N' and @codeSystem='2.16.840.1.113883.5.61') or @nullFlavor='NI'] is required [min 1x]. (count(hl7:proficiencyLevelCode[(@code='G' and @codeSystem='2.16.840.1.113883.5.61') or (@code='P' and @codeSystem='2.16.840.1.113883.5.61') or (@code='N' and @codeSystem='2.16.840.1.113883.5.61') or @nullFlavor='NI'])&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900727-2012-05-03T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:proficiencyLevelCode[(@code='G' and @codeSystem='2.16.840.1.113883.5.61') or (@code='P' and @codeSystem='2.16.840.1.113883.5.61') or (@code='N' and @codeSystem='2.16.840.1.113883.5.61') or @nullFlavor='NI'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TaalvaardigheidNederlandsetaal): element hl7:proficiencyLevelCode[(@code='G' and @codeSystem='2.16.840.1.113883.5.61') or (@code='P' and @codeSystem='2.16.840.1.113883.5.61') or (@code='N' and @codeSystem='2.16.840.1.113883.5.61') or @nullFlavor='NI'] komt te vaak voor [max 1x]. (count(hl7:proficiencyLevelCode[(@code='G' and @codeSystem='2.16.840.1.113883.5.61') or (@code='P' and @codeSystem='2.16.840.1.113883.5.61') or (@code='N' and @codeSystem='2.16.840.1.113883.5.61') or @nullFlavor='NI'])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900727-2012-05-03T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-950202-113691-871373-147984-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:subject/hl7:patient/hl7:patientPerson/hl7:languageCommunication/hl7:languageCode[(@code='nl-NL' and @codeSystem='2.16.840.1.113883.6.121')]"
                 priority="1430"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='nl-NL' and @codeSystem='2.16.840.1.113883.6.121')"/>
         <xsl:otherwise>
            <xsl:message>(TaalvaardigheidNederlandsetaal): de elementwaarde MOET zijn code 'nl-NL' codeSystem '2.16.840.1.113883.6.121'. (@nullFlavor or (@code='nl-NL' and @codeSystem='2.16.840.1.113883.6.121') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900727-2012-05-03T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-486188-777658-790845-628400-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:subject/hl7:patient/hl7:patientPerson/hl7:languageCommunication/hl7:proficiencyLevelCode[(@code='G' and @codeSystem='2.16.840.1.113883.5.61') or (@code='P' and @codeSystem='2.16.840.1.113883.5.61') or (@code='N' and @codeSystem='2.16.840.1.113883.5.61') or @nullFlavor='NI']"
                 priority="1429"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="validCodeOrCodeSystemFound"
                    select="concat(exists(document('include/voc-2.16.840.1.113883.2.4.11.141-DYNAMIC.xml')/*/valueSet[conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-2.16.840.1.113883.2.4.11.141-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>
      <xsl:variable name="explicitExceptions" select="''"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or contains($validCodeOrCodeSystemFound,'true')"/>
         <xsl:otherwise>
            <xsl:message>(TaalvaardigheidNederlandsetaal): de waarde van @code MOET worden gekozen uit waardenlijst LanguageAbilityProficiency2 Language Ability Proficiency (DYNAMISCH). NB: codeSystemVersion MOET exact overeenkomen indien gespecificeerd in de waardenlijst. (@nullFlavor or contains($validCodeOrCodeSystemFound,'true') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900727-2012-05-03T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|'))"/>
         <xsl:otherwise>
            <xsl:message>(TaalvaardigheidNederlandsetaal): de nulwaarde voor @code MOET komen uit de set die is gedefinieerd voor dit attribuut of zijn gekoppeld aan waardenlijst LanguageAbilityProficiency2 Language Ability Proficiency (DYNAMISCH). (not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|')) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900727-2012-05-03T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-822153-204603-582818-736035-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:author"
                 priority="1428"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='AUT'"/>
         <xsl:otherwise>
            <xsl:message>(Zorgverlenereninstellingkort): de waarde van @typeCode MOET 'AUT' zijn. (string(@typeCode)='AUT' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900668-2012-03-17T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:time)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(Zorgverlenereninstellingkort): element hl7:time is required [min 1x]. (count(hl7:time)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900668-2012-03-17T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:time)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Zorgverlenereninstellingkort): element hl7:time komt te vaak voor [max 1x]. (count(hl7:time)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900668-2012-03-17T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:modeCode)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(Zorgverlenereninstellingkort): element hl7:modeCode is required [min 1x]. (count(hl7:modeCode)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900668-2012-03-17T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:modeCode)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Zorgverlenereninstellingkort): element hl7:modeCode komt te vaak voor [max 1x]. (count(hl7:modeCode)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900668-2012-03-17T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:signatureCode)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(Zorgverlenereninstellingkort): element hl7:signatureCode is required [min 1x]. (count(hl7:signatureCode)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900668-2012-03-17T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:signatureCode)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Zorgverlenereninstellingkort): element hl7:signatureCode komt te vaak voor [max 1x]. (count(hl7:signatureCode)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900668-2012-03-17T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:responsibleParty)&gt;=1 and not(hl7:responsibleParty/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Zorgverlenereninstellingkort): element hl7:responsibleParty is mandatory [min 1x]. (count(hl7:responsibleParty)&gt;=1 and not(hl7:responsibleParty/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900668-2012-03-17T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:responsibleParty)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Zorgverlenereninstellingkort): element hl7:responsibleParty komt te vaak voor [max 1x]. (count(hl7:responsibleParty)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900668-2012-03-17T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-543410-544239-140036-809050-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:author/hl7:time"
                 priority="1427"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-542409-467562-975455-396596-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:author/hl7:modeCode"
                 priority="1426"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@nullFlavor)='NA'"/>
         <xsl:otherwise>
            <xsl:message>(Zorgverlenereninstellingkort): de waarde van @nullFlavor MOET 'NA' zijn. (string(@nullFlavor)='NA' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900668-2012-03-17T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-704645-122096-497389-919988-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:author/hl7:signatureCode"
                 priority="1425"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@nullFlavor)='NA'"/>
         <xsl:otherwise>
            <xsl:message>(Zorgverlenereninstellingkort): de waarde van @nullFlavor MOET 'NA' zijn. (string(@nullFlavor)='NA' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900668-2012-03-17T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-654732-226306-138888-685099-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:author/hl7:responsibleParty"
                 priority="1424"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='ASSIGNED'"/>
         <xsl:otherwise>
            <xsl:message>(Zorgverlenereninstellingkort): de waarde van @classCode MOET 'ASSIGNED' zijn. (string(@classCode)='ASSIGNED' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900668-2012-03-17T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:telecom)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(Zorgverlenereninstellingkort): element hl7:telecom is required [min 1x]. (count(hl7:telecom)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900668-2012-03-17T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:telecom)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Zorgverlenereninstellingkort): element hl7:telecom komt te vaak voor [max 1x]. (count(hl7:telecom)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900668-2012-03-17T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:agentPerson)&gt;=1 and not(hl7:agentPerson/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Zorgverlenereninstellingkort): element hl7:agentPerson is mandatory [min 1x]. (count(hl7:agentPerson)&gt;=1 and not(hl7:agentPerson/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900668-2012-03-17T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:agentPerson)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Zorgverlenereninstellingkort): element hl7:agentPerson komt te vaak voor [max 1x]. (count(hl7:agentPerson)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900668-2012-03-17T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:representedOrganization)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(Zorgverlenereninstellingkort): element hl7:representedOrganization is required [min 1x]. (count(hl7:representedOrganization)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900668-2012-03-17T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:representedOrganization)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Zorgverlenereninstellingkort): element hl7:representedOrganization komt te vaak voor [max 1x]. (count(hl7:representedOrganization)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900668-2012-03-17T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-139492-388570-488779-594233-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:author/hl7:responsibleParty/hl7:telecom"
                 priority="1423"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@value,'^tel:(\+?([\d()./-]|(%[a-f\d]{2}))+)*(;(phone-context=((\+?([\d()./-]|(%[a-f\d]{2}))+)|(([a-z\d-]|(%[a-f\d]{2}))+(\.([a-z\d-]|(%[a-f\d]{2}))+)*))|(ext=[\d./-]+)|(isub=(([a-z\d();/?:@&amp;=+$,_.!~*''-])|(%[a-f\d]{2}))+)|([a-z\d-]+=([a-z\d\[\]/:&amp;+$_.!~*()-]|(%[a-f\d]{2}))+)))*$')"/>
         <xsl:otherwise>
            <xsl:message>(Zorgverlenereninstellingkort): De waarde van dit telecom element('<xsl:text/>
               <xsl:value-of select="@value"/>
               <xsl:text/>') moet een telefoonnummer bevatten, starten met 'tel:' en vervolgens een valide telefoon uri hebben conform RFC3966. (matches(@value,'^tel:(\+?([\d()./-]|(%[a-f\d]{2}))+)*(;(phone-context=((\+?([\d()./-]|(%[a-f\d]{2}))+)|(([a-z\d-]|(%[a-f\d]{2}))+(\.([a-z\d-]|(%[a-f\d]{2}))+)*))|(ext=[\d./-]+)|(isub=(([a-z\d();/?:@&amp;=+$,_.!~*''-])|(%[a-f\d]{2}))+)|([a-z\d-]+=([a-z\d\[\]/:&amp;+$_.!~*()-]|(%[a-f\d]{2}))+)))*$') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://tools.ietf.org/html/rfc3966)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-241689-942705-725448-653848-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:author/hl7:responsibleParty/hl7:agentPerson"
                 priority="1422"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='PSN'"/>
         <xsl:otherwise>
            <xsl:message>(Zorgverlenereninstellingkort): de waarde van @classCode MOET 'PSN' zijn. (string(@classCode)='PSN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900668-2012-03-17T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@determinerCode)='INSTANCE'"/>
         <xsl:otherwise>
            <xsl:message>(Zorgverlenereninstellingkort): de waarde van @determinerCode MOET 'INSTANCE' zijn. (string(@determinerCode)='INSTANCE' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900668-2012-03-17T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:name)&gt;=1 and not(hl7:name/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Zorgverlenereninstellingkort): element hl7:name is mandatory [min 1x]. (count(hl7:name)&gt;=1 and not(hl7:name/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900668-2012-03-17T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:name)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Zorgverlenereninstellingkort): element hl7:name komt te vaak voor [max 1x]. (count(hl7:name)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900668-2012-03-17T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-730738-178551-594150-276329-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:author/hl7:responsibleParty/hl7:agentPerson/hl7:name"
                 priority="1421"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@use)='L' or string(@use)='OR' or string(@use)='L OR' or string(@use)='OR L'"/>
         <xsl:otherwise>
            <xsl:message>(NaamORofL): de waarde van @use MOET één van de volgende codes bevatten: L', 'OR', 'L OR', 'OR L. (string(@use)='L' or string(@use)='OR' or string(@use)='L OR' or string(@use)='OR L' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900916-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount"
                    select="count(hl7:given|hl7:prefix|hl7:family|hl7:delimiter|hl7:suffix)"/>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-258044-526111-355121-497032-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:author/hl7:responsibleParty/hl7:agentPerson/hl7:name/hl7:given"
                 priority="1420"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-849560-197913-142572-890683-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:author/hl7:responsibleParty/hl7:agentPerson/hl7:name/hl7:prefix"
                 priority="1419"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT warning-->
<xsl:choose>
         <xsl:when test="@qualifier"/>
         <xsl:otherwise>
            <xsl:message>(NaamORofL): 
                            <xsl:text/>
               <xsl:value-of select="name(..)"/>
               <xsl:text/>/<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>/@qualifier ontbreekt. Deze prefix zal als titel worden geïnterpreteerd. (@qualifier / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900916-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-361561-973722-427144-278599-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:author/hl7:responsibleParty/hl7:agentPerson/hl7:name/hl7:family"
                 priority="1418"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-868300-338040-748407-247968-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:author/hl7:responsibleParty/hl7:agentPerson/hl7:name/hl7:delimiter"
                 priority="1417"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-154776-265395-876624-826032-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:author/hl7:responsibleParty/hl7:agentPerson/hl7:name/hl7:suffix"
                 priority="1416"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-632958-285945-188258-689391-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:author/hl7:responsibleParty/hl7:representedOrganization"
                 priority="1415"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='ORG'"/>
         <xsl:otherwise>
            <xsl:message>(Zorgverlenereninstellingkort): de waarde van @classCode MOET 'ORG' zijn. (string(@classCode)='ORG' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900668-2012-03-17T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@determinerCode)='INSTANCE'"/>
         <xsl:otherwise>
            <xsl:message>(Zorgverlenereninstellingkort): de waarde van @determinerCode MOET 'INSTANCE' zijn. (string(@determinerCode)='INSTANCE' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900668-2012-03-17T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id[not(@root='2.16.840.1.113883.2.4.6.1' or @root='2.16.840.1.113883.2.4.3.22.98.1' or @root='2.16.528.1.1007.3.3')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Zorgverlenereninstellingkort): element hl7:id[not(@root='2.16.840.1.113883.2.4.6.1' or @root='2.16.840.1.113883.2.4.3.22.98.1' or @root='2.16.528.1.1007.3.3')] komt te vaak voor [max 1x]. (count(hl7:id[not(@root='2.16.840.1.113883.2.4.6.1' or @root='2.16.840.1.113883.2.4.3.22.98.1' or @root='2.16.528.1.1007.3.3')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900668-2012-03-17T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount"
                    select="count(hl7:id[@root='2.16.840.1.113883.2.4.6.1']|hl7:id[@root='2.16.840.1.113883.2.4.3.22.98.1']|hl7:id[@root='2.16.528.1.1007.3.3'])"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$elmcount&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Zorgverlenereninstellingkort): keuze (hl7:id[@root='2.16.840.1.113883.2.4.6.1'] of hl7:id[@root='2.16.840.1.113883.2.4.3.22.98.1'] of hl7:id[@root='2.16.528.1.1007.3.3']) bevat te weinig elementen [min 1x] ($elmcount&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900668-2012-03-17T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id[@root='2.16.840.1.113883.2.4.6.1'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Zorgverlenereninstellingkort): element hl7:id[@root='2.16.840.1.113883.2.4.6.1'] komt te vaak voor [max 1x]. (count(hl7:id[@root='2.16.840.1.113883.2.4.6.1'])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900668-2012-03-17T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id[@root='2.16.840.1.113883.2.4.3.22.98.1'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Zorgverlenereninstellingkort): element hl7:id[@root='2.16.840.1.113883.2.4.3.22.98.1'] komt te vaak voor [max 1x]. (count(hl7:id[@root='2.16.840.1.113883.2.4.3.22.98.1'])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900668-2012-03-17T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id[@root='2.16.528.1.1007.3.3'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Zorgverlenereninstellingkort): element hl7:id[@root='2.16.528.1.1007.3.3'] komt te vaak voor [max 1x]. (count(hl7:id[@root='2.16.528.1.1007.3.3'])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900668-2012-03-17T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:name)&gt;=1 and not(hl7:name/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Zorgverlenereninstellingkort): element hl7:name is mandatory [min 1x]. (count(hl7:name)&gt;=1 and not(hl7:name/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900668-2012-03-17T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:name)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Zorgverlenereninstellingkort): element hl7:name komt te vaak voor [max 1x]. (count(hl7:name)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900668-2012-03-17T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-856688-393688-606070-996095-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:author/hl7:responsibleParty/hl7:representedOrganization/hl7:id[not(@root='2.16.840.1.113883.2.4.6.1' or @root='2.16.840.1.113883.2.4.3.22.98.1' or @root='2.16.528.1.1007.3.3')]"
                 priority="1414"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-777774-501797-643317-630054-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:author/hl7:responsibleParty/hl7:representedOrganization/hl7:id[@root='2.16.840.1.113883.2.4.6.1']"
                 priority="1413"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@root)='2.16.840.1.113883.2.4.6.1'"/>
         <xsl:otherwise>
            <xsl:message>(ZorginstellingAGBID): @root MOET de waarde '2.16.840.1.113883.2.4.6.1' hebben. (string(@root)='2.16.840.1.113883.2.4.6.1' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900610-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-274861-787670-585936-475413-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:author/hl7:responsibleParty/hl7:representedOrganization/hl7:id[@root='2.16.840.1.113883.2.4.3.22.98.1']"
                 priority="1412"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@root)='2.16.840.1.113883.2.4.3.22.98.1'"/>
         <xsl:otherwise>
            <xsl:message>(ZorginstellingLVR1ID): @root MOET de waarde '2.16.840.1.113883.2.4.3.22.98.1' hebben. (string(@root)='2.16.840.1.113883.2.4.3.22.98.1' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900044-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-986833-155269-936841-941116-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:author/hl7:responsibleParty/hl7:representedOrganization/hl7:id[@root='2.16.528.1.1007.3.3']"
                 priority="1411"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@root)='2.16.528.1.1007.3.3'"/>
         <xsl:otherwise>
            <xsl:message>(ZorginstellingURA): @root MOET de waarde '2.16.528.1.1007.3.3' hebben. (string(@root)='2.16.528.1.1007.3.3' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900021-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-463048-996357-636486-952927-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:author/hl7:responsibleParty/hl7:representedOrganization/hl7:name"
                 priority="1410"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-983241-279552-570236-567926-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:reason[hl7:conditionEvent[hl7:code[(@code='38341003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='45757002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='44247006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='21522001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.63') or (@code='183695003' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI']]]"
                 priority="1409"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='RSON'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @typeCode MOET 'RSON' zijn. (string(@typeCode)='RSON' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:conditionEvent[hl7:code[(@code='38341003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='45757002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='44247006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='21522001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.63') or (@code='183695003' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI']])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:conditionEvent[hl7:code[(@code='38341003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='45757002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='44247006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='21522001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.63') or (@code='183695003' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI']] is required [min 1x]. (count(hl7:conditionEvent[hl7:code[(@code='38341003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='45757002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='44247006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='21522001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.63') or (@code='183695003' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI']])&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:conditionEvent[hl7:code[(@code='38341003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='45757002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='44247006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='21522001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.63') or (@code='183695003' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI']])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:conditionEvent[hl7:code[(@code='38341003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='45757002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='44247006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='21522001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.63') or (@code='183695003' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI']] komt te vaak voor [max 1x]. (count(hl7:conditionEvent[hl7:code[(@code='38341003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='45757002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='44247006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='21522001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.63') or (@code='183695003' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI']])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-558978-399936-363811-922327-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:reason[hl7:conditionEvent[hl7:code[(@code='38341003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='45757002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='44247006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='21522001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.63') or (@code='183695003' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI']]]/hl7:conditionEvent"
                 priority="1408"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='COND'"/>
         <xsl:otherwise>
            <xsl:message>(CategorieRedenAcuteOverdracht): de waarde van @classCode MOET 'COND' zijn. (string(@classCode)='COND' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900037-2012-03-15T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(CategorieRedenAcuteOverdracht): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900037-2012-03-15T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(CategorieRedenAcuteOverdracht): element hl7:id is required [min 1x]. (count(hl7:id)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900037-2012-03-15T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CategorieRedenAcuteOverdracht): element hl7:id komt te vaak voor [max 1x]. (count(hl7:id)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900037-2012-03-15T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='38341003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='45757002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='44247006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='21522001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.63') or (@code='183695003' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI'])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(CategorieRedenAcuteOverdracht): element hl7:code[(@code='38341003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='45757002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='44247006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='21522001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.63') or (@code='183695003' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI'] is required [min 1x]. (count(hl7:code[(@code='38341003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='45757002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='44247006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='21522001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.63') or (@code='183695003' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI'])&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900037-2012-03-15T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='38341003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='45757002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='44247006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='21522001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.63') or (@code='183695003' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CategorieRedenAcuteOverdracht): element hl7:code[(@code='38341003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='45757002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='44247006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='21522001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.63') or (@code='183695003' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI'] komt te vaak voor [max 1x]. (count(hl7:code[(@code='38341003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='45757002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='44247006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='21522001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.63') or (@code='183695003' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI'])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900037-2012-03-15T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:text)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CategorieRedenAcuteOverdracht): element hl7:text komt te vaak voor [max 1x]. (count(hl7:text)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900037-2012-03-15T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-995955-413217-475347-234297-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:reason[hl7:conditionEvent[hl7:code[(@code='38341003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='45757002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='44247006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='21522001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.63') or (@code='183695003' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI']]]/hl7:conditionEvent/hl7:id"
                 priority="1407"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@nullFlavor)='NI' or not(@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(CategorieRedenAcuteOverdracht): de waarde van @nullFlavor MOET 'NI' zijn. (string(@nullFlavor)='NI' or not(@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900037-2012-03-15T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-971302-161747-339136-598784-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:reason[hl7:conditionEvent[hl7:code[(@code='38341003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='45757002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='44247006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='21522001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.63') or (@code='183695003' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI']]]/hl7:conditionEvent/hl7:code[(@code='38341003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='45757002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='44247006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='21522001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.63') or (@code='183695003' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI']"
                 priority="1406"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="validCodeOrCodeSystemFound"
                    select="concat(exists(document('include/voc-2.16.840.1.113883.2.4.11.153-2012-08-29T000000.xml')/*/valueSet[conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-2.16.840.1.113883.2.4.11.153-2012-08-29T000000.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>
      <xsl:variable name="explicitExceptions" select="''"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or contains($validCodeOrCodeSystemFound,'true')"/>
         <xsl:otherwise>
            <xsl:message>(CategorieRedenAcuteOverdracht): de waarde van @code MOET worden gekozen uit waardenlijst RedenOverdrachtCategorie Categorie Reden overdracht (2012-08-29T00:00:00). NB: codeSystemVersion MOET exact overeenkomen indien gespecificeerd in de waardenlijst. (@nullFlavor or contains($validCodeOrCodeSystemFound,'true') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900037-2012-03-15T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|'))"/>
         <xsl:otherwise>
            <xsl:message>(CategorieRedenAcuteOverdracht): de nulwaarde voor @code MOET komen uit de set die is gedefinieerd voor dit attribuut of zijn gekoppeld aan waardenlijst RedenOverdrachtCategorie Categorie Reden overdracht (2012-08-29T00:00:00). (not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|')) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900037-2012-03-15T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-198613-804173-213578-401224-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:reason[hl7:conditionEvent[hl7:code[(@code='38341003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='45757002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='44247006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='21522001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.63') or (@code='183695003' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI']]]/hl7:conditionEvent/hl7:text"
                 priority="1405"
                 mode="M6">
      <xsl:variable name="theValue" select="text()"/>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-166056-676747-398370-638991-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation2[hl7:careProvisionEvent/hl7:pertinentInformation2/hl7:actList/hl7:code[@code='VERLIND']]"
                 priority="1404"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='PERT'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @typeCode MOET 'PERT' zijn. (string(@typeCode)='PERT' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@contextConductionInd)='true'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @contextConductionInd MOET 'true' zijn. (string(@contextConductionInd)='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:careProvisionEvent)&gt;=1 and not(hl7:careProvisionEvent/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:careProvisionEvent is mandatory [min 1x]. (count(hl7:careProvisionEvent)&gt;=1 and not(hl7:careProvisionEvent/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:careProvisionEvent)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:careProvisionEvent komt te vaak voor [max 1x]. (count(hl7:careProvisionEvent)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-135815-822546-217873-719384-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation2[hl7:careProvisionEvent/hl7:pertinentInformation2/hl7:actList/hl7:code[@code='VERLIND']]/hl7:careProvisionEvent"
                 priority="1403"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='PCPR'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @classCode MOET 'PCPR' zijn. (string(@classCode)='PCPR' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation2[hl7:actList[hl7:code[@code='VERLIND']]])&gt;=1 and not(hl7:pertinentInformation2[hl7:actList[hl7:code[@code='VERLIND']]]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:pertinentInformation2[hl7:actList[hl7:code[@code='VERLIND']]] is mandatory [min 1x]. (count(hl7:pertinentInformation2[hl7:actList[hl7:code[@code='VERLIND']]])&gt;=1 and not(hl7:pertinentInformation2[hl7:actList[hl7:code[@code='VERLIND']]]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation2[hl7:actList[hl7:code[@code='VERLIND']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:pertinentInformation2[hl7:actList[hl7:code[@code='VERLIND']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation2[hl7:actList[hl7:code[@code='VERLIND']]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-828029-613523-827331-351750-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation2[hl7:careProvisionEvent/hl7:pertinentInformation2/hl7:actList/hl7:code[@code='VERLIND']]/hl7:careProvisionEvent/hl7:pertinentInformation2[hl7:actList[hl7:code[@code='VERLIND']]]"
                 priority="1402"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='PERT'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @typeCode MOET 'PERT' zijn. (string(@typeCode)='PERT' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@contextConductionInd)='true'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @contextConductionInd MOET 'true' zijn. (string(@contextConductionInd)='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:actList[hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')]])&gt;=1 and not(hl7:actList[hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:actList[hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')]] is mandatory [min 1x]. (count(hl7:actList[hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')]])&gt;=1 and not(hl7:actList[hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:actList[hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:actList[hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')]] komt te vaak voor [max 1x]. (count(hl7:actList[hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-289661-617872-153395-421250-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation2[hl7:careProvisionEvent/hl7:pertinentInformation2/hl7:actList/hl7:code[@code='VERLIND']]/hl7:careProvisionEvent/hl7:pertinentInformation2[hl7:actList[hl7:code[@code='VERLIND']]]/hl7:actList[hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]"
                 priority="1401"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='LIST'"/>
         <xsl:otherwise>
            <xsl:message>(Ziektenenbijzonderhedenvrouwindealgemeneanamnese_5): de waarde van @classCode MOET 'LIST' zijn. (string(@classCode)='LIST' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900897-2013-01-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(Ziektenenbijzonderhedenvrouwindealgemeneanamnese_5): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900897-2013-01-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&gt;=1 and not(hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Ziektenenbijzonderhedenvrouwindealgemeneanamnese_5): element hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')] is mandatory [min 1x]. (count(hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&gt;=1 and not(hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900897-2013-01-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Ziektenenbijzonderhedenvrouwindealgemeneanamnese_5): element hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900897-2013-01-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:observation[hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Ziektenenbijzonderhedenvrouwindealgemeneanamnese_5): element hl7:component[hl7:observation[hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]] komt te vaak voor [max 1x]. (count(hl7:component[hl7:observation[hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900897-2013-01-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-528532-969317-584835-486003-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation2[hl7:careProvisionEvent/hl7:pertinentInformation2/hl7:actList/hl7:code[@code='VERLIND']]/hl7:careProvisionEvent/hl7:pertinentInformation2[hl7:actList[hl7:code[@code='VERLIND']]]/hl7:actList[hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]/hl7:code"
                 priority="1400"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>(Ziektenenbijzonderhedenvrouwindealgemeneanamnese_5): de elementwaarde MOET zijn code 'VERLIND' codeSystem '2.16.840.1.113883.2.4.4.13'. (@nullFlavor or (@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900897-2013-01-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-124910-143061-841500-690788-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation2[hl7:careProvisionEvent/hl7:pertinentInformation2/hl7:actList/hl7:code[@code='VERLIND']]/hl7:careProvisionEvent/hl7:pertinentInformation2[hl7:actList[hl7:code[@code='VERLIND']]]/hl7:actList[hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]/hl7:component[hl7:observation[hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]"
                 priority="1399"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(Ziektenenbijzonderhedenvrouwindealgemeneanamnese_5): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900897-2013-01-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:observation[hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')]])&gt;=1 and not(hl7:observation[hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Ziektenenbijzonderhedenvrouwindealgemeneanamnese_5): element hl7:observation[hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')]] is mandatory [min 1x]. (count(hl7:observation[hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')]])&gt;=1 and not(hl7:observation[hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900897-2013-01-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:observation[hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Ziektenenbijzonderhedenvrouwindealgemeneanamnese_5): element hl7:observation[hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')]] komt te vaak voor [max 1x]. (count(hl7:observation[hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900897-2013-01-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-680312-508561-427534-966585-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation2[hl7:careProvisionEvent/hl7:pertinentInformation2/hl7:actList/hl7:code[@code='VERLIND']]/hl7:careProvisionEvent/hl7:pertinentInformation2[hl7:actList[hl7:code[@code='VERLIND']]]/hl7:actList[hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]/hl7:component[hl7:observation[hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation"
                 priority="1398"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(Ziektenenbijzonderhedenvrouwindealgemeneanamnese_5): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900897-2013-01-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(Ziektenenbijzonderhedenvrouwindealgemeneanamnese_5): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900897-2013-01-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&gt;=1 and not(hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Ziektenenbijzonderhedenvrouwindealgemeneanamnese_5): element hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')] is mandatory [min 1x]. (count(hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&gt;=1 and not(hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900897-2013-01-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Ziektenenbijzonderhedenvrouwindealgemeneanamnese_5): element hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900897-2013-01-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(Ziektenenbijzonderhedenvrouwindealgemeneanamnese_5): element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900897-2013-01-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Ziektenenbijzonderhedenvrouwindealgemeneanamnese_5): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900897-2013-01-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-930994-855260-233075-584462-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation2[hl7:careProvisionEvent/hl7:pertinentInformation2/hl7:actList/hl7:code[@code='VERLIND']]/hl7:careProvisionEvent/hl7:pertinentInformation2[hl7:actList[hl7:code[@code='VERLIND']]]/hl7:actList[hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]/hl7:component[hl7:observation[hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')]"
                 priority="1397"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>(Ziektenenbijzonderhedenvrouwindealgemeneanamnese_5): de elementwaarde MOET zijn code 'VERLIND' codeSystem '2.16.840.1.113883.2.4.4.13'. (@nullFlavor or (@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900897-2013-01-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-511241-314807-868623-491749-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation2[hl7:careProvisionEvent/hl7:pertinentInformation2/hl7:actList/hl7:code[@code='VERLIND']]/hl7:careProvisionEvent/hl7:pertinentInformation2[hl7:actList[hl7:code[@code='VERLIND']]]/hl7:actList[hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]/hl7:component[hl7:observation[hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:value"
                 priority="1396"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @value='false' or count(../hl7:inboundRelationship)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>(Ziektenenbijzonderhedenvrouwindealgemeneanamnese_5):  Als er sprake van ziekten en bijzonderheden is dan moet een lijst soort ziekten als inboundRelationship component worden meegegeven (@nullFlavor or @value='false' or count(../hl7:inboundRelationship)&gt;0 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900897-2013-01-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@value='true' or count(../hl7:inboundRelationship)=0"/>
         <xsl:otherwise>
            <xsl:message>(Ziektenenbijzonderhedenvrouwindealgemeneanamnese_5):  Als er geen sprake van ziekten en bijzonderheden is dan mag er geen lijst soort ziekten als inboundRelationship component worden meegegeven (@value='true' or count(../hl7:inboundRelationship)=0 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900897-2013-01-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-669272-363582-876724-232886-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation2[hl7:careProvisionEvent/hl7:pertinentInformation2/hl7:actList/hl7:code[@code='VERLIND']]/hl7:careProvisionEvent/hl7:pertinentInformation2[hl7:actList[hl7:code[@code='VERLIND']]]/hl7:actList[hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]/hl7:component[hl7:observation[hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]"
                 priority="1395"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(Ziektenenbijzonderhedenvrouwindealgemeneanamnese_5): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900897-2013-01-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-944054-574732-425521-320372-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation2[hl7:careProvisionEvent/hl7:pertinentInformation2/hl7:actList/hl7:code[@code='VERLIND']]/hl7:careProvisionEvent/hl7:pertinentInformation2[hl7:actList[hl7:code[@code='VERLIND']]]/hl7:actList[hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]/hl7:component[hl7:observation[hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation"
                 priority="1394"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(Soortziektenenbijzonderhedenvrouwindealganamnese): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900152-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(Soortziektenenbijzonderhedenvrouwindealganamnese): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900152-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Soortziektenenbijzonderhedenvrouwindealganamnese): element hl7:id komt te vaak voor [max 1x]. (count(hl7:id)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900152-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&gt;=1 and not(hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Soortziektenenbijzonderhedenvrouwindealganamnese): element hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')] is mandatory [min 1x]. (count(hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&gt;=1 and not(hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900152-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Soortziektenenbijzonderhedenvrouwindealganamnese): element hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900152-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:uncertaintyCode)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Soortziektenenbijzonderhedenvrouwindealganamnese): element hl7:uncertaintyCode komt te vaak voor [max 1x]. (count(hl7:uncertaintyCode)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900152-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value[(@code='1000' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1010' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1020' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1030' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1040' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1050' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1060' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1070' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1080' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1081' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1082' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1090' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1100' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1110' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1120' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1130' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1140' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1150' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1160' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1170' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1171' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1172' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1180' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1181' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1182' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1183' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1184' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1185' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1186' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1190' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1200' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1210' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1220' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1230' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1240' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1250' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1260' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1270' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1280' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1999' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2000' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2010' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2020' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2021' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2022' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2023' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2030' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2040' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2050' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2060' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2061' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2062' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2070' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2080' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2090' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2999' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or @nullFlavor='NI'])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(Soortziektenenbijzonderhedenvrouwindealganamnese): element hl7:value[(@code='1000' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1010' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1020' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1030' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1040' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1050' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1060' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1070' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1080' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1081' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1082' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1090' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1100' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1110' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1120' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1130' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1140' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1150' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1160' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1170' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1171' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1172' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1180' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1181' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1182' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1183' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1184' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1185' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1186' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1190' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1200' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1210' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1220' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1230' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1240' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1250' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1260' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1270' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1280' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1999' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2000' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2010' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2020' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2021' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2022' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2023' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2030' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2040' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2050' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2060' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2061' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2062' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2070' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2080' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2090' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2999' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or @nullFlavor='NI'] is required [min 1x]. (count(hl7:value[(@code='1000' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1010' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1020' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1030' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1040' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1050' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1060' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1070' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1080' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1081' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1082' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1090' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1100' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1110' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1120' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1130' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1140' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1150' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1160' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1170' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1171' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1172' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1180' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1181' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1182' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1183' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1184' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1185' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1186' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1190' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1200' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1210' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1220' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1230' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1240' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1250' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1260' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1270' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1280' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1999' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2000' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2010' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2020' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2021' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2022' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2023' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2030' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2040' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2050' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2060' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2061' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2062' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2070' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2080' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2090' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2999' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or @nullFlavor='NI'])&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900152-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value[(@code='1000' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1010' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1020' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1030' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1040' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1050' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1060' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1070' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1080' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1081' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1082' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1090' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1100' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1110' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1120' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1130' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1140' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1150' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1160' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1170' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1171' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1172' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1180' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1181' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1182' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1183' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1184' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1185' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1186' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1190' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1200' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1210' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1220' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1230' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1240' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1250' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1260' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1270' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1280' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1999' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2000' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2010' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2020' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2021' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2022' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2023' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2030' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2040' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2050' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2060' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2061' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2062' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2070' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2080' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2090' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2999' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or @nullFlavor='NI'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Soortziektenenbijzonderhedenvrouwindealganamnese): element hl7:value[(@code='1000' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1010' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1020' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1030' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1040' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1050' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1060' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1070' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1080' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1081' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1082' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1090' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1100' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1110' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1120' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1130' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1140' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1150' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1160' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1170' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1171' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1172' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1180' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1181' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1182' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1183' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1184' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1185' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1186' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1190' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1200' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1210' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1220' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1230' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1240' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1250' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1260' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1270' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1280' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1999' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2000' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2010' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2020' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2021' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2022' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2023' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2030' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2040' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2050' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2060' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2061' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2062' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2070' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2080' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2090' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2999' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or @nullFlavor='NI'] komt te vaak voor [max 1x]. (count(hl7:value[(@code='1000' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1010' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1020' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1030' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1040' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1050' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1060' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1070' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1080' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1081' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1082' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1090' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1100' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1110' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1120' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1130' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1140' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1150' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1160' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1170' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1171' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1172' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1180' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1181' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1182' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1183' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1184' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1185' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1186' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1190' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1200' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1210' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1220' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1230' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1240' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1250' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1260' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1270' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1280' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1999' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2000' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2010' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2020' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2021' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2022' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2023' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2030' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2040' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2050' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2060' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2061' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2062' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2070' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2080' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2090' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2999' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or @nullFlavor='NI'])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900152-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-269480-664057-564053-452747-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation2[hl7:careProvisionEvent/hl7:pertinentInformation2/hl7:actList/hl7:code[@code='VERLIND']]/hl7:careProvisionEvent/hl7:pertinentInformation2[hl7:actList[hl7:code[@code='VERLIND']]]/hl7:actList[hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]/hl7:component[hl7:observation[hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:id"
                 priority="1393"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-720992-354777-952486-297012-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation2[hl7:careProvisionEvent/hl7:pertinentInformation2/hl7:actList/hl7:code[@code='VERLIND']]/hl7:careProvisionEvent/hl7:pertinentInformation2[hl7:actList[hl7:code[@code='VERLIND']]]/hl7:actList[hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]/hl7:component[hl7:observation[hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')]"
                 priority="1392"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>(Soortziektenenbijzonderhedenvrouwindealganamnese): de elementwaarde MOET zijn code 'VERLIND' codeSystem '2.16.840.1.113883.2.4.4.13'. (@nullFlavor or (@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900152-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-942216-917629-974831-159000-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation2[hl7:careProvisionEvent/hl7:pertinentInformation2/hl7:actList/hl7:code[@code='VERLIND']]/hl7:careProvisionEvent/hl7:pertinentInformation2[hl7:actList[hl7:code[@code='VERLIND']]]/hl7:actList[hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]/hl7:component[hl7:observation[hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:uncertaintyCode"
                 priority="1391"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-467147-114667-344425-860658-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation2[hl7:careProvisionEvent/hl7:pertinentInformation2/hl7:actList/hl7:code[@code='VERLIND']]/hl7:careProvisionEvent/hl7:pertinentInformation2[hl7:actList[hl7:code[@code='VERLIND']]]/hl7:actList[hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]/hl7:component[hl7:observation[hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:value[(@code='1000' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1010' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1020' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1030' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1040' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1050' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1060' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1070' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1080' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1081' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1082' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1090' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1100' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1110' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1120' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1130' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1140' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1150' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1160' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1170' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1171' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1172' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1180' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1181' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1182' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1183' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1184' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1185' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1186' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1190' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1200' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1210' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1220' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1230' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1240' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1250' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1260' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1270' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1280' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='1999' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2000' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2010' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2020' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2021' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2022' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2023' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2030' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2040' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2050' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2060' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2061' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2062' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2070' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2080' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2090' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='2999' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or @nullFlavor='NI']"
                 priority="1390"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="validCodeOrCodeSystemFound"
                    select="concat(exists(document('include/voc-2.16.840.1.113883.2.4.11.125-DYNAMIC.xml')/*/valueSet[conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-2.16.840.1.113883.2.4.11.125-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>
      <xsl:variable name="explicitExceptions" select="''"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or contains($validCodeOrCodeSystemFound,'true')"/>
         <xsl:otherwise>
            <xsl:message>(Soortziektenenbijzonderhedenvrouwindealganamnese): de waarde van @code MOET worden gekozen uit waardenlijst VILLijst10002000 (DYNAMISCH). NB: codeSystemVersion MOET exact overeenkomen indien gespecificeerd in de waardenlijst. (@nullFlavor or contains($validCodeOrCodeSystemFound,'true') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900152-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|'))"/>
         <xsl:otherwise>
            <xsl:message>(Soortziektenenbijzonderhedenvrouwindealganamnese): de nulwaarde voor @code MOET komen uit de set die is gedefinieerd voor dit attribuut of zijn gekoppeld aan waardenlijst VILLijst10002000 (DYNAMISCH). (not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|')) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900152-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-350891-138600-403932-887998-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation2[hl7:careProvisionEvent/hl7:pertinentInformation2/hl7:actList/hl7:code[@code='OBSTANAM']]"
                 priority="1389"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='PERT'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @typeCode MOET 'PERT' zijn. (string(@typeCode)='PERT' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@contextConductionInd)='true'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @contextConductionInd MOET 'true' zijn. (string(@contextConductionInd)='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:careProvisionEvent)&gt;=1 and not(hl7:careProvisionEvent/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:careProvisionEvent is mandatory [min 1x]. (count(hl7:careProvisionEvent)&gt;=1 and not(hl7:careProvisionEvent/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:careProvisionEvent)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:careProvisionEvent komt te vaak voor [max 1x]. (count(hl7:careProvisionEvent)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-981397-848403-278827-590812-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation2[hl7:careProvisionEvent/hl7:pertinentInformation2/hl7:actList/hl7:code[@code='OBSTANAM']]/hl7:careProvisionEvent"
                 priority="1388"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='PCPR'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @classCode MOET 'PCPR' zijn. (string(@classCode)='PCPR' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation2[hl7:actList/hl7:code[@code='OBSTANAM']])&gt;=1 and not(hl7:pertinentInformation2[hl7:actList/hl7:code[@code='OBSTANAM']]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:pertinentInformation2[hl7:actList/hl7:code[@code='OBSTANAM']] is mandatory [min 1x]. (count(hl7:pertinentInformation2[hl7:actList/hl7:code[@code='OBSTANAM']])&gt;=1 and not(hl7:pertinentInformation2[hl7:actList/hl7:code[@code='OBSTANAM']]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation2[hl7:actList/hl7:code[@code='OBSTANAM']])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:pertinentInformation2[hl7:actList/hl7:code[@code='OBSTANAM']] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation2[hl7:actList/hl7:code[@code='OBSTANAM']])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-718024-909449-408629-385682-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation2[hl7:careProvisionEvent/hl7:pertinentInformation2/hl7:actList/hl7:code[@code='OBSTANAM']]/hl7:careProvisionEvent/hl7:pertinentInformation2[hl7:actList/hl7:code[@code='OBSTANAM']]"
                 priority="1387"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='PERT'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @typeCode MOET 'PERT' zijn. (string(@typeCode)='PERT' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@contextConductionInd)='true'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @contextConductionInd MOET 'true' zijn. (string(@contextConductionInd)='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:actList[hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')]])&gt;=1 and not(hl7:actList[hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:actList[hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')]] is mandatory [min 1x]. (count(hl7:actList[hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')]])&gt;=1 and not(hl7:actList[hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:actList[hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:actList[hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')]] komt te vaak voor [max 1x]. (count(hl7:actList[hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-811683-786689-348811-376221-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation2[hl7:careProvisionEvent/hl7:pertinentInformation2/hl7:actList/hl7:code[@code='OBSTANAM']]/hl7:careProvisionEvent/hl7:pertinentInformation2[hl7:actList/hl7:code[@code='OBSTANAM']]/hl7:actList[hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]"
                 priority="1386"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='LIST'"/>
         <xsl:otherwise>
            <xsl:message>(Bijzonderhedenobstetrischeanamnese_3): de waarde van @classCode MOET 'LIST' zijn. (string(@classCode)='LIST' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900711-2012-05-03T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(Bijzonderhedenobstetrischeanamnese_3): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900711-2012-05-03T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&gt;=1 and not(hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Bijzonderhedenobstetrischeanamnese_3): element hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')] is mandatory [min 1x]. (count(hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&gt;=1 and not(hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900711-2012-05-03T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Bijzonderhedenobstetrischeanamnese_3): element hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900711-2012-05-03T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:observation[hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Bijzonderhedenobstetrischeanamnese_3): element hl7:component[hl7:observation[hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]] komt te vaak voor [max 1x]. (count(hl7:component[hl7:observation[hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900711-2012-05-03T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-904375-181362-434704-646105-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation2[hl7:careProvisionEvent/hl7:pertinentInformation2/hl7:actList/hl7:code[@code='OBSTANAM']]/hl7:careProvisionEvent/hl7:pertinentInformation2[hl7:actList/hl7:code[@code='OBSTANAM']]/hl7:actList[hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]/hl7:code"
                 priority="1385"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>(Bijzonderhedenobstetrischeanamnese_3): de elementwaarde MOET zijn code 'OBSTANAM' codeSystem '2.16.840.1.113883.2.4.4.13'. (@nullFlavor or (@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900711-2012-05-03T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-760425-255910-800377-347138-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation2[hl7:careProvisionEvent/hl7:pertinentInformation2/hl7:actList/hl7:code[@code='OBSTANAM']]/hl7:careProvisionEvent/hl7:pertinentInformation2[hl7:actList/hl7:code[@code='OBSTANAM']]/hl7:actList[hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]/hl7:component[hl7:observation[hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]"
                 priority="1384"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(Bijzonderhedenobstetrischeanamnese_3): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900711-2012-05-03T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:observation[hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')]])&gt;=1 and not(hl7:observation[hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Bijzonderhedenobstetrischeanamnese_3): element hl7:observation[hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')]] is mandatory [min 1x]. (count(hl7:observation[hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')]])&gt;=1 and not(hl7:observation[hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900711-2012-05-03T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:observation[hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Bijzonderhedenobstetrischeanamnese_3): element hl7:observation[hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')]] komt te vaak voor [max 1x]. (count(hl7:observation[hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900711-2012-05-03T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-109115-808921-977642-845608-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation2[hl7:careProvisionEvent/hl7:pertinentInformation2/hl7:actList/hl7:code[@code='OBSTANAM']]/hl7:careProvisionEvent/hl7:pertinentInformation2[hl7:actList/hl7:code[@code='OBSTANAM']]/hl7:actList[hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]/hl7:component[hl7:observation[hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation"
                 priority="1383"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(Bijzonderhedenobstetrischeanamnese_3): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900711-2012-05-03T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(Bijzonderhedenobstetrischeanamnese_3): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900711-2012-05-03T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&gt;=1 and not(hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Bijzonderhedenobstetrischeanamnese_3): element hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')] is mandatory [min 1x]. (count(hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&gt;=1 and not(hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900711-2012-05-03T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Bijzonderhedenobstetrischeanamnese_3): element hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900711-2012-05-03T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(Bijzonderhedenobstetrischeanamnese_3): element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900711-2012-05-03T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Bijzonderhedenobstetrischeanamnese_3): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900711-2012-05-03T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-847285-563907-188046-739538-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation2[hl7:careProvisionEvent/hl7:pertinentInformation2/hl7:actList/hl7:code[@code='OBSTANAM']]/hl7:careProvisionEvent/hl7:pertinentInformation2[hl7:actList/hl7:code[@code='OBSTANAM']]/hl7:actList[hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]/hl7:component[hl7:observation[hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')]"
                 priority="1382"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>(Bijzonderhedenobstetrischeanamnese_3): de elementwaarde MOET zijn code 'OBSTANAM' codeSystem '2.16.840.1.113883.2.4.4.13'. (@nullFlavor or (@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900711-2012-05-03T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-367498-799161-973090-935756-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation2[hl7:careProvisionEvent/hl7:pertinentInformation2/hl7:actList/hl7:code[@code='OBSTANAM']]/hl7:careProvisionEvent/hl7:pertinentInformation2[hl7:actList/hl7:code[@code='OBSTANAM']]/hl7:actList[hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]/hl7:component[hl7:observation[hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:value"
                 priority="1381"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @value='false' or count(../hl7:inboundRelationship)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>(Bijzonderhedenobstetrischeanamnese_3):  Als er sprake van ziekten en bijzonderheden is dan moet een lijst soort ziekten als inboundRelationship component worden meegegeven (@nullFlavor or @value='false' or count(../hl7:inboundRelationship)&gt;0 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900711-2012-05-03T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@value='true' or count(../hl7:inboundRelationship)=0"/>
         <xsl:otherwise>
            <xsl:message>(Bijzonderhedenobstetrischeanamnese_3):  Als er geen sprake van ziekten en bijzonderheden is dan mag er geen lijst soort ziekten als inboundRelationship component worden meegegeven (@value='true' or count(../hl7:inboundRelationship)=0 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900711-2012-05-03T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-543517-450290-676850-905533-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation2[hl7:careProvisionEvent/hl7:pertinentInformation2/hl7:actList/hl7:code[@code='OBSTANAM']]/hl7:careProvisionEvent/hl7:pertinentInformation2[hl7:actList/hl7:code[@code='OBSTANAM']]/hl7:actList[hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]/hl7:component[hl7:observation[hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]"
                 priority="1380"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(Bijzonderhedenobstetrischeanamnese_3): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900711-2012-05-03T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-546616-784359-270637-571224-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation2[hl7:careProvisionEvent/hl7:pertinentInformation2/hl7:actList/hl7:code[@code='OBSTANAM']]/hl7:careProvisionEvent/hl7:pertinentInformation2[hl7:actList/hl7:code[@code='OBSTANAM']]/hl7:actList[hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]/hl7:component[hl7:observation[hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation"
                 priority="1379"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(Soortbijzonderhedenobstetrischeanamnese): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900155-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(Soortbijzonderhedenobstetrischeanamnese): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900155-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Soortbijzonderhedenobstetrischeanamnese): element hl7:id komt te vaak voor [max 1x]. (count(hl7:id)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900155-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&gt;=1 and not(hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Soortbijzonderhedenobstetrischeanamnese): element hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')] is mandatory [min 1x]. (count(hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&gt;=1 and not(hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900155-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Soortbijzonderhedenobstetrischeanamnese): element hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900155-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:uncertaintyCode)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Soortbijzonderhedenobstetrischeanamnese): element hl7:uncertaintyCode komt te vaak voor [max 1x]. (count(hl7:uncertaintyCode)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900155-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value[(@code='3000' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3010' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3011' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3012' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3020' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3021' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3022' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3030' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3031' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3032' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3040' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3041' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3042' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3050' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3060' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3070' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3080' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3081' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3082' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3090' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3091' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3092' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3100' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3110' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3120' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3130' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3140' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3150' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3160' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3161' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3162' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3170' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3180' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3190' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3200' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3210' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3220' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3230' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3250' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3251' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3999' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or @nullFlavor='NI'])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(Soortbijzonderhedenobstetrischeanamnese): element hl7:value[(@code='3000' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3010' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3011' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3012' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3020' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3021' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3022' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3030' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3031' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3032' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3040' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3041' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3042' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3050' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3060' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3070' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3080' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3081' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3082' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3090' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3091' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3092' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3100' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3110' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3120' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3130' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3140' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3150' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3160' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3161' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3162' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3170' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3180' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3190' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3200' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3210' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3220' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3230' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3250' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3251' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3999' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or @nullFlavor='NI'] is required [min 1x]. (count(hl7:value[(@code='3000' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3010' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3011' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3012' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3020' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3021' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3022' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3030' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3031' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3032' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3040' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3041' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3042' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3050' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3060' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3070' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3080' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3081' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3082' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3090' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3091' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3092' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3100' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3110' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3120' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3130' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3140' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3150' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3160' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3161' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3162' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3170' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3180' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3190' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3200' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3210' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3220' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3230' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3250' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3251' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3999' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or @nullFlavor='NI'])&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900155-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value[(@code='3000' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3010' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3011' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3012' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3020' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3021' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3022' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3030' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3031' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3032' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3040' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3041' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3042' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3050' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3060' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3070' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3080' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3081' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3082' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3090' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3091' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3092' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3100' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3110' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3120' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3130' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3140' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3150' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3160' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3161' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3162' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3170' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3180' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3190' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3200' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3210' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3220' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3230' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3250' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3251' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3999' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or @nullFlavor='NI'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Soortbijzonderhedenobstetrischeanamnese): element hl7:value[(@code='3000' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3010' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3011' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3012' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3020' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3021' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3022' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3030' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3031' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3032' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3040' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3041' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3042' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3050' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3060' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3070' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3080' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3081' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3082' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3090' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3091' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3092' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3100' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3110' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3120' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3130' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3140' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3150' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3160' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3161' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3162' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3170' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3180' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3190' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3200' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3210' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3220' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3230' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3250' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3251' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3999' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or @nullFlavor='NI'] komt te vaak voor [max 1x]. (count(hl7:value[(@code='3000' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3010' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3011' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3012' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3020' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3021' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3022' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3030' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3031' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3032' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3040' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3041' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3042' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3050' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3060' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3070' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3080' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3081' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3082' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3090' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3091' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3092' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3100' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3110' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3120' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3130' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3140' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3150' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3160' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3161' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3162' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3170' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3180' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3190' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3200' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3210' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3220' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3230' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3250' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3251' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3999' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or @nullFlavor='NI'])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900155-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-339069-766466-903531-700707-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation2[hl7:careProvisionEvent/hl7:pertinentInformation2/hl7:actList/hl7:code[@code='OBSTANAM']]/hl7:careProvisionEvent/hl7:pertinentInformation2[hl7:actList/hl7:code[@code='OBSTANAM']]/hl7:actList[hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]/hl7:component[hl7:observation[hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:id"
                 priority="1378"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-837959-584488-482992-835046-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation2[hl7:careProvisionEvent/hl7:pertinentInformation2/hl7:actList/hl7:code[@code='OBSTANAM']]/hl7:careProvisionEvent/hl7:pertinentInformation2[hl7:actList/hl7:code[@code='OBSTANAM']]/hl7:actList[hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]/hl7:component[hl7:observation[hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')]"
                 priority="1377"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>(Soortbijzonderhedenobstetrischeanamnese): de elementwaarde MOET zijn code 'OBSTANAM' codeSystem '2.16.840.1.113883.2.4.4.13'. (@nullFlavor or (@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900155-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-214678-612906-699392-586024-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation2[hl7:careProvisionEvent/hl7:pertinentInformation2/hl7:actList/hl7:code[@code='OBSTANAM']]/hl7:careProvisionEvent/hl7:pertinentInformation2[hl7:actList/hl7:code[@code='OBSTANAM']]/hl7:actList[hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]/hl7:component[hl7:observation[hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:uncertaintyCode"
                 priority="1376"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-232142-633159-611613-354993-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation2[hl7:careProvisionEvent/hl7:pertinentInformation2/hl7:actList/hl7:code[@code='OBSTANAM']]/hl7:careProvisionEvent/hl7:pertinentInformation2[hl7:actList/hl7:code[@code='OBSTANAM']]/hl7:actList[hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]/hl7:component[hl7:observation[hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:value[(@code='3000' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3010' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3011' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3012' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3020' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3021' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3022' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3030' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3031' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3032' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3040' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3041' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3042' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3050' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3060' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3070' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3080' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3081' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3082' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3090' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3091' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3092' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3100' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3110' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3120' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3130' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3140' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3150' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3160' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3161' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3162' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3170' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3180' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3190' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3200' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3210' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3220' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3230' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3250' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3251' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or (@code='3999' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.1') or @nullFlavor='NI']"
                 priority="1375"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="validCodeOrCodeSystemFound"
                    select="concat(exists(document('include/voc-2.16.840.1.113883.2.4.11.126-DYNAMIC.xml')/*/valueSet[conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-2.16.840.1.113883.2.4.11.126-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>
      <xsl:variable name="explicitExceptions" select="''"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or contains($validCodeOrCodeSystemFound,'true')"/>
         <xsl:otherwise>
            <xsl:message>(Soortbijzonderhedenobstetrischeanamnese): de waarde van @code MOET worden gekozen uit waardenlijst VILLijst3000 (DYNAMISCH). NB: codeSystemVersion MOET exact overeenkomen indien gespecificeerd in de waardenlijst. (@nullFlavor or contains($validCodeOrCodeSystemFound,'true') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900155-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|'))"/>
         <xsl:otherwise>
            <xsl:message>(Soortbijzonderhedenobstetrischeanamnese): de nulwaarde voor @code MOET komen uit de set die is gedefinieerd voor dit attribuut of zijn gekoppeld aan waardenlijst VILLijst3000 (DYNAMISCH). (not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|')) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900155-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-681122-392042-585743-830413-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='364332008' and @codeSystem='2.16.840.1.113883.6.96')]]]"
                 priority="1374"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='PERT'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @typeCode MOET 'PERT' zijn. (string(@typeCode)='PERT' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@contextConductionInd)='true'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @contextConductionInd MOET 'true' zijn. (string(@contextConductionInd)='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-322998-588463-516111-813039-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='364332008' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation"
                 priority="1373"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(HoeveelheidBloedverlies_2): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900900-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(HoeveelheidBloedverlies_2): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900900-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='364332008' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='364332008' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(HoeveelheidBloedverlies_2): element hl7:code[(@code='364332008' and @codeSystem='2.16.840.1.113883.6.96')] is mandatory [min 1x]. (count(hl7:code[(@code='364332008' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='364332008' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900900-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='364332008' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HoeveelheidBloedverlies_2): element hl7:code[(@code='364332008' and @codeSystem='2.16.840.1.113883.6.96')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='364332008' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900900-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(HoeveelheidBloedverlies_2): element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900900-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HoeveelheidBloedverlies_2): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900900-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-348065-884422-379885-664076-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='364332008' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:code[(@code='364332008' and @codeSystem='2.16.840.1.113883.6.96')]"
                 priority="1372"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='364332008' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>(HoeveelheidBloedverlies_2): de elementwaarde MOET zijn code '364332008' codeSystem '2.16.840.1.113883.6.96'. (@nullFlavor or (@code='364332008' and @codeSystem='2.16.840.1.113883.6.96') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900900-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-413879-413851-331616-237234-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='364332008' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:value"
                 priority="1371"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (@unit='ml' and number($theValue)&gt;=0))"/>
         <xsl:otherwise>
            <xsl:message>(HoeveelheidBloedverlies_2): value MOET eenheid 'ml' gebruiken en in bereik [0..] liggen   ((@nullFlavor or (@unit='ml' and number($theValue)&gt;=0)) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900900-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-560861-129077-530262-842592-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='59291004' and @codeSystem='2.16.840.1.113883.6.96')]]]"
                 priority="1370"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='PERT'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @typeCode MOET 'PERT' zijn. (string(@typeCode)='PERT' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@contextConductionInd)='true'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @contextConductionInd MOET 'true' zijn. (string(@contextConductionInd)='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-566961-393652-967454-460803-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='59291004' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation"
                 priority="1369"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(IUVD): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900918-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(IUVD): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900918-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='59291004' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='59291004' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(IUVD): element hl7:code[(@code='59291004' and @codeSystem='2.16.840.1.113883.6.96')] is mandatory [min 1x]. (count(hl7:code[(@code='59291004' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='59291004' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900918-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='59291004' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IUVD): element hl7:code[(@code='59291004' and @codeSystem='2.16.840.1.113883.6.96')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='59291004' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900918-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:uncertaintyCode)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IUVD): element hl7:uncertaintyCode komt te vaak voor [max 1x]. (count(hl7:uncertaintyCode)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900918-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(IUVD): element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900918-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IUVD): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900918-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-475510-500751-573980-335844-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='59291004' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:code[(@code='59291004' and @codeSystem='2.16.840.1.113883.6.96')]"
                 priority="1368"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='59291004' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>(IUVD): de elementwaarde MOET zijn code '59291004' codeSystem '2.16.840.1.113883.6.96'. (@nullFlavor or (@code='59291004' and @codeSystem='2.16.840.1.113883.6.96') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900918-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-836679-274922-955865-489073-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='59291004' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:uncertaintyCode"
                 priority="1367"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="validCodeOrCodeSystemFound"
                    select="concat(exists(document('include/voc-2.16.840.1.113883.2.4.11.52-2013-03-20T000000.xml')/*/valueSet[conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-2.16.840.1.113883.2.4.11.52-2013-03-20T000000.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>
      <xsl:variable name="explicitExceptions" select="''"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or contains($validCodeOrCodeSystemFound,'true')"/>
         <xsl:otherwise>
            <xsl:message>(IUVD): de waarde van @code MOET worden gekozen uit waardenlijst UncertaintyCode2 UncertaintyCode 2 (2013-03-20T00:00:00). NB: codeSystemVersion MOET exact overeenkomen indien gespecificeerd in de waardenlijst. (@nullFlavor or contains($validCodeOrCodeSystemFound,'true') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900918-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|'))"/>
         <xsl:otherwise>
            <xsl:message>(IUVD): de nulwaarde voor @code MOET komen uit de set die is gedefinieerd voor dit attribuut of zijn gekoppeld aan waardenlijst UncertaintyCode2 UncertaintyCode 2 (2013-03-20T00:00:00). (not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|')) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900918-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="../hl7:value/@value='true'"/>
         <xsl:otherwise>
            <xsl:message>(IUVD): Waarschijnlijkheid intra-uteriene vruchtdood alleen opnemen wanneer er sprake is van intra-uteriene vruchtdood. (../hl7:value/@value='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900918-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-537563-437439-733700-532818-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='59291004' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:value"
                 priority="1366"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @value='false' or ../hl7:uncertaintyCode"/>
         <xsl:otherwise>
            <xsl:message>(IUVD):  Als er sprake is van intra-uteriene vruchtdood dan moet waarschijnlijkheid intra-uteriene vruchtdood worden meegegeven. (@nullFlavor or @value='false' or ../hl7:uncertaintyCode / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900918-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-138670-893894-834402-515943-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='106190000' and @codeSystem='2.16.840.1.113883.6.96')]]]"
                 priority="1365"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='PERT'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @typeCode MOET 'PERT' zijn. (string(@typeCode)='PERT' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@contextConductionInd)='true'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @contextConductionInd MOET 'true' zijn. (string(@contextConductionInd)='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-570316-986476-566573-315752-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='106190000' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation"
                 priority="1364"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(Allergieen): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900149-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(Allergieen): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900149-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='106190000' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='106190000' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Allergieen): element hl7:code[(@code='106190000' and @codeSystem='2.16.840.1.113883.6.96')] is mandatory [min 1x]. (count(hl7:code[(@code='106190000' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='106190000' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900149-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='106190000' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Allergieen): element hl7:code[(@code='106190000' and @codeSystem='2.16.840.1.113883.6.96')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='106190000' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900149-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value[(@code='160244002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='300916003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='294914009' and @codeSystem='2.16.840.1.113883.6.96') or (@code='62014003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='292799005' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI'])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(Allergieen): element hl7:value[(@code='160244002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='300916003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='294914009' and @codeSystem='2.16.840.1.113883.6.96') or (@code='62014003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='292799005' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI'] is required [min 1x]. (count(hl7:value[(@code='160244002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='300916003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='294914009' and @codeSystem='2.16.840.1.113883.6.96') or (@code='62014003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='292799005' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI'])&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900149-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value[(@code='160244002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='300916003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='294914009' and @codeSystem='2.16.840.1.113883.6.96') or (@code='62014003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='292799005' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Allergieen): element hl7:value[(@code='160244002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='300916003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='294914009' and @codeSystem='2.16.840.1.113883.6.96') or (@code='62014003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='292799005' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI'] komt te vaak voor [max 1x]. (count(hl7:value[(@code='160244002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='300916003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='294914009' and @codeSystem='2.16.840.1.113883.6.96') or (@code='62014003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='292799005' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI'])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900149-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-166419-610024-521262-667280-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='106190000' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:code[(@code='106190000' and @codeSystem='2.16.840.1.113883.6.96')]"
                 priority="1363"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='106190000' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>(Allergieen): de elementwaarde MOET zijn code '106190000' codeSystem '2.16.840.1.113883.6.96'. (@nullFlavor or (@code='106190000' and @codeSystem='2.16.840.1.113883.6.96') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900149-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-779675-778494-677134-452368-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='106190000' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:value[(@code='160244002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='300916003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='294914009' and @codeSystem='2.16.840.1.113883.6.96') or (@code='62014003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='292799005' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI']"
                 priority="1362"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="validCodeOrCodeSystemFound"
                    select="concat(exists(document('include/voc-2.16.840.1.113883.2.4.11.154-2013-03-20T000000.xml')/*/valueSet[conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-2.16.840.1.113883.2.4.11.154-2013-03-20T000000.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>
      <xsl:variable name="explicitExceptions" select="''"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or contains($validCodeOrCodeSystemFound,'true')"/>
         <xsl:otherwise>
            <xsl:message>(Allergieen): de waarde van @code MOET worden gekozen uit waardenlijst Allergies (2013-03-20T00:00:00). NB: codeSystemVersion MOET exact overeenkomen indien gespecificeerd in de waardenlijst. (@nullFlavor or contains($validCodeOrCodeSystemFound,'true') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900149-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|'))"/>
         <xsl:otherwise>
            <xsl:message>(Allergieen): de nulwaarde voor @code MOET komen uit de set die is gedefinieerd voor dit attribuut of zijn gekoppeld aan waardenlijst Allergies (2013-03-20T00:00:00). (not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|')) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900149-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-350748-573834-919691-854054-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='129019007' and @codeSystem='2.16.840.1.113883.6.96')]]]"
                 priority="1361"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='PERT'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @typeCode MOET 'PERT' zijn. (string(@typeCode)='PERT' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@contextConductionInd)='true'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @contextConductionInd MOET 'true' zijn. (string(@contextConductionInd)='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-159297-475725-378694-785099-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='129019007' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation"
                 priority="1360"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(Actuelemedicatie): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900654-2012-05-03T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(Actuelemedicatie): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900654-2012-05-03T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='129019007' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='129019007' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Actuelemedicatie): element hl7:code[(@code='129019007' and @codeSystem='2.16.840.1.113883.6.96')] is mandatory [min 1x]. (count(hl7:code[(@code='129019007' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='129019007' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900654-2012-05-03T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='129019007' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Actuelemedicatie): element hl7:code[(@code='129019007' and @codeSystem='2.16.840.1.113883.6.96')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='129019007' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900654-2012-05-03T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(Actuelemedicatie): element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900654-2012-05-03T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Actuelemedicatie): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900654-2012-05-03T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-991357-993951-443077-217994-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='129019007' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:code[(@code='129019007' and @codeSystem='2.16.840.1.113883.6.96')]"
                 priority="1359"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='129019007' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>(Actuelemedicatie): de elementwaarde MOET zijn code '129019007' codeSystem '2.16.840.1.113883.6.96'. (@nullFlavor or (@code='129019007' and @codeSystem='2.16.840.1.113883.6.96') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900654-2012-05-03T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-435254-879117-634084-648178-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='129019007' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:value"
                 priority="1358"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@value='true' or count(../hl7:inboundRelationship)=0"/>
         <xsl:otherwise>
            <xsl:message>(Actuelemedicatie): Als er geen sprake van medicatie is is dan mag er geen lijst medicatie als inboundRelationship component worden meegegeven (@value='true' or count(../hl7:inboundRelationship)=0 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900654-2012-05-03T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-311837-369564-209842-809225-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='129019007' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:inboundRelationship"
                 priority="1357"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(Actuelemedicatie): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900654-2012-05-03T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-318850-797698-176632-607750-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='129019007' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:inboundRelationship/hl7:substanceAdministration"
                 priority="1356"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='SBADM'"/>
         <xsl:otherwise>
            <xsl:message>(SoortactueleMedicatie): de waarde van @classCode MOET 'SBADM' zijn. (string(@classCode)='SBADM' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900655-2012-04-22T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(SoortactueleMedicatie): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900655-2012-04-22T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:consumable)&gt;=1 and not(hl7:consumable/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(SoortactueleMedicatie): element hl7:consumable is mandatory [min 1x]. (count(hl7:consumable)&gt;=1 and not(hl7:consumable/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900655-2012-04-22T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:consumable)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SoortactueleMedicatie): element hl7:consumable komt te vaak voor [max 1x]. (count(hl7:consumable)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900655-2012-04-22T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-997956-815722-662918-468718-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='129019007' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:inboundRelationship/hl7:substanceAdministration/hl7:consumable"
                 priority="1355"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='CSM'"/>
         <xsl:otherwise>
            <xsl:message>(SoortactueleMedicatie): de waarde van @typeCode MOET 'CSM' zijn. (string(@typeCode)='CSM' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900655-2012-04-22T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:manufacturedProduct)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(SoortactueleMedicatie): element hl7:manufacturedProduct is required [min 1x]. (count(hl7:manufacturedProduct)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900655-2012-04-22T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:manufacturedProduct)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SoortactueleMedicatie): element hl7:manufacturedProduct komt te vaak voor [max 1x]. (count(hl7:manufacturedProduct)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900655-2012-04-22T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-655159-522054-814651-177339-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='129019007' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:inboundRelationship/hl7:substanceAdministration/hl7:consumable/hl7:manufacturedProduct"
                 priority="1354"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='MANU'"/>
         <xsl:otherwise>
            <xsl:message>(SoortactueleMedicatie): de waarde van @classCode MOET 'MANU' zijn. (string(@classCode)='MANU' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900655-2012-04-22T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:manufacturedProduct)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(SoortactueleMedicatie): element hl7:manufacturedProduct is required [min 1x]. (count(hl7:manufacturedProduct)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900655-2012-04-22T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:manufacturedProduct)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SoortactueleMedicatie): element hl7:manufacturedProduct komt te vaak voor [max 1x]. (count(hl7:manufacturedProduct)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900655-2012-04-22T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-917556-253725-177257-494419-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='129019007' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:inboundRelationship/hl7:substanceAdministration/hl7:consumable/hl7:manufacturedProduct/hl7:manufacturedProduct"
                 priority="1353"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='MMAT'"/>
         <xsl:otherwise>
            <xsl:message>(SoortactueleMedicatie): de waarde van @classCode MOET 'MMAT' zijn. (string(@classCode)='MMAT' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900655-2012-04-22T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@determinerCode)='KIND'"/>
         <xsl:otherwise>
            <xsl:message>(SoortactueleMedicatie): de waarde van @determinerCode MOET 'KIND' zijn. (string(@determinerCode)='KIND' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900655-2012-04-22T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:name)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(SoortactueleMedicatie): element hl7:name is required [min 1x]. (count(hl7:name)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900655-2012-04-22T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:name)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SoortactueleMedicatie): element hl7:name komt te vaak voor [max 1x]. (count(hl7:name)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900655-2012-04-22T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-120318-255141-448069-731794-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='129019007' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:inboundRelationship/hl7:substanceAdministration/hl7:consumable/hl7:manufacturedProduct/hl7:manufacturedProduct/hl7:name"
                 priority="1352"
                 mode="M6">
      <xsl:variable name="theValue" select="text()"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@nullFlavor)='NI' or string(@nullFlavor)='UNK' or not(@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(SoortactueleMedicatie): de waarde van @nullFlavor MOET één van de volgende codes bevatten: NI', 'UNK. (string(@nullFlavor)='NI' or string(@nullFlavor)='UNK' or not(@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900655-2012-04-22T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-452105-704083-529847-636859-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='NEGSE' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]"
                 priority="1351"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='PERT'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @typeCode MOET 'PERT' zijn. (string(@typeCode)='PERT' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@contextConductionInd)='true'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @contextConductionInd MOET 'true' zijn. (string(@contextConductionInd)='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-692224-969617-215651-955175-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='NEGSE' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation"
                 priority="1350"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(Negatievesexueleervaringen): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900656-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(Negatievesexueleervaringen): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900656-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='NEGSE' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&gt;=1 and not(hl7:code[(@code='NEGSE' and @codeSystem='2.16.840.1.113883.2.4.4.13')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Negatievesexueleervaringen): element hl7:code[(@code='NEGSE' and @codeSystem='2.16.840.1.113883.2.4.4.13')] is mandatory [min 1x]. (count(hl7:code[(@code='NEGSE' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&gt;=1 and not(hl7:code[(@code='NEGSE' and @codeSystem='2.16.840.1.113883.2.4.4.13')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900656-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='NEGSE' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Negatievesexueleervaringen): element hl7:code[(@code='NEGSE' and @codeSystem='2.16.840.1.113883.2.4.4.13')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='NEGSE' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900656-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(Negatievesexueleervaringen): element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900656-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Negatievesexueleervaringen): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900656-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-744216-150076-967409-101678-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='NEGSE' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:code[(@code='NEGSE' and @codeSystem='2.16.840.1.113883.2.4.4.13')]"
                 priority="1349"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='NEGSE' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>(Negatievesexueleervaringen): de elementwaarde MOET zijn code 'NEGSE' codeSystem '2.16.840.1.113883.2.4.4.13'. (@nullFlavor or (@code='NEGSE' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900656-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-172849-293517-260703-985220-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='NEGSE' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:value"
                 priority="1348"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-249781-812600-754265-837949-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='266096002' and @codeSystem='2.16.840.1.113883.6.96')]]]"
                 priority="1347"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='PERT'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @typeCode MOET 'PERT' zijn. (string(@typeCode)='PERT' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@contextConductionInd)='true'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @contextConductionInd MOET 'true' zijn. (string(@contextConductionInd)='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-227495-321776-946352-330347-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='266096002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation"
                 priority="1346"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(MRSAbesmettingaangetoond): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900657-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(MRSAbesmettingaangetoond): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900657-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='266096002' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='266096002' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(MRSAbesmettingaangetoond): element hl7:code[(@code='266096002' and @codeSystem='2.16.840.1.113883.6.96')] is mandatory [min 1x]. (count(hl7:code[(@code='266096002' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='266096002' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900657-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='266096002' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MRSAbesmettingaangetoond): element hl7:code[(@code='266096002' and @codeSystem='2.16.840.1.113883.6.96')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='266096002' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900657-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(MRSAbesmettingaangetoond): element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900657-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MRSAbesmettingaangetoond): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900657-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-919800-458567-811718-550158-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='266096002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:code[(@code='266096002' and @codeSystem='2.16.840.1.113883.6.96')]"
                 priority="1345"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='266096002' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>(MRSAbesmettingaangetoond): de elementwaarde MOET zijn code '266096002' codeSystem '2.16.840.1.113883.6.96'. (@nullFlavor or (@code='266096002' and @codeSystem='2.16.840.1.113883.6.96') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900657-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-637589-679519-333152-128930-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='266096002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:value"
                 priority="1344"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-126679-192684-121634-185665-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='161664006' and @codeSystem='2.16.840.1.113883.6.96')]]]"
                 priority="1343"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='PERT'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @typeCode MOET 'PERT' zijn. (string(@typeCode)='PERT' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@contextConductionInd)='true'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @contextConductionInd MOET 'true' zijn. (string(@contextConductionInd)='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-658738-502782-753455-426257-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='161664006' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation"
                 priority="1342"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(Bloedtransfusie): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900158-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(Bloedtransfusie): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900158-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='161664006' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='161664006' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Bloedtransfusie): element hl7:code[(@code='161664006' and @codeSystem='2.16.840.1.113883.6.96')] is mandatory [min 1x]. (count(hl7:code[(@code='161664006' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='161664006' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900158-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='161664006' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Bloedtransfusie): element hl7:code[(@code='161664006' and @codeSystem='2.16.840.1.113883.6.96')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='161664006' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900158-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(Bloedtransfusie): element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900158-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Bloedtransfusie): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900158-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-112617-819198-953632-301058-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='161664006' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:code[(@code='161664006' and @codeSystem='2.16.840.1.113883.6.96')]"
                 priority="1341"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='161664006' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>(Bloedtransfusie): de elementwaarde MOET zijn code '161664006' codeSystem '2.16.840.1.113883.6.96'. (@nullFlavor or (@code='161664006' and @codeSystem='2.16.840.1.113883.6.96') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900158-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-328163-493900-887866-687803-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='161664006' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:value"
                 priority="1340"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-396069-602281-648799-516936-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='39156-5' and @codeSystem='2.16.840.1.113883.6.1')]]]"
                 priority="1339"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='PERT'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @typeCode MOET 'PERT' zijn. (string(@typeCode)='PERT' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@contextConductionInd)='true'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @contextConductionInd MOET 'true' zijn. (string(@contextConductionInd)='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-121935-705410-977198-998909-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='39156-5' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation"
                 priority="1338"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(BMI): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900159-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(BMI): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900159-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='39156-5' and @codeSystem='2.16.840.1.113883.6.1')])&gt;=1 and not(hl7:code[(@code='39156-5' and @codeSystem='2.16.840.1.113883.6.1')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(BMI): element hl7:code[(@code='39156-5' and @codeSystem='2.16.840.1.113883.6.1')] is mandatory [min 1x]. (count(hl7:code[(@code='39156-5' and @codeSystem='2.16.840.1.113883.6.1')])&gt;=1 and not(hl7:code[(@code='39156-5' and @codeSystem='2.16.840.1.113883.6.1')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900159-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='39156-5' and @codeSystem='2.16.840.1.113883.6.1')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(BMI): element hl7:code[(@code='39156-5' and @codeSystem='2.16.840.1.113883.6.1')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='39156-5' and @codeSystem='2.16.840.1.113883.6.1')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900159-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:effectiveTime)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(BMI): element hl7:effectiveTime komt te vaak voor [max 1x]. (count(hl7:effectiveTime)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900159-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(BMI): element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900159-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(BMI): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900159-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-151271-851648-580442-780733-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='39156-5' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation/hl7:code[(@code='39156-5' and @codeSystem='2.16.840.1.113883.6.1')]"
                 priority="1337"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='39156-5' and @codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <xsl:message>(BMI): de elementwaarde MOET zijn code '39156-5' codeSystem '2.16.840.1.113883.6.1'. (@nullFlavor or (@code='39156-5' and @codeSystem='2.16.840.1.113883.6.1') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900159-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-386590-668344-701885-307938-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='39156-5' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation/hl7:effectiveTime"
                 priority="1336"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-304948-724352-598014-753554-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='39156-5' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation/hl7:value"
                 priority="1335"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (@unit='kg/m2' and number($theValue)&gt;=0))"/>
         <xsl:otherwise>
            <xsl:message>(BMI): value MOET eenheid 'kg/m2' gebruiken en in bereik [0..] liggen   ((@nullFlavor or (@unit='kg/m2' and number($theValue)&gt;=0)) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900159-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-567272-369396-185603-547478-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='75367002' and @codeSystem='2.16.840.1.113883.6.96')]]]"
                 priority="1334"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='PERT'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @typeCode MOET 'PERT' zijn. (string(@typeCode)='PERT' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@contextConductionInd)='true'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @contextConductionInd MOET 'true' zijn. (string(@contextConductionInd)='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-576639-224366-824914-153013-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='75367002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer"
                 priority="1333"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='CONTAINER'"/>
         <xsl:otherwise>
            <xsl:message>(Actuelebloeddruk): de waarde van @classCode MOET 'CONTAINER' zijn. (string(@classCode)='CONTAINER' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900612-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(Actuelebloeddruk): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900612-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='75367002' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='75367002' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Actuelebloeddruk): element hl7:code[(@code='75367002' and @codeSystem='2.16.840.1.113883.6.96')] is mandatory [min 1x]. (count(hl7:code[(@code='75367002' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='75367002' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900612-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='75367002' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Actuelebloeddruk): element hl7:code[(@code='75367002' and @codeSystem='2.16.840.1.113883.6.96')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='75367002' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900612-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:observation[hl7:code[(@code='271649006' and @codeSystem='2.16.840.1.113883.6.96')]]])&gt;=1 and not(hl7:component[hl7:observation[hl7:code[(@code='271649006' and @codeSystem='2.16.840.1.113883.6.96')]]]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Actuelebloeddruk): element hl7:component[hl7:observation[hl7:code[(@code='271649006' and @codeSystem='2.16.840.1.113883.6.96')]]] is mandatory [min 1x]. (count(hl7:component[hl7:observation[hl7:code[(@code='271649006' and @codeSystem='2.16.840.1.113883.6.96')]]])&gt;=1 and not(hl7:component[hl7:observation[hl7:code[(@code='271649006' and @codeSystem='2.16.840.1.113883.6.96')]]]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900612-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:observation[hl7:code[(@code='271649006' and @codeSystem='2.16.840.1.113883.6.96')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Actuelebloeddruk): element hl7:component[hl7:observation[hl7:code[(@code='271649006' and @codeSystem='2.16.840.1.113883.6.96')]]] komt te vaak voor [max 1x]. (count(hl7:component[hl7:observation[hl7:code[(@code='271649006' and @codeSystem='2.16.840.1.113883.6.96')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900612-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:observation[hl7:code[(@code='271650006' and @codeSystem='2.16.840.1.113883.6.96')]]])&gt;=1 and not(hl7:component[hl7:observation[hl7:code[(@code='271650006' and @codeSystem='2.16.840.1.113883.6.96')]]]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Actuelebloeddruk): element hl7:component[hl7:observation[hl7:code[(@code='271650006' and @codeSystem='2.16.840.1.113883.6.96')]]] is mandatory [min 1x]. (count(hl7:component[hl7:observation[hl7:code[(@code='271650006' and @codeSystem='2.16.840.1.113883.6.96')]]])&gt;=1 and not(hl7:component[hl7:observation[hl7:code[(@code='271650006' and @codeSystem='2.16.840.1.113883.6.96')]]]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900612-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:observation[hl7:code[(@code='271650006' and @codeSystem='2.16.840.1.113883.6.96')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Actuelebloeddruk): element hl7:component[hl7:observation[hl7:code[(@code='271650006' and @codeSystem='2.16.840.1.113883.6.96')]]] komt te vaak voor [max 1x]. (count(hl7:component[hl7:observation[hl7:code[(@code='271650006' and @codeSystem='2.16.840.1.113883.6.96')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900612-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-722397-233430-389420-794088-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='75367002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:code[(@code='75367002' and @codeSystem='2.16.840.1.113883.6.96')]"
                 priority="1332"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='75367002' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>(Actuelebloeddruk): de elementwaarde MOET zijn code '75367002' codeSystem '2.16.840.1.113883.6.96'. (@nullFlavor or (@code='75367002' and @codeSystem='2.16.840.1.113883.6.96') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900612-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-906453-684210-220620-831077-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='75367002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='271649006' and @codeSystem='2.16.840.1.113883.6.96')]]]"
                 priority="1331"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(Actuelebloeddruk): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900612-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-273078-403754-340934-804337-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='75367002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='271649006' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation"
                 priority="1330"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(Actuelebloeddruksystolisch): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900661-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(Actuelebloeddruksystolisch): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900661-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='271649006' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='271649006' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Actuelebloeddruksystolisch): element hl7:code[(@code='271649006' and @codeSystem='2.16.840.1.113883.6.96')] is mandatory [min 1x]. (count(hl7:code[(@code='271649006' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='271649006' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900661-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='271649006' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Actuelebloeddruksystolisch): element hl7:code[(@code='271649006' and @codeSystem='2.16.840.1.113883.6.96')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='271649006' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900661-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(Actuelebloeddruksystolisch): element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900661-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Actuelebloeddruksystolisch): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900661-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-546214-880362-430317-971763-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='75367002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='271649006' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:code[(@code='271649006' and @codeSystem='2.16.840.1.113883.6.96')]"
                 priority="1329"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='271649006' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>(Actuelebloeddruksystolisch): de elementwaarde MOET zijn code '271649006' codeSystem '2.16.840.1.113883.6.96'. (@nullFlavor or (@code='271649006' and @codeSystem='2.16.840.1.113883.6.96') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900661-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-452052-134896-502534-638617-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='75367002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='271649006' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:value"
                 priority="1328"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (@unit='mm[Hg]' and number($theValue)&gt;=0))"/>
         <xsl:otherwise>
            <xsl:message>(Actuelebloeddruksystolisch): value MOET eenheid 'mm[Hg]' gebruiken en in bereik [0..] liggen   ((@nullFlavor or (@unit='mm[Hg]' and number($theValue)&gt;=0)) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900661-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-310601-610384-544796-165315-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='75367002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='271650006' and @codeSystem='2.16.840.1.113883.6.96')]]]"
                 priority="1327"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(Actuelebloeddruk): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900612-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-715627-697976-984820-532561-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='75367002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='271650006' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation"
                 priority="1326"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(Actuelebloeddrukdiastolisch): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900662-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(Actuelebloeddrukdiastolisch): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900662-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='271650006' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='271650006' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Actuelebloeddrukdiastolisch): element hl7:code[(@code='271650006' and @codeSystem='2.16.840.1.113883.6.96')] is mandatory [min 1x]. (count(hl7:code[(@code='271650006' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='271650006' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900662-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='271650006' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Actuelebloeddrukdiastolisch): element hl7:code[(@code='271650006' and @codeSystem='2.16.840.1.113883.6.96')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='271650006' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900662-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(Actuelebloeddrukdiastolisch): element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900662-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Actuelebloeddrukdiastolisch): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900662-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-386556-670669-765050-816769-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='75367002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='271650006' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:code[(@code='271650006' and @codeSystem='2.16.840.1.113883.6.96')]"
                 priority="1325"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='271650006' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>(Actuelebloeddrukdiastolisch): de elementwaarde MOET zijn code '271650006' codeSystem '2.16.840.1.113883.6.96'. (@nullFlavor or (@code='271650006' and @codeSystem='2.16.840.1.113883.6.96') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900662-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-827700-303489-341814-309290-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='75367002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='271650006' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:value"
                 priority="1324"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (@unit='mm[Hg]' and number($theValue)&gt;=0))"/>
         <xsl:otherwise>
            <xsl:message>(Actuelebloeddrukdiastolisch): value MOET eenheid 'mm[Hg]' gebruiken en in bereik [0..] liggen   ((@nullFlavor or (@unit='mm[Hg]' and number($theValue)&gt;=0)) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900662-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-796974-739267-667883-486757-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='883-9' and @codeSystem='2.16.840.1.113883.6.1')]]]"
                 priority="1323"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='PERT'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @typeCode MOET 'PERT' zijn. (string(@typeCode)='PERT' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@contextConductionInd)='true'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @contextConductionInd MOET 'true' zijn. (string(@contextConductionInd)='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-645712-762142-326882-875738-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='883-9' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation"
                 priority="1322"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(Bloedgroep): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900663-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(Bloedgroep): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900663-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='883-9' and @codeSystem='2.16.840.1.113883.6.1')])&gt;=1 and not(hl7:code[(@code='883-9' and @codeSystem='2.16.840.1.113883.6.1')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Bloedgroep): element hl7:code[(@code='883-9' and @codeSystem='2.16.840.1.113883.6.1')] is mandatory [min 1x]. (count(hl7:code[(@code='883-9' and @codeSystem='2.16.840.1.113883.6.1')])&gt;=1 and not(hl7:code[(@code='883-9' and @codeSystem='2.16.840.1.113883.6.1')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900663-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='883-9' and @codeSystem='2.16.840.1.113883.6.1')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Bloedgroep): element hl7:code[(@code='883-9' and @codeSystem='2.16.840.1.113883.6.1')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='883-9' and @codeSystem='2.16.840.1.113883.6.1')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900663-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value[(@code='112144000' and @codeSystem='2.16.840.1.113883.6.96') or (@code='112149005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='165743006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='58460004' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='NI'])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(Bloedgroep): element hl7:value[(@code='112144000' and @codeSystem='2.16.840.1.113883.6.96') or (@code='112149005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='165743006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='58460004' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='NI'] is required [min 1x]. (count(hl7:value[(@code='112144000' and @codeSystem='2.16.840.1.113883.6.96') or (@code='112149005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='165743006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='58460004' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='NI'])&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900663-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value[(@code='112144000' and @codeSystem='2.16.840.1.113883.6.96') or (@code='112149005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='165743006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='58460004' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='NI'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Bloedgroep): element hl7:value[(@code='112144000' and @codeSystem='2.16.840.1.113883.6.96') or (@code='112149005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='165743006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='58460004' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='NI'] komt te vaak voor [max 1x]. (count(hl7:value[(@code='112144000' and @codeSystem='2.16.840.1.113883.6.96') or (@code='112149005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='165743006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='58460004' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='NI'])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900663-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-510959-833051-218956-611977-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='883-9' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation/hl7:code[(@code='883-9' and @codeSystem='2.16.840.1.113883.6.1')]"
                 priority="1321"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='883-9' and @codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <xsl:message>(Bloedgroep): de elementwaarde MOET zijn code '883-9' codeSystem '2.16.840.1.113883.6.1'. (@nullFlavor or (@code='883-9' and @codeSystem='2.16.840.1.113883.6.1') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900663-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-359595-881927-999854-639859-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='883-9' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation/hl7:value[(@code='112144000' and @codeSystem='2.16.840.1.113883.6.96') or (@code='112149005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='165743006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='58460004' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='NI']"
                 priority="1320"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="validCodeOrCodeSystemFound"
                    select="concat(exists(document('include/voc-2.16.840.1.113883.2.4.11.155-DYNAMIC.xml')/*/valueSet[conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-2.16.840.1.113883.2.4.11.155-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>
      <xsl:variable name="explicitExceptions" select="''"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or contains($validCodeOrCodeSystemFound,'true')"/>
         <xsl:otherwise>
            <xsl:message>(Bloedgroep): de waarde van @code MOET worden gekozen uit waardenlijst AB0BloodGroup AB0 blood group (DYNAMISCH). NB: codeSystemVersion MOET exact overeenkomen indien gespecificeerd in de waardenlijst. (@nullFlavor or contains($validCodeOrCodeSystemFound,'true') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900663-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|'))"/>
         <xsl:otherwise>
            <xsl:message>(Bloedgroep): de nulwaarde voor @code MOET komen uit de set die is gedefinieerd voor dit attribuut of zijn gekoppeld aan waardenlijst AB0BloodGroup AB0 blood group (DYNAMISCH). (not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|')) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900663-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-383369-906901-881159-863426-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='978-7' and @codeSystem='2.16.840.1.113883.6.1')]]]"
                 priority="1319"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='PERT'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @typeCode MOET 'PERT' zijn. (string(@typeCode)='PERT' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@contextConductionInd)='true'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @contextConductionInd MOET 'true' zijn. (string(@contextConductionInd)='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-386430-716414-311919-965290-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='978-7' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation"
                 priority="1318"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(RhesusDFactor): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900669-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(RhesusDFactor): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900669-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='978-7' and @codeSystem='2.16.840.1.113883.6.1')])&gt;=1 and not(hl7:code[(@code='978-7' and @codeSystem='2.16.840.1.113883.6.1')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(RhesusDFactor): element hl7:code[(@code='978-7' and @codeSystem='2.16.840.1.113883.6.1')] is mandatory [min 1x]. (count(hl7:code[(@code='978-7' and @codeSystem='2.16.840.1.113883.6.1')])&gt;=1 and not(hl7:code[(@code='978-7' and @codeSystem='2.16.840.1.113883.6.1')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900669-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='978-7' and @codeSystem='2.16.840.1.113883.6.1')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(RhesusDFactor): element hl7:code[(@code='978-7' and @codeSystem='2.16.840.1.113883.6.1')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='978-7' and @codeSystem='2.16.840.1.113883.6.1')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900669-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value[(@code='165747007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='165746003' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='NI'])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(RhesusDFactor): element hl7:value[(@code='165747007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='165746003' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='NI'] is required [min 1x]. (count(hl7:value[(@code='165747007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='165746003' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='NI'])&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900669-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value[(@code='165747007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='165746003' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='NI'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(RhesusDFactor): element hl7:value[(@code='165747007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='165746003' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='NI'] komt te vaak voor [max 1x]. (count(hl7:value[(@code='165747007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='165746003' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='NI'])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900669-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-193545-999482-674342-973582-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='978-7' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation/hl7:code[(@code='978-7' and @codeSystem='2.16.840.1.113883.6.1')]"
                 priority="1317"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='978-7' and @codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <xsl:message>(RhesusDFactor): de elementwaarde MOET zijn code '978-7' codeSystem '2.16.840.1.113883.6.1'. (@nullFlavor or (@code='978-7' and @codeSystem='2.16.840.1.113883.6.1') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900669-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-492751-223422-663561-571810-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='978-7' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation/hl7:value[(@code='165747007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='165746003' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='NI']"
                 priority="1316"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="validCodeOrCodeSystemFound"
                    select="concat(exists(document('include/voc-2.16.840.1.113883.2.4.11.156-DYNAMIC.xml')/*/valueSet[conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-2.16.840.1.113883.2.4.11.156-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>
      <xsl:variable name="explicitExceptions" select="''"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or contains($validCodeOrCodeSystemFound,'true')"/>
         <xsl:otherwise>
            <xsl:message>(RhesusDFactor): de waarde van @code MOET worden gekozen uit waardenlijst RhesusDBloodGroup Rhesus D Blood Group (DYNAMISCH). NB: codeSystemVersion MOET exact overeenkomen indien gespecificeerd in de waardenlijst. (@nullFlavor or contains($validCodeOrCodeSystemFound,'true') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900669-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|'))"/>
         <xsl:otherwise>
            <xsl:message>(RhesusDFactor): de nulwaarde voor @code MOET komen uit de set die is gedefinieerd voor dit attribuut of zijn gekoppeld aan waardenlijst RhesusDBloodGroup Rhesus D Blood Group (DYNAMISCH). (not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|')) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900669-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-804823-906444-352161-167725-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='312457003' and @codeSystem='2.16.840.1.113883.6.96')]]]"
                 priority="1315"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='PERT'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @typeCode MOET 'PERT' zijn. (string(@typeCode)='PERT' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@contextConductionInd)='true'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @contextConductionInd MOET 'true' zijn. (string(@contextConductionInd)='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-787855-711405-317929-246252-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='312457003' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation"
                 priority="1314"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(Irregulaireantistoffen): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900171-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(Irregulaireantistoffen): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900171-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@negationInd='true' or @nullFlavor or hl7:value"/>
         <xsl:otherwise>
            <xsl:message>(Irregulaireantistoffen): Indien er irregulaire antistoffen aanwezig zijn moet value een waarde bevatten of nullFlavor bevatten. (@negationInd='true' or @nullFlavor or hl7:value / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900171-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='312457003' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='312457003' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Irregulaireantistoffen): element hl7:code[(@code='312457003' and @codeSystem='2.16.840.1.113883.6.96')] is mandatory [min 1x]. (count(hl7:code[(@code='312457003' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='312457003' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900171-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='312457003' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Irregulaireantistoffen): element hl7:code[(@code='312457003' and @codeSystem='2.16.840.1.113883.6.96')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='312457003' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900171-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Irregulaireantistoffen): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900171-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-617960-747388-120085-222532-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='312457003' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:code[(@code='312457003' and @codeSystem='2.16.840.1.113883.6.96')]"
                 priority="1313"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='312457003' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>(Irregulaireantistoffen): de elementwaarde MOET zijn code '312457003' codeSystem '2.16.840.1.113883.6.96'. (@nullFlavor or (@code='312457003' and @codeSystem='2.16.840.1.113883.6.96') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900171-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-608704-997774-427234-583003-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='312457003' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:value"
                 priority="1312"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="validCodeOrCodeSystemFound"
                    select="concat(exists(document('include/voc-2.16.840.1.113883.2.4.11.157-DYNAMIC.xml')/*/valueSet[conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-2.16.840.1.113883.2.4.11.157-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>
      <xsl:variable name="explicitExceptions" select="''"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or contains($validCodeOrCodeSystemFound,'true')"/>
         <xsl:otherwise>
            <xsl:message>(Irregulaireantistoffen): de waarde van @code MOET worden gekozen uit waardenlijst BloodGroupAntibodies Blood Group Antibodies (DYNAMISCH). NB: codeSystemVersion MOET exact overeenkomen indien gespecificeerd in de waardenlijst. (@nullFlavor or contains($validCodeOrCodeSystemFound,'true') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900171-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|'))"/>
         <xsl:otherwise>
            <xsl:message>(Irregulaireantistoffen): de nulwaarde voor @code MOET komen uit de set die is gedefinieerd voor dit attribuut of zijn gekoppeld aan waardenlijst BloodGroupAntibodies Blood Group Antibodies (DYNAMISCH). (not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|')) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900171-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-147560-110832-643038-535564-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='948-0' and @codeSystem='2.16.840.1.113883.6.1')]]]"
                 priority="1311"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='PERT'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @typeCode MOET 'PERT' zijn. (string(@typeCode)='PERT' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@contextConductionInd)='true'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @contextConductionInd MOET 'true' zijn. (string(@contextConductionInd)='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-389270-154615-837205-292692-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='948-0' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation"
                 priority="1310"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(RhesusCFactor): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900683-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(RhesusCFactor): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900683-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='948-0' and @codeSystem='2.16.840.1.113883.6.1')])&gt;=1 and not(hl7:code[(@code='948-0' and @codeSystem='2.16.840.1.113883.6.1')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(RhesusCFactor): element hl7:code[(@code='948-0' and @codeSystem='2.16.840.1.113883.6.1')] is mandatory [min 1x]. (count(hl7:code[(@code='948-0' and @codeSystem='2.16.840.1.113883.6.1')])&gt;=1 and not(hl7:code[(@code='948-0' and @codeSystem='2.16.840.1.113883.6.1')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900683-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='948-0' and @codeSystem='2.16.840.1.113883.6.1')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(RhesusCFactor): element hl7:code[(@code='948-0' and @codeSystem='2.16.840.1.113883.6.1')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='948-0' and @codeSystem='2.16.840.1.113883.6.1')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900683-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:effectiveTime)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(RhesusCFactor): element hl7:effectiveTime komt te vaak voor [max 1x]. (count(hl7:effectiveTime)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900683-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value[(@code='rhcneg' and @codeSystem='2.16.840.1.113883.2.4.4.13.45') or (@code='rhcpos' and @codeSystem='2.16.840.1.113883.2.4.4.13.45') or @nullFlavor='NI'])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(RhesusCFactor): element hl7:value[(@code='rhcneg' and @codeSystem='2.16.840.1.113883.2.4.4.13.45') or (@code='rhcpos' and @codeSystem='2.16.840.1.113883.2.4.4.13.45') or @nullFlavor='NI'] is required [min 1x]. (count(hl7:value[(@code='rhcneg' and @codeSystem='2.16.840.1.113883.2.4.4.13.45') or (@code='rhcpos' and @codeSystem='2.16.840.1.113883.2.4.4.13.45') or @nullFlavor='NI'])&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900683-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value[(@code='rhcneg' and @codeSystem='2.16.840.1.113883.2.4.4.13.45') or (@code='rhcpos' and @codeSystem='2.16.840.1.113883.2.4.4.13.45') or @nullFlavor='NI'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(RhesusCFactor): element hl7:value[(@code='rhcneg' and @codeSystem='2.16.840.1.113883.2.4.4.13.45') or (@code='rhcpos' and @codeSystem='2.16.840.1.113883.2.4.4.13.45') or @nullFlavor='NI'] komt te vaak voor [max 1x]. (count(hl7:value[(@code='rhcneg' and @codeSystem='2.16.840.1.113883.2.4.4.13.45') or (@code='rhcpos' and @codeSystem='2.16.840.1.113883.2.4.4.13.45') or @nullFlavor='NI'])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900683-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-862346-423247-970922-830406-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='948-0' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation/hl7:code[(@code='948-0' and @codeSystem='2.16.840.1.113883.6.1')]"
                 priority="1309"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='948-0' and @codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <xsl:message>(RhesusCFactor): de elementwaarde MOET zijn code '948-0' codeSystem '2.16.840.1.113883.6.1'. (@nullFlavor or (@code='948-0' and @codeSystem='2.16.840.1.113883.6.1') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900683-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-145375-316153-664867-220859-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='948-0' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation/hl7:effectiveTime"
                 priority="1308"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-764568-637554-569916-581319-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='948-0' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation/hl7:value[(@code='rhcneg' and @codeSystem='2.16.840.1.113883.2.4.4.13.45') or (@code='rhcpos' and @codeSystem='2.16.840.1.113883.2.4.4.13.45') or @nullFlavor='NI']"
                 priority="1307"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="validCodeOrCodeSystemFound"
                    select="concat(exists(document('include/voc-2.16.840.1.113883.2.4.11.164-DYNAMIC.xml')/*/valueSet[conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-2.16.840.1.113883.2.4.11.164-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>
      <xsl:variable name="explicitExceptions" select="''"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or contains($validCodeOrCodeSystemFound,'true')"/>
         <xsl:otherwise>
            <xsl:message>(RhesusCFactor): de waarde van @code MOET worden gekozen uit waardenlijst RhesusCFactor Rhesus C Factor (DYNAMISCH). NB: codeSystemVersion MOET exact overeenkomen indien gespecificeerd in de waardenlijst. (@nullFlavor or contains($validCodeOrCodeSystemFound,'true') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900683-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|'))"/>
         <xsl:otherwise>
            <xsl:message>(RhesusCFactor): de nulwaarde voor @code MOET komen uit de set die is gedefinieerd voor dit attribuut of zijn gekoppeld aan waardenlijst RhesusCFactor Rhesus C Factor (DYNAMISCH). (not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|')) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900683-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-801169-521486-602369-191764-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='165806002' and @codeSystem='2.16.840.1.113883.6.96')]]]"
                 priority="1306"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='PERT'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @typeCode MOET 'PERT' zijn. (string(@typeCode)='PERT' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@contextConductionInd)='true'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @contextConductionInd MOET 'true' zijn. (string(@contextConductionInd)='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-945811-204523-325721-591340-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='165806002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation"
                 priority="1305"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(HBsAg): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900186-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(HBsAg): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900186-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='165806002' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='165806002' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(HBsAg): element hl7:code[(@code='165806002' and @codeSystem='2.16.840.1.113883.6.96')] is mandatory [min 1x]. (count(hl7:code[(@code='165806002' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='165806002' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900186-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='165806002' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HBsAg): element hl7:code[(@code='165806002' and @codeSystem='2.16.840.1.113883.6.96')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='165806002' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900186-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(HBsAg): element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900186-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HBsAg): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900186-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-948370-445928-112842-355501-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='165806002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:code[(@code='165806002' and @codeSystem='2.16.840.1.113883.6.96')]"
                 priority="1304"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='165806002' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>(HBsAg): de elementwaarde MOET zijn code '165806002' codeSystem '2.16.840.1.113883.6.96'. (@nullFlavor or (@code='165806002' and @codeSystem='2.16.840.1.113883.6.96') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900186-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-602931-316368-588226-689916-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:observation[hl7:code[(@code='165806002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:value"
                 priority="1303"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-144305-618731-226231-792980-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]"
                 priority="1302"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='PERT'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @typeCode MOET 'PERT' zijn. (string(@typeCode)='PERT' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@contextConductionInd)='true'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @contextConductionInd MOET 'true' zijn. (string(@contextConductionInd)='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-905731-604411-708453-297756-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer"
                 priority="1301"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='CONTAINER'"/>
         <xsl:otherwise>
            <xsl:message>(Obstetrischeanamnesevoorgaandezwangerschap): de waarde van @classCode MOET 'CONTAINER' zijn. (string(@classCode)='CONTAINER' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900725-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(Obstetrischeanamnesevoorgaandezwangerschap): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900725-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Obstetrischeanamnesevoorgaandezwangerschap): element hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')] is mandatory [min 1x]. (count(hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900725-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Obstetrischeanamnesevoorgaandezwangerschap): element hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900725-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:observation[hl7:code[(@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1')]]])&gt;=1 and not(hl7:component[hl7:observation[hl7:code[(@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1')]]]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Obstetrischeanamnesevoorgaandezwangerschap): element hl7:component[hl7:observation[hl7:code[(@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1')]]] is mandatory [min 1x]. (count(hl7:component[hl7:observation[hl7:code[(@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1')]]])&gt;=1 and not(hl7:component[hl7:observation[hl7:code[(@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1')]]]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900725-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:observation[hl7:code[(@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Obstetrischeanamnesevoorgaandezwangerschap): element hl7:component[hl7:observation[hl7:code[(@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1')]]] komt te vaak voor [max 1x]. (count(hl7:component[hl7:observation[hl7:code[(@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900725-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:observation[hl7:code[(@code='EindeZw' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Obstetrischeanamnesevoorgaandezwangerschap): element hl7:component[hl7:observation[hl7:code[(@code='EindeZw' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]] komt te vaak voor [max 1x]. (count(hl7:component[hl7:observation[hl7:code[(@code='EindeZw' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900725-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:observation[hl7:code[(@code='412726003' and @codeSystem='2.16.840.1.113883.6.96')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Obstetrischeanamnesevoorgaandezwangerschap): element hl7:component[hl7:observation[hl7:code[(@code='412726003' and @codeSystem='2.16.840.1.113883.6.96')]]] komt te vaak voor [max 1x]. (count(hl7:component[hl7:observation[hl7:code[(@code='412726003' and @codeSystem='2.16.840.1.113883.6.96')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900725-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:procedure/hl7:code/@code='236973005'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Obstetrischeanamnesevoorgaandezwangerschap): element hl7:component[hl7:procedure/hl7:code/@code='236973005'] komt te vaak voor [max 1x]. (count(hl7:component[hl7:procedure/hl7:code/@code='236973005'])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900725-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-826119-881427-397355-405598-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]"
                 priority="1300"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>(Obstetrischeanamnesevoorgaandezwangerschap): de elementwaarde MOET zijn code '248983002' codeSystem '2.16.840.1.113883.6.96'. (@nullFlavor or (@code='248983002' and @codeSystem='2.16.840.1.113883.6.96') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900725-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-370171-545218-284532-811065-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1')]]]"
                 priority="1299"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(Obstetrischeanamnesevoorgaandezwangerschap): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900725-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@contextConductionInd)='true'"/>
         <xsl:otherwise>
            <xsl:message>(Obstetrischeanamnesevoorgaandezwangerschap): de waarde van @contextConductionInd MOET 'true' zijn. (string(@contextConductionInd)='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900725-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-515380-570488-793837-571579-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation"
                 priority="1298"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(Identificatievandezwangerschap_3): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900728-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(Identificatievandezwangerschap_3): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900728-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1')])&gt;=1 and not(hl7:code[(@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Identificatievandezwangerschap_3): element hl7:code[(@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1')] is mandatory [min 1x]. (count(hl7:code[(@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1')])&gt;=1 and not(hl7:code[(@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900728-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Identificatievandezwangerschap_3): element hl7:code[(@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900728-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Identificatievandezwangerschap_3): element hl7:value is mandatory [min 1x]. (count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900728-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Identificatievandezwangerschap_3): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900728-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-911180-983261-519731-195104-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation/hl7:code[(@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1')]"
                 priority="1297"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <xsl:message>(Identificatievandezwangerschap_3): de elementwaarde MOET zijn code 'X_PREGNBR' codeSystem '2.16.840.1.113883.6.1'. (@nullFlavor or (@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900728-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-841256-281322-119968-486453-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation/hl7:value"
                 priority="1296"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-737274-173514-124541-272886-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='EindeZw' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]"
                 priority="1295"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(Obstetrischeanamnesevoorgaandezwangerschap): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900725-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@contextConductionInd)='true'"/>
         <xsl:otherwise>
            <xsl:message>(Obstetrischeanamnesevoorgaandezwangerschap): de waarde van @contextConductionInd MOET 'true' zijn. (string(@contextConductionInd)='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900725-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-251937-181789-299509-570845-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='EindeZw' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation"
                 priority="1294"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(WijzeEindeZwangerschap): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900876-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(WijzeEindeZwangerschap): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900876-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='EindeZw' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&gt;=1 and not(hl7:code[(@code='EindeZw' and @codeSystem='2.16.840.1.113883.2.4.4.13')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(WijzeEindeZwangerschap): element hl7:code[(@code='EindeZw' and @codeSystem='2.16.840.1.113883.2.4.4.13')] is mandatory [min 1x]. (count(hl7:code[(@code='EindeZw' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&gt;=1 and not(hl7:code[(@code='EindeZw' and @codeSystem='2.16.840.1.113883.2.4.4.13')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900876-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='EindeZw' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(WijzeEindeZwangerschap): element hl7:code[(@code='EindeZw' and @codeSystem='2.16.840.1.113883.2.4.4.13')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='EindeZw' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900876-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='21' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='22' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='23' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='31' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='32' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='4' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or @nullFlavor='NI'])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(WijzeEindeZwangerschap): element hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='21' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='22' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='23' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='31' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='32' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='4' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or @nullFlavor='NI'] is required [min 1x]. (count(hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='21' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='22' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='23' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='31' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='32' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='4' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or @nullFlavor='NI'])&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900876-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='21' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='22' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='23' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='31' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='32' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='4' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or @nullFlavor='NI'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(WijzeEindeZwangerschap): element hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='21' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='22' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='23' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='31' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='32' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='4' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or @nullFlavor='NI'] komt te vaak voor [max 1x]. (count(hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='21' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='22' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='23' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='31' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='32' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='4' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or @nullFlavor='NI'])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900876-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-202357-821573-709675-759840-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='EindeZw' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:code[(@code='EindeZw' and @codeSystem='2.16.840.1.113883.2.4.4.13')]"
                 priority="1293"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='EindeZw' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>(WijzeEindeZwangerschap): de elementwaarde MOET zijn code 'EindeZw' codeSystem '2.16.840.1.113883.2.4.4.13'. (@nullFlavor or (@code='EindeZw' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900876-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-349962-401983-316423-717586-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='EindeZw' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='21' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='22' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='23' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='31' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='32' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='4' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or @nullFlavor='NI']"
                 priority="1292"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="validCodeOrCodeSystemFound"
                    select="concat(exists(document('include/voc-2.16.840.1.113883.2.4.11.171-2013-03-20T000000.xml')/*/valueSet[conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-2.16.840.1.113883.2.4.11.171-2013-03-20T000000.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>
      <xsl:variable name="explicitExceptions" select="''"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or contains($validCodeOrCodeSystemFound,'true')"/>
         <xsl:otherwise>
            <xsl:message>(WijzeEindeZwangerschap): de waarde van @code MOET worden gekozen uit waardenlijst WijzeEindeZwangerschap (2013-03-20T00:00:00). NB: codeSystemVersion MOET exact overeenkomen indien gespecificeerd in de waardenlijst. (@nullFlavor or contains($validCodeOrCodeSystemFound,'true') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900876-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|'))"/>
         <xsl:otherwise>
            <xsl:message>(WijzeEindeZwangerschap): de nulwaarde voor @code MOET komen uit de set die is gedefinieerd voor dit attribuut of zijn gekoppeld aan waardenlijst WijzeEindeZwangerschap (2013-03-20T00:00:00). (not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|')) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900876-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-644922-308823-757752-663944-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='412726003' and @codeSystem='2.16.840.1.113883.6.96')]]]"
                 priority="1291"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(Obstetrischeanamnesevoorgaandezwangerschap): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900725-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@contextConductionInd)='true'"/>
         <xsl:otherwise>
            <xsl:message>(Obstetrischeanamnesevoorgaandezwangerschap): de waarde van @contextConductionInd MOET 'true' zijn. (string(@contextConductionInd)='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900725-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-655322-324388-909903-294830-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='412726003' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation"
                 priority="1290"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(Zwangerschapsduur_3): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900200-2012-08-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(Zwangerschapsduur_3): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900200-2012-08-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='412726003' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='412726003' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Zwangerschapsduur_3): element hl7:code[(@code='412726003' and @codeSystem='2.16.840.1.113883.6.96')] is mandatory [min 1x]. (count(hl7:code[(@code='412726003' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='412726003' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900200-2012-08-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='412726003' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Zwangerschapsduur_3): element hl7:code[(@code='412726003' and @codeSystem='2.16.840.1.113883.6.96')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='412726003' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900200-2012-08-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(Zwangerschapsduur_3): element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900200-2012-08-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Zwangerschapsduur_3): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900200-2012-08-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-828235-795566-673944-205037-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='412726003' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:code[(@code='412726003' and @codeSystem='2.16.840.1.113883.6.96')]"
                 priority="1289"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='412726003' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>(Zwangerschapsduur_3): de elementwaarde MOET zijn code '412726003' codeSystem '2.16.840.1.113883.6.96'. (@nullFlavor or (@code='412726003' and @codeSystem='2.16.840.1.113883.6.96') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900200-2012-08-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-128775-326010-940532-323217-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='412726003' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:value"
                 priority="1288"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (@unit='d' and number($theValue)&gt;=0))"/>
         <xsl:otherwise>
            <xsl:message>(Zwangerschapsduur_3): value MOET eenheid 'd' gebruiken en in bereik [0..] liggen   ((@nullFlavor or (@unit='d' and number($theValue)&gt;=0)) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900200-2012-08-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-388668-717099-935420-877235-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:procedure/hl7:code/@code='236973005']"
                 priority="1287"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(Obstetrischeanamnesevoorgaandezwangerschap): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900725-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@contextConductionInd)='true'"/>
         <xsl:otherwise>
            <xsl:message>(Obstetrischeanamnesevoorgaandezwangerschap): de waarde van @contextConductionInd MOET 'true' zijn. (string(@contextConductionInd)='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900725-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="../hl7:component/hl7:observation[hl7:code/@code='EindeZw']/hl7:value/@code='1' or not(exists(../hl7:component/hl7:observation[hl7:code/@code='EindeZw'])) or ../hl7:component/hl7:observation[hl7:code/@code='EindeZw']/hl7:value/@nullFlavor"/>
         <xsl:otherwise>
            <xsl:message>(Obstetrischeanamnesevoorgaandezwangerschap): Eerdere bevalling is alleen van toepassing wanneer wijze einde zwangerschap = partus. (../hl7:component/hl7:observation[hl7:code/@code='EindeZw']/hl7:value/@code='1' or not(exists(../hl7:component/hl7:observation[hl7:code/@code='EindeZw'])) or ../hl7:component/hl7:observation[hl7:code/@code='EindeZw']/hl7:value/@nullFlavor / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900725-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-295979-136279-892115-949422-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:procedure/hl7:code/@code='236973005']/hl7:procedure[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]"
                 priority="1286"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='PROC'"/>
         <xsl:otherwise>
            <xsl:message>(Obstetrischeanamnesevoorgaandezwangerschap): de waarde van @classCode MOET 'PROC' zijn. (string(@classCode)='PROC' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900725-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(Obstetrischeanamnesevoorgaandezwangerschap): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900725-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(Obstetrischeanamnesevoorgaandezwangerschap): element hl7:id is required [min 1x]. (count(hl7:id)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900725-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Obstetrischeanamnesevoorgaandezwangerschap): element hl7:id komt te vaak voor [max 1x]. (count(hl7:id)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900725-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Obstetrischeanamnesevoorgaandezwangerschap): element hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')] is mandatory [min 1x]. (count(hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900725-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Obstetrischeanamnesevoorgaandezwangerschap): element hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900725-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship[hl7:observation[hl7:code[(@code='364332008' and @codeSystem='2.16.840.1.113883.6.96')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Obstetrischeanamnesevoorgaandezwangerschap): element hl7:inboundRelationship[hl7:observation[hl7:code[(@code='364332008' and @codeSystem='2.16.840.1.113883.6.96')]]] komt te vaak voor [max 1x]. (count(hl7:inboundRelationship[hl7:observation[hl7:code[(@code='364332008' and @codeSystem='2.16.840.1.113883.6.96')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900725-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship[hl7:observation[hl7:code[(@code='169821004' and @codeSystem='2.16.840.1.113883.6.96')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Obstetrischeanamnesevoorgaandezwangerschap): element hl7:inboundRelationship[hl7:observation[hl7:code[(@code='169821004' and @codeSystem='2.16.840.1.113883.6.96')]]] komt te vaak voor [max 1x]. (count(hl7:inboundRelationship[hl7:observation[hl7:code[(@code='169821004' and @codeSystem='2.16.840.1.113883.6.96')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900725-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship[hl7:observation[hl7:code[(@code='169822006' and @codeSystem='2.16.840.1.113883.6.96')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Obstetrischeanamnesevoorgaandezwangerschap): element hl7:inboundRelationship[hl7:observation[hl7:code[(@code='169822006' and @codeSystem='2.16.840.1.113883.6.96')]]] komt te vaak voor [max 1x]. (count(hl7:inboundRelationship[hl7:observation[hl7:code[(@code='169822006' and @codeSystem='2.16.840.1.113883.6.96')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900725-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship[hl7:observation[hl7:code[(@code='PRN5704' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Obstetrischeanamnesevoorgaandezwangerschap): element hl7:inboundRelationship[hl7:observation[hl7:code[(@code='PRN5704' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')]]] komt te vaak voor [max 1x]. (count(hl7:inboundRelationship[hl7:observation[hl7:code[(@code='PRN5704' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900725-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-468420-798592-591914-259361-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:procedure/hl7:code/@code='236973005']/hl7:procedure[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:id"
                 priority="1285"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-213808-953166-826629-249698-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:procedure/hl7:code/@code='236973005']/hl7:procedure[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:code"
                 priority="1284"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>(Obstetrischeanamnesevoorgaandezwangerschap): de elementwaarde MOET zijn code '236973005' codeSystem '2.16.840.1.113883.6.96'. (@nullFlavor or (@code='236973005' and @codeSystem='2.16.840.1.113883.6.96') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900725-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-112685-958988-774928-636355-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:procedure/hl7:code/@code='236973005']/hl7:procedure[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='364332008' and @codeSystem='2.16.840.1.113883.6.96')]]]"
                 priority="1283"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(Obstetrischeanamnesevoorgaandezwangerschap): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900725-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-839345-569103-491818-588010-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:procedure/hl7:code/@code='236973005']/hl7:procedure[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='364332008' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation"
                 priority="1282"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(HoeveelheidBloedverlies_2): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900900-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(HoeveelheidBloedverlies_2): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900900-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='364332008' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='364332008' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(HoeveelheidBloedverlies_2): element hl7:code[(@code='364332008' and @codeSystem='2.16.840.1.113883.6.96')] is mandatory [min 1x]. (count(hl7:code[(@code='364332008' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='364332008' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900900-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='364332008' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HoeveelheidBloedverlies_2): element hl7:code[(@code='364332008' and @codeSystem='2.16.840.1.113883.6.96')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='364332008' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900900-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(HoeveelheidBloedverlies_2): element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900900-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HoeveelheidBloedverlies_2): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900900-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-385549-185529-211408-788217-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:procedure/hl7:code/@code='236973005']/hl7:procedure[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='364332008' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:code[(@code='364332008' and @codeSystem='2.16.840.1.113883.6.96')]"
                 priority="1281"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='364332008' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>(HoeveelheidBloedverlies_2): de elementwaarde MOET zijn code '364332008' codeSystem '2.16.840.1.113883.6.96'. (@nullFlavor or (@code='364332008' and @codeSystem='2.16.840.1.113883.6.96') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900900-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-309182-785248-931597-344735-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:procedure/hl7:code/@code='236973005']/hl7:procedure[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='364332008' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:value"
                 priority="1280"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (@unit='ml' and number($theValue)&gt;=0))"/>
         <xsl:otherwise>
            <xsl:message>(HoeveelheidBloedverlies_2): value MOET eenheid 'ml' gebruiken en in bereik [0..] liggen   ((@nullFlavor or (@unit='ml' and number($theValue)&gt;=0)) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900900-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-610883-279682-240008-990655-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:procedure/hl7:code/@code='236973005']/hl7:procedure[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='169821004' and @codeSystem='2.16.840.1.113883.6.96')]]]"
                 priority="1279"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(Obstetrischeanamnesevoorgaandezwangerschap): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900725-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-527353-281992-354969-508669-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:procedure/hl7:code/@code='236973005']/hl7:procedure[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='169821004' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation"
                 priority="1278"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(Ontsluitingsduur): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900898-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(Ontsluitingsduur): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900898-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='169821004' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='169821004' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Ontsluitingsduur): element hl7:code[(@code='169821004' and @codeSystem='2.16.840.1.113883.6.96')] is mandatory [min 1x]. (count(hl7:code[(@code='169821004' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='169821004' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900898-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='169821004' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Ontsluitingsduur): element hl7:code[(@code='169821004' and @codeSystem='2.16.840.1.113883.6.96')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='169821004' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900898-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(Ontsluitingsduur): element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900898-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Ontsluitingsduur): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900898-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-361946-404599-913128-894385-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:procedure/hl7:code/@code='236973005']/hl7:procedure[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='169821004' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:code[(@code='169821004' and @codeSystem='2.16.840.1.113883.6.96')]"
                 priority="1277"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='169821004' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>(Ontsluitingsduur): de elementwaarde MOET zijn code '169821004' codeSystem '2.16.840.1.113883.6.96'. (@nullFlavor or (@code='169821004' and @codeSystem='2.16.840.1.113883.6.96') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900898-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-163024-626435-684846-489716-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:procedure/hl7:code/@code='236973005']/hl7:procedure[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='169821004' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:value"
                 priority="1276"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (@unit='h' and number($theValue)&gt;=0))"/>
         <xsl:otherwise>
            <xsl:message>(Ontsluitingsduur): value MOET eenheid 'h' gebruiken en in bereik [0..] liggen   ((@nullFlavor or (@unit='h' and number($theValue)&gt;=0)) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900898-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-978486-165951-194662-353271-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:procedure/hl7:code/@code='236973005']/hl7:procedure[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='169822006' and @codeSystem='2.16.840.1.113883.6.96')]]]"
                 priority="1275"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(Obstetrischeanamnesevoorgaandezwangerschap): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900725-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-524270-732539-831622-899809-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:procedure/hl7:code/@code='236973005']/hl7:procedure[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='169822006' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation"
                 priority="1274"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(Uitdrijvingsduur): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900899-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(Uitdrijvingsduur): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900899-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='169822006' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='169822006' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Uitdrijvingsduur): element hl7:code[(@code='169822006' and @codeSystem='2.16.840.1.113883.6.96')] is mandatory [min 1x]. (count(hl7:code[(@code='169822006' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='169822006' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900899-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='169822006' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Uitdrijvingsduur): element hl7:code[(@code='169822006' and @codeSystem='2.16.840.1.113883.6.96')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='169822006' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900899-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(Uitdrijvingsduur): element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900899-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Uitdrijvingsduur): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900899-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-904813-668555-114560-916798-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:procedure/hl7:code/@code='236973005']/hl7:procedure[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='169822006' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:code[(@code='169822006' and @codeSystem='2.16.840.1.113883.6.96')]"
                 priority="1273"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='169822006' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>(Uitdrijvingsduur): de elementwaarde MOET zijn code '169822006' codeSystem '2.16.840.1.113883.6.96'. (@nullFlavor or (@code='169822006' and @codeSystem='2.16.840.1.113883.6.96') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900899-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-275841-784564-993527-948578-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:procedure/hl7:code/@code='236973005']/hl7:procedure[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='169822006' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:value"
                 priority="1272"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (@unit='min' and number($theValue)&gt;=0))"/>
         <xsl:otherwise>
            <xsl:message>(Uitdrijvingsduur): value MOET eenheid 'min' gebruiken en in bereik [0..] liggen   ((@nullFlavor or (@unit='min' and number($theValue)&gt;=0)) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900899-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-269420-150671-748393-331517-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:procedure/hl7:code/@code='236973005']/hl7:procedure[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='PRN5704' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')]]]"
                 priority="1271"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(Obstetrischeanamnesevoorgaandezwangerschap): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900725-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-369137-898944-560765-157247-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:procedure/hl7:code/@code='236973005']/hl7:procedure[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='PRN5704' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')]]]/hl7:observation"
                 priority="1270"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(Conditieperineumpostpartum): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900262-2013-04-23T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(Conditieperineumpostpartum): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900262-2013-04-23T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='PRN5704' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')])&gt;=1 and not(hl7:code[(@code='PRN5704' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Conditieperineumpostpartum): element hl7:code[(@code='PRN5704' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')] is mandatory [min 1x]. (count(hl7:code[(@code='PRN5704' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')])&gt;=1 and not(hl7:code[(@code='PRN5704' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900262-2013-04-23T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='PRN5704' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Conditieperineumpostpartum): element hl7:code[(@code='PRN5704' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='PRN5704' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900262-2013-04-23T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value[(@code='A' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='B' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='C' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='D' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='E' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='F' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI'])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(Conditieperineumpostpartum): element hl7:value[(@code='A' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='B' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='C' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='D' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='E' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='F' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI'] is required [min 1x]. (count(hl7:value[(@code='A' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='B' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='C' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='D' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='E' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='F' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI'])&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900262-2013-04-23T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value[(@code='A' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='B' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='C' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='D' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='E' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='F' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Conditieperineumpostpartum): element hl7:value[(@code='A' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='B' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='C' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='D' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='E' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='F' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI'] komt te vaak voor [max 1x]. (count(hl7:value[(@code='A' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='B' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='C' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='D' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='E' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='F' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI'])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900262-2013-04-23T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-955415-290831-517788-935673-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:procedure/hl7:code/@code='236973005']/hl7:procedure[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='PRN5704' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')]]]/hl7:observation/hl7:code[(@code='PRN5704' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')]"
                 priority="1269"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='PRN5704' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')"/>
         <xsl:otherwise>
            <xsl:message>(Conditieperineumpostpartum): de elementwaarde MOET zijn code 'PRN5704' codeSystem '2.16.840.1.113883.2.4.3.22.1.1'. (@nullFlavor or (@code='PRN5704' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900262-2013-04-23T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-940542-746362-161537-651101-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:procedure/hl7:code/@code='236973005']/hl7:procedure[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='PRN5704' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')]]]/hl7:observation/hl7:value[(@code='A' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='B' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='C' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='D' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='E' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='F' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI']"
                 priority="1268"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="validCodeOrCodeSystemFound"
                    select="concat(exists(document('include/voc-2.16.840.1.113883.2.4.11.27-2013-04-23T000000.xml')/*/valueSet[conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-2.16.840.1.113883.2.4.11.27-2013-04-23T000000.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>
      <xsl:variable name="explicitExceptions" select="''"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or contains($validCodeOrCodeSystemFound,'true')"/>
         <xsl:otherwise>
            <xsl:message>(Conditieperineumpostpartum): de waarde van @code MOET worden gekozen uit waardenlijst ConditiePerineum (2013-04-23T00:00:00). NB: codeSystemVersion MOET exact overeenkomen indien gespecificeerd in de waardenlijst. (@nullFlavor or contains($validCodeOrCodeSystemFound,'true') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900262-2013-04-23T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|'))"/>
         <xsl:otherwise>
            <xsl:message>(Conditieperineumpostpartum): de nulwaarde voor @code MOET komen uit de set die is gedefinieerd voor dit attribuut of zijn gekoppeld aan waardenlijst ConditiePerineum (2013-04-23T00:00:00). (not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|')) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900262-2013-04-23T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-838678-927202-779862-321348-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:procedure/hl7:code/@code='236973005']/hl7:procedure[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:inboundRelationship[hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]]"
                 priority="1267"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(Obstetrischeanamnesevoorgaandezwangerschap): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900725-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-217345-574692-878567-203087-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:procedure/hl7:code/@code='236973005']/hl7:procedure[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:inboundRelationship[hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]]/hl7:procedure"
                 priority="1266"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='PROC'"/>
         <xsl:otherwise>
            <xsl:message>(VorigeUitkomstperkind): de waarde van @classCode MOET 'PROC' zijn. (string(@classCode)='PROC' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900901-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(VorigeUitkomstperkind): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900901-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(VorigeUitkomstperkind): element hl7:id is required [min 1x]. (count(hl7:id)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900901-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(VorigeUitkomstperkind): element hl7:id komt te vaak voor [max 1x]. (count(hl7:id)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900901-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')])&gt;=1 and not(hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(VorigeUitkomstperkind): element hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')] is mandatory [min 1x]. (count(hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')])&gt;=1 and not(hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900901-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(VorigeUitkomstperkind): element hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900901-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship[hl7:observation[hl7:code[(@code='289258004' and @codeSystem='2.16.840.1.113883.6.96')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(VorigeUitkomstperkind): element hl7:inboundRelationship[hl7:observation[hl7:code[(@code='289258004' and @codeSystem='2.16.840.1.113883.6.96')]]] komt te vaak voor [max 1x]. (count(hl7:inboundRelationship[hl7:observation[hl7:code[(@code='289258004' and @codeSystem='2.16.840.1.113883.6.96')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900901-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship[hl7:observation[hl7:code[(@code='8339-4' and @codeSystem='2.16.840.1.113883.6.1')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(VorigeUitkomstperkind): element hl7:inboundRelationship[hl7:observation[hl7:code[(@code='8339-4' and @codeSystem='2.16.840.1.113883.6.1')]]] komt te vaak voor [max 1x]. (count(hl7:inboundRelationship[hl7:observation[hl7:code[(@code='8339-4' and @codeSystem='2.16.840.1.113883.6.1')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900901-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship[hl7:observation[hl7:code[(@code='301334000' and @codeSystem='2.16.840.1.113883.6.96')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(VorigeUitkomstperkind): element hl7:inboundRelationship[hl7:observation[hl7:code[(@code='301334000' and @codeSystem='2.16.840.1.113883.6.96')]]] komt te vaak voor [max 1x]. (count(hl7:inboundRelationship[hl7:observation[hl7:code[(@code='301334000' and @codeSystem='2.16.840.1.113883.6.96')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900901-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship[hl7:observation[hl7:code[(@code='9274-2' and @codeSystem='2.16.840.1.113883.6.1')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(VorigeUitkomstperkind): element hl7:inboundRelationship[hl7:observation[hl7:code[(@code='9274-2' and @codeSystem='2.16.840.1.113883.6.1')]]] komt te vaak voor [max 1x]. (count(hl7:inboundRelationship[hl7:observation[hl7:code[(@code='9274-2' and @codeSystem='2.16.840.1.113883.6.1')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900901-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship[hl7:procedure[hl7:code[(@code='SectioCae' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(VorigeUitkomstperkind): element hl7:inboundRelationship[hl7:procedure[hl7:code[(@code='SectioCae' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]] komt te vaak voor [max 1x]. (count(hl7:inboundRelationship[hl7:procedure[hl7:code[(@code='SectioCae' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900901-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-142149-189067-846004-887350-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:procedure/hl7:code/@code='236973005']/hl7:procedure[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:inboundRelationship[hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]]/hl7:procedure/hl7:id"
                 priority="1265"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-539218-820450-456951-311751-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:procedure/hl7:code/@code='236973005']/hl7:procedure[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:inboundRelationship[hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]]/hl7:procedure/hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]"
                 priority="1264"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')"/>
         <xsl:otherwise>
            <xsl:message>(VorigeUitkomstperkind): de elementwaarde MOET zijn code 'Baring' codeSystem '2.16.840.1.113883.2.4.3.22.1.3'. (@nullFlavor or (@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900901-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-409974-785064-628641-736344-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:procedure/hl7:code/@code='236973005']/hl7:procedure[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:inboundRelationship[hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]]/hl7:procedure/hl7:subject[hl7:personalRelationship[hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')]]]"
                 priority="1263"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='SBJ'"/>
         <xsl:otherwise>
            <xsl:message>(VorigeUitkomstperkind): de waarde van @typeCode MOET 'SBJ' zijn. (string(@typeCode)='SBJ' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900901-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:personalRelationship[hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')]])&gt;=1 and not(hl7:personalRelationship[hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')]]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(VorigeUitkomstperkind): element hl7:personalRelationship[hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')]] is mandatory [min 1x]. (count(hl7:personalRelationship[hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')]])&gt;=1 and not(hl7:personalRelationship[hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')]]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900901-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:personalRelationship[hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(VorigeUitkomstperkind): element hl7:personalRelationship[hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')]] komt te vaak voor [max 1x]. (count(hl7:personalRelationship[hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900901-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-114259-436435-397576-889372-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:procedure/hl7:code/@code='236973005']/hl7:procedure[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:inboundRelationship[hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]]/hl7:procedure/hl7:subject[hl7:personalRelationship[hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')]]]/hl7:personalRelationship"
                 priority="1262"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='PRS'"/>
         <xsl:otherwise>
            <xsl:message>(VorigeUitkomstperkind): de waarde van @classCode MOET 'PRS' zijn. (string(@classCode)='PRS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900901-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')])&gt;=1 and not(hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(VorigeUitkomstperkind): element hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')] is mandatory [min 1x]. (count(hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')])&gt;=1 and not(hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900901-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(VorigeUitkomstperkind): element hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900901-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:relationshipHolder)&gt;=1 and not(hl7:relationshipHolder/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(VorigeUitkomstperkind): element hl7:relationshipHolder is mandatory [min 1x]. (count(hl7:relationshipHolder)&gt;=1 and not(hl7:relationshipHolder/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900901-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:relationshipHolder)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(VorigeUitkomstperkind): element hl7:relationshipHolder komt te vaak voor [max 1x]. (count(hl7:relationshipHolder)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900901-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-521665-731067-378746-302637-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:procedure/hl7:code/@code='236973005']/hl7:procedure[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:inboundRelationship[hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]]/hl7:procedure/hl7:subject[hl7:personalRelationship[hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')]]]/hl7:personalRelationship/hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')]"
                 priority="1261"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <xsl:message>(VorigeUitkomstperkind): de elementwaarde MOET zijn code 'CHILD' codeSystem '2.16.840.1.113883.5.111'. (@nullFlavor or (@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900901-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-279627-927293-309512-249258-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:procedure/hl7:code/@code='236973005']/hl7:procedure[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:inboundRelationship[hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]]/hl7:procedure/hl7:subject[hl7:personalRelationship[hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')]]]/hl7:personalRelationship/hl7:relationshipHolder"
                 priority="1260"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='PSN'"/>
         <xsl:otherwise>
            <xsl:message>(VorigeUitkomstperkind): de waarde van @classCode MOET 'PSN' zijn. (string(@classCode)='PSN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900901-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@determinerCode)='INSTANCE'"/>
         <xsl:otherwise>
            <xsl:message>(VorigeUitkomstperkind): de waarde van @determinerCode MOET 'INSTANCE' zijn. (string(@determinerCode)='INSTANCE' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900901-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-909940-395884-168201-756585-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:procedure/hl7:code/@code='236973005']/hl7:procedure[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:inboundRelationship[hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='289258004' and @codeSystem='2.16.840.1.113883.6.96')]]]"
                 priority="1259"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(VorigeUitkomstperkind): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900901-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-901652-182647-138214-432093-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:procedure/hl7:code/@code='236973005']/hl7:procedure[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:inboundRelationship[hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='289258004' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation"
                 priority="1258"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(TypePartus): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900861-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(TypePartus): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900861-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='289258004' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='289258004' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TypePartus): element hl7:code[(@code='289258004' and @codeSystem='2.16.840.1.113883.6.96')] is mandatory [min 1x]. (count(hl7:code[(@code='289258004' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='289258004' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900861-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='289258004' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TypePartus): element hl7:code[(@code='289258004' and @codeSystem='2.16.840.1.113883.6.96')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='289258004' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900861-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value[(@code='48782003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='KuVerlng' and @codeSystem='2.16.840.1.113883.2.4.4.13') or (@code='200130005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='267278005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='271370008' and @codeSystem='2.16.840.1.113883.6.96') or (@code='200146002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='200148001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='200149009' and @codeSystem='2.16.840.1.113883.6.96') or (@code='39406005' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='NI'])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(TypePartus): element hl7:value[(@code='48782003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='KuVerlng' and @codeSystem='2.16.840.1.113883.2.4.4.13') or (@code='200130005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='267278005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='271370008' and @codeSystem='2.16.840.1.113883.6.96') or (@code='200146002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='200148001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='200149009' and @codeSystem='2.16.840.1.113883.6.96') or (@code='39406005' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='NI'] is required [min 1x]. (count(hl7:value[(@code='48782003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='KuVerlng' and @codeSystem='2.16.840.1.113883.2.4.4.13') or (@code='200130005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='267278005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='271370008' and @codeSystem='2.16.840.1.113883.6.96') or (@code='200146002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='200148001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='200149009' and @codeSystem='2.16.840.1.113883.6.96') or (@code='39406005' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='NI'])&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900861-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value[(@code='48782003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='KuVerlng' and @codeSystem='2.16.840.1.113883.2.4.4.13') or (@code='200130005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='267278005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='271370008' and @codeSystem='2.16.840.1.113883.6.96') or (@code='200146002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='200148001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='200149009' and @codeSystem='2.16.840.1.113883.6.96') or (@code='39406005' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='NI'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TypePartus): element hl7:value[(@code='48782003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='KuVerlng' and @codeSystem='2.16.840.1.113883.2.4.4.13') or (@code='200130005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='267278005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='271370008' and @codeSystem='2.16.840.1.113883.6.96') or (@code='200146002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='200148001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='200149009' and @codeSystem='2.16.840.1.113883.6.96') or (@code='39406005' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='NI'] komt te vaak voor [max 1x]. (count(hl7:value[(@code='48782003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='KuVerlng' and @codeSystem='2.16.840.1.113883.2.4.4.13') or (@code='200130005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='267278005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='271370008' and @codeSystem='2.16.840.1.113883.6.96') or (@code='200146002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='200148001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='200149009' and @codeSystem='2.16.840.1.113883.6.96') or (@code='39406005' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='NI'])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900861-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-404453-276929-137800-279572-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:procedure/hl7:code/@code='236973005']/hl7:procedure[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:inboundRelationship[hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='289258004' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:code[(@code='289258004' and @codeSystem='2.16.840.1.113883.6.96')]"
                 priority="1257"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='289258004' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>(TypePartus): de elementwaarde MOET zijn code '289258004' codeSystem '2.16.840.1.113883.6.96'. (@nullFlavor or (@code='289258004' and @codeSystem='2.16.840.1.113883.6.96') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900861-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-786657-985062-991436-954107-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:procedure/hl7:code/@code='236973005']/hl7:procedure[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:inboundRelationship[hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='289258004' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:value[(@code='48782003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='KuVerlng' and @codeSystem='2.16.840.1.113883.2.4.4.13') or (@code='200130005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='267278005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='271370008' and @codeSystem='2.16.840.1.113883.6.96') or (@code='200146002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='200148001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='200149009' and @codeSystem='2.16.840.1.113883.6.96') or (@code='39406005' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='NI']"
                 priority="1256"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="validCodeOrCodeSystemFound"
                    select="concat(exists(document('include/voc-2.16.840.1.113883.2.4.11.170-DYNAMIC.xml')/*/valueSet[conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-2.16.840.1.113883.2.4.11.170-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>
      <xsl:variable name="explicitExceptions" select="''"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or contains($validCodeOrCodeSystemFound,'true')"/>
         <xsl:otherwise>
            <xsl:message>(TypePartus): de waarde van @code MOET worden gekozen uit waardenlijst TypePartus (DYNAMISCH). NB: codeSystemVersion MOET exact overeenkomen indien gespecificeerd in de waardenlijst. (@nullFlavor or contains($validCodeOrCodeSystemFound,'true') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900861-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|'))"/>
         <xsl:otherwise>
            <xsl:message>(TypePartus): de nulwaarde voor @code MOET komen uit de set die is gedefinieerd voor dit attribuut of zijn gekoppeld aan waardenlijst TypePartus (DYNAMISCH). (not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|')) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900861-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-509143-500259-670346-259383-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:procedure/hl7:code/@code='236973005']/hl7:procedure[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:inboundRelationship[hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='8339-4' and @codeSystem='2.16.840.1.113883.6.1')]]]"
                 priority="1255"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(VorigeUitkomstperkind): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900901-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-160742-400401-400622-568878-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:procedure/hl7:code/@code='236973005']/hl7:procedure[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:inboundRelationship[hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='8339-4' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation"
                 priority="1254"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(Geboortegewicht): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900425-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(Geboortegewicht): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900425-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='8339-4' and @codeSystem='2.16.840.1.113883.6.1')])&gt;=1 and not(hl7:code[(@code='8339-4' and @codeSystem='2.16.840.1.113883.6.1')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Geboortegewicht): element hl7:code[(@code='8339-4' and @codeSystem='2.16.840.1.113883.6.1')] is mandatory [min 1x]. (count(hl7:code[(@code='8339-4' and @codeSystem='2.16.840.1.113883.6.1')])&gt;=1 and not(hl7:code[(@code='8339-4' and @codeSystem='2.16.840.1.113883.6.1')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900425-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='8339-4' and @codeSystem='2.16.840.1.113883.6.1')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Geboortegewicht): element hl7:code[(@code='8339-4' and @codeSystem='2.16.840.1.113883.6.1')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='8339-4' and @codeSystem='2.16.840.1.113883.6.1')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900425-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(Geboortegewicht): element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900425-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Geboortegewicht): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900425-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-341995-659267-281870-203982-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:procedure/hl7:code/@code='236973005']/hl7:procedure[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:inboundRelationship[hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='8339-4' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation/hl7:code[(@code='8339-4' and @codeSystem='2.16.840.1.113883.6.1')]"
                 priority="1253"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='8339-4' and @codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <xsl:message>(Geboortegewicht): de elementwaarde MOET zijn code '8339-4' codeSystem '2.16.840.1.113883.6.1'. (@nullFlavor or (@code='8339-4' and @codeSystem='2.16.840.1.113883.6.1') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900425-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-482888-944601-800781-796339-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:procedure/hl7:code/@code='236973005']/hl7:procedure[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:inboundRelationship[hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='8339-4' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation/hl7:value"
                 priority="1252"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (@unit='g' and number($theValue)&gt;=0 and (matches(string($theValue), '^[-+]?[0-9]*$'))))"/>
         <xsl:otherwise>
            <xsl:message>(Geboortegewicht): value MOET eenheid 'g' gebruiken en in bereik [0..] liggen  en tot op minstens 0 decimalen nauwkeurig zijn  ((@nullFlavor or (@unit='g' and number($theValue)&gt;=0 and (matches(string($theValue), '^[-+]?[0-9]*$')))) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900425-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-698736-969705-862961-988075-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:procedure/hl7:code/@code='236973005']/hl7:procedure[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:inboundRelationship[hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='301334000' and @codeSystem='2.16.840.1.113883.6.96')]]]"
                 priority="1251"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(VorigeUitkomstperkind): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900901-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-368531-389601-789787-482149-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:procedure/hl7:code/@code='236973005']/hl7:procedure[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:inboundRelationship[hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='301334000' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation"
                 priority="1250"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(PercentielGeboortegewicht): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900902-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(PercentielGeboortegewicht): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900902-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='301334000' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='301334000' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(PercentielGeboortegewicht): element hl7:code[(@code='301334000' and @codeSystem='2.16.840.1.113883.6.96')] is mandatory [min 1x]. (count(hl7:code[(@code='301334000' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='301334000' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900902-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='301334000' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PercentielGeboortegewicht): element hl7:code[(@code='301334000' and @codeSystem='2.16.840.1.113883.6.96')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='301334000' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900902-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='4' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='6' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or @nullFlavor='NI'])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(PercentielGeboortegewicht): element hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='4' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='6' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or @nullFlavor='NI'] is required [min 1x]. (count(hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='4' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='6' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or @nullFlavor='NI'])&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900902-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='4' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='6' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or @nullFlavor='NI'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PercentielGeboortegewicht): element hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='4' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='6' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or @nullFlavor='NI'] komt te vaak voor [max 1x]. (count(hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='4' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='6' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or @nullFlavor='NI'])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900902-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-617502-502404-222284-825507-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:procedure/hl7:code/@code='236973005']/hl7:procedure[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:inboundRelationship[hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='301334000' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:code[(@code='301334000' and @codeSystem='2.16.840.1.113883.6.96')]"
                 priority="1249"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='301334000' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>(PercentielGeboortegewicht): de elementwaarde MOET zijn code '301334000' codeSystem '2.16.840.1.113883.6.96'. (@nullFlavor or (@code='301334000' and @codeSystem='2.16.840.1.113883.6.96') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900902-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-446249-411863-510868-440565-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:procedure/hl7:code/@code='236973005']/hl7:procedure[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:inboundRelationship[hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='301334000' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='4' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='6' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or @nullFlavor='NI']"
                 priority="1248"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="validCodeOrCodeSystemFound"
                    select="concat(exists(document('include/voc-2.16.840.1.113883.2.4.11.176-2013-11-08T000000.xml')/*/valueSet[conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-2.16.840.1.113883.2.4.11.176-2013-11-08T000000.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>
      <xsl:variable name="explicitExceptions" select="''"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or contains($validCodeOrCodeSystemFound,'true')"/>
         <xsl:otherwise>
            <xsl:message>(PercentielGeboortegewicht): de waarde van @code MOET worden gekozen uit waardenlijst PercentielGeboortegewicht (2013-11-08T00:00:00). NB: codeSystemVersion MOET exact overeenkomen indien gespecificeerd in de waardenlijst. (@nullFlavor or contains($validCodeOrCodeSystemFound,'true') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900902-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|'))"/>
         <xsl:otherwise>
            <xsl:message>(PercentielGeboortegewicht): de nulwaarde voor @code MOET komen uit de set die is gedefinieerd voor dit attribuut of zijn gekoppeld aan waardenlijst PercentielGeboortegewicht (2013-11-08T00:00:00). (not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|')) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900902-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-124433-211368-726623-124383-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:procedure/hl7:code/@code='236973005']/hl7:procedure[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:inboundRelationship[hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='9274-2' and @codeSystem='2.16.840.1.113883.6.1')]]]"
                 priority="1247"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(VorigeUitkomstperkind): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900901-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-841783-393135-734145-913126-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:procedure/hl7:code/@code='236973005']/hl7:procedure[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:inboundRelationship[hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='9274-2' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation"
                 priority="1246"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(Apgarscorena5min): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900294-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(Apgarscorena5min): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900294-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='9274-2' and @codeSystem='2.16.840.1.113883.6.1')])&gt;=1 and not(hl7:code[(@code='9274-2' and @codeSystem='2.16.840.1.113883.6.1')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Apgarscorena5min): element hl7:code[(@code='9274-2' and @codeSystem='2.16.840.1.113883.6.1')] is mandatory [min 1x]. (count(hl7:code[(@code='9274-2' and @codeSystem='2.16.840.1.113883.6.1')])&gt;=1 and not(hl7:code[(@code='9274-2' and @codeSystem='2.16.840.1.113883.6.1')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900294-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='9274-2' and @codeSystem='2.16.840.1.113883.6.1')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Apgarscorena5min): element hl7:code[(@code='9274-2' and @codeSystem='2.16.840.1.113883.6.1')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='9274-2' and @codeSystem='2.16.840.1.113883.6.1')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900294-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(Apgarscorena5min): element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900294-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Apgarscorena5min): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900294-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-747158-803896-717600-856596-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:procedure/hl7:code/@code='236973005']/hl7:procedure[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:inboundRelationship[hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='9274-2' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation/hl7:code[(@code='9274-2' and @codeSystem='2.16.840.1.113883.6.1')]"
                 priority="1245"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='9274-2' and @codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <xsl:message>(Apgarscorena5min): de elementwaarde MOET zijn code '9274-2' codeSystem '2.16.840.1.113883.6.1'. (@nullFlavor or (@code='9274-2' and @codeSystem='2.16.840.1.113883.6.1') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900294-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-403135-412667-533404-791151-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:procedure/hl7:code/@code='236973005']/hl7:procedure[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:inboundRelationship[hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='9274-2' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation/hl7:value"
                 priority="1244"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (number($theValue)&gt;=0 and number($theValue)&lt;=10))"/>
         <xsl:otherwise>
            <xsl:message>(Apgarscorena5min): value MOET in bereik [0..10] liggen   ((@nullFlavor or (number($theValue)&gt;=0 and number($theValue)&lt;=10)) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900294-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-660086-235464-882637-917867-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:procedure/hl7:code/@code='236973005']/hl7:procedure[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:inboundRelationship[hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]]/hl7:procedure/hl7:inboundRelationship[hl7:procedure[hl7:code[(@code='KuVerl' and @codeSystem='2.16.840.1.113883.2.4.4.14')]]]"
                 priority="1243"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(VorigeUitkomstperkind): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900901-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-524321-365907-604943-645296-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:procedure/hl7:code/@code='236973005']/hl7:procedure[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:inboundRelationship[hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]]/hl7:procedure/hl7:inboundRelationship[hl7:procedure[hl7:code[(@code='KuVerl' and @codeSystem='2.16.840.1.113883.2.4.4.14')]]]/hl7:procedure"
                 priority="1242"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='PROC'"/>
         <xsl:otherwise>
            <xsl:message>(VaginalekunstverlossingProc): de waarde van @classCode MOET 'PROC' zijn. (string(@classCode)='PROC' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900903-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(VaginalekunstverlossingProc): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900903-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@nullFlavor)='NI' or not(@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(VaginalekunstverlossingProc): de waarde van @nullFlavor MOET 'NI' zijn. (string(@nullFlavor)='NI' or not(@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900903-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="../hl7:procedure/@negationInd or ../hl7:procedure/@nullFlavor"/>
         <xsl:otherwise>
            <xsl:message>(VaginalekunstverlossingProc): Vaginalekunstverlossing shall have a negationInd (true or false) unless null (../hl7:procedure/@negationInd or ../hl7:procedure/@nullFlavor / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900903-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(VaginalekunstverlossingProc): element hl7:id is required [min 1x]. (count(hl7:id)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900903-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(VaginalekunstverlossingProc): element hl7:id komt te vaak voor [max 1x]. (count(hl7:id)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900903-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='KuVerl' and @codeSystem='2.16.840.1.113883.2.4.4.14')])&gt;=1 and not(hl7:code[(@code='KuVerl' and @codeSystem='2.16.840.1.113883.2.4.4.14')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(VaginalekunstverlossingProc): element hl7:code[(@code='KuVerl' and @codeSystem='2.16.840.1.113883.2.4.4.14')] is mandatory [min 1x]. (count(hl7:code[(@code='KuVerl' and @codeSystem='2.16.840.1.113883.2.4.4.14')])&gt;=1 and not(hl7:code[(@code='KuVerl' and @codeSystem='2.16.840.1.113883.2.4.4.14')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900903-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='KuVerl' and @codeSystem='2.16.840.1.113883.2.4.4.14')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(VaginalekunstverlossingProc): element hl7:code[(@code='KuVerl' and @codeSystem='2.16.840.1.113883.2.4.4.14')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='KuVerl' and @codeSystem='2.16.840.1.113883.2.4.4.14')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900903-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:methodCode)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(VaginalekunstverlossingProc): element hl7:methodCode komt te vaak voor [max 1x]. (count(hl7:methodCode)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900903-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-115923-652393-655299-454318-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:procedure/hl7:code/@code='236973005']/hl7:procedure[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:inboundRelationship[hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]]/hl7:procedure/hl7:inboundRelationship[hl7:procedure[hl7:code[(@code='KuVerl' and @codeSystem='2.16.840.1.113883.2.4.4.14')]]]/hl7:procedure/hl7:id"
                 priority="1241"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-731756-579833-659958-269351-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:procedure/hl7:code/@code='236973005']/hl7:procedure[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:inboundRelationship[hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]]/hl7:procedure/hl7:inboundRelationship[hl7:procedure[hl7:code[(@code='KuVerl' and @codeSystem='2.16.840.1.113883.2.4.4.14')]]]/hl7:procedure/hl7:code[(@code='KuVerl' and @codeSystem='2.16.840.1.113883.2.4.4.14')]"
                 priority="1240"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='KuVerl' and @codeSystem='2.16.840.1.113883.2.4.4.14')"/>
         <xsl:otherwise>
            <xsl:message>(VaginalekunstverlossingProc): de elementwaarde MOET zijn code 'KuVerl' codeSystem '2.16.840.1.113883.2.4.4.14'. (@nullFlavor or (@code='KuVerl' and @codeSystem='2.16.840.1.113883.2.4.4.14') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900903-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-424326-466180-649137-762493-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:procedure/hl7:code/@code='236973005']/hl7:procedure[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:inboundRelationship[hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]]/hl7:procedure/hl7:inboundRelationship[hl7:procedure[hl7:code[(@code='KuVerl' and @codeSystem='2.16.840.1.113883.2.4.4.14')]]]/hl7:procedure/hl7:methodCode"
                 priority="1239"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="validCodeOrCodeSystemFound"
                    select="concat(exists(document('include/voc-2.16.840.1.113883.2.4.11.36-DYNAMIC.xml')/*/valueSet[conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-2.16.840.1.113883.2.4.11.36-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>
      <xsl:variable name="explicitExceptions" select="''"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or contains($validCodeOrCodeSystemFound,'true')"/>
         <xsl:otherwise>
            <xsl:message>(VaginalekunstverlossingProc): de waarde van @code MOET worden gekozen uit waardenlijst VaginaleKunstverlossing (DYNAMISCH). NB: codeSystemVersion MOET exact overeenkomen indien gespecificeerd in de waardenlijst. (@nullFlavor or contains($validCodeOrCodeSystemFound,'true') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900903-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|'))"/>
         <xsl:otherwise>
            <xsl:message>(VaginalekunstverlossingProc): de nulwaarde voor @code MOET komen uit de set die is gedefinieerd voor dit attribuut of zijn gekoppeld aan waardenlijst VaginaleKunstverlossing (DYNAMISCH). (not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|')) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900903-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-589224-646908-296187-241839-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:procedure/hl7:code/@code='236973005']/hl7:procedure[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:inboundRelationship[hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]]/hl7:procedure/hl7:inboundRelationship[hl7:procedure[hl7:code[(@code='SectioCae' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]]"
                 priority="1238"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(VorigeUitkomstperkind): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900901-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-189697-854065-720686-412969-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:procedure/hl7:code/@code='236973005']/hl7:procedure[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:inboundRelationship[hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]]/hl7:procedure/hl7:inboundRelationship[hl7:procedure[hl7:code[(@code='SectioCae' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]]/hl7:procedure"
                 priority="1237"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='PROC'"/>
         <xsl:otherwise>
            <xsl:message>(Beslismomentsectiocaesarea): de waarde van @classCode MOET 'PROC' zijn. (string(@classCode)='PROC' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900278-2012-10-07T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='INT'"/>
         <xsl:otherwise>
            <xsl:message>(Beslismomentsectiocaesarea): de waarde van @moodCode MOET 'INT' zijn. (string(@moodCode)='INT' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900278-2012-10-07T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@nullFlavor)='NI' or string(@nullFlavor)='UNK' or not(@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Beslismomentsectiocaesarea): de waarde van @nullFlavor MOET één van de volgende codes bevatten: NI', 'UNK. (string(@nullFlavor)='NI' or string(@nullFlavor)='UNK' or not(@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900278-2012-10-07T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@negationInd='true' or @nullFlavor or hl7:methodCode"/>
         <xsl:otherwise>
            <xsl:message>(Beslismomentsectiocaesarea): Als er sprake is van een sectio, dan is het beslismoment verplicht. (@negationInd='true' or @nullFlavor or hl7:methodCode / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900278-2012-10-07T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(Beslismomentsectiocaesarea): element hl7:id is required [min 1x]. (count(hl7:id)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900278-2012-10-07T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='SectioCae' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')])&gt;=1 and not(hl7:code[(@code='SectioCae' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Beslismomentsectiocaesarea): element hl7:code[(@code='SectioCae' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')] is mandatory [min 1x]. (count(hl7:code[(@code='SectioCae' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')])&gt;=1 and not(hl7:code[(@code='SectioCae' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900278-2012-10-07T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='SectioCae' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Beslismomentsectiocaesarea): element hl7:code[(@code='SectioCae' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='SectioCae' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900278-2012-10-07T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:methodCode)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Beslismomentsectiocaesarea): element hl7:methodCode komt te vaak voor [max 1x]. (count(hl7:methodCode)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900278-2012-10-07T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-255003-780918-684695-764904-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:procedure/hl7:code/@code='236973005']/hl7:procedure[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:inboundRelationship[hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]]/hl7:procedure/hl7:inboundRelationship[hl7:procedure[hl7:code[(@code='SectioCae' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]]/hl7:procedure/hl7:id"
                 priority="1236"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-343449-465148-292887-570747-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:procedure/hl7:code/@code='236973005']/hl7:procedure[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:inboundRelationship[hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]]/hl7:procedure/hl7:inboundRelationship[hl7:procedure[hl7:code[(@code='SectioCae' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]]/hl7:procedure/hl7:code[(@code='SectioCae' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]"
                 priority="1235"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='SectioCae' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')"/>
         <xsl:otherwise>
            <xsl:message>(Beslismomentsectiocaesarea): de elementwaarde MOET zijn code 'SectioCae' codeSystem '2.16.840.1.113883.2.4.3.22.1.3'. (@nullFlavor or (@code='SectioCae' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900278-2012-10-07T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-157620-136237-810779-934808-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:organizer/hl7:component[hl7:procedure/hl7:code/@code='236973005']/hl7:procedure[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:inboundRelationship[hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]]/hl7:procedure/hl7:inboundRelationship[hl7:procedure[hl7:code[(@code='SectioCae' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]]/hl7:procedure/hl7:methodCode"
                 priority="1234"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="validCodeOrCodeSystemFound"
                    select="concat(exists(document('include/voc-2.16.840.1.113883.2.4.11.38-DYNAMIC.xml')/*/valueSet[conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-2.16.840.1.113883.2.4.11.38-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>
      <xsl:variable name="explicitExceptions" select="''"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or contains($validCodeOrCodeSystemFound,'true')"/>
         <xsl:otherwise>
            <xsl:message>(Beslismomentsectiocaesarea): de waarde van @code MOET worden gekozen uit waardenlijst BesluitSC (DYNAMISCH). NB: codeSystemVersion MOET exact overeenkomen indien gespecificeerd in de waardenlijst. (@nullFlavor or contains($validCodeOrCodeSystemFound,'true') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900278-2012-10-07T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|'))"/>
         <xsl:otherwise>
            <xsl:message>(Beslismomentsectiocaesarea): de nulwaarde voor @code MOET komen uit de set die is gedefinieerd voor dit attribuut of zijn gekoppeld aan waardenlijst BesluitSC (DYNAMISCH). (not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|')) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900278-2012-10-07T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-808706-650934-194970-202457-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='364320009']"
                 priority="1233"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='PERT'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @typeCode MOET 'PERT' zijn. (string(@typeCode)='PERT' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@contextConductionInd)='true'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @contextConductionInd MOET 'true' zijn. (string(@contextConductionInd)='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:organizer[hl7:code[(@code='364320009' and @codeSystem='2.16.840.1.113883.6.96')]])&gt;=1 and not(hl7:organizer[hl7:code[(@code='364320009' and @codeSystem='2.16.840.1.113883.6.96')]]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:organizer[hl7:code[(@code='364320009' and @codeSystem='2.16.840.1.113883.6.96')]] is mandatory [min 1x]. (count(hl7:organizer[hl7:code[(@code='364320009' and @codeSystem='2.16.840.1.113883.6.96')]])&gt;=1 and not(hl7:organizer[hl7:code[(@code='364320009' and @codeSystem='2.16.840.1.113883.6.96')]]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:organizer[hl7:code[(@code='364320009' and @codeSystem='2.16.840.1.113883.6.96')]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:organizer[hl7:code[(@code='364320009' and @codeSystem='2.16.840.1.113883.6.96')]] komt te vaak voor [max 1x]. (count(hl7:organizer[hl7:code[(@code='364320009' and @codeSystem='2.16.840.1.113883.6.96')]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-980748-707644-982816-949424-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='364320009']/hl7:organizer[hl7:code[(@code='364320009' and @codeSystem='2.16.840.1.113883.6.96')]]"
                 priority="1232"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='CONTAINER'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @classCode MOET 'CONTAINER' zijn. (string(@classCode)='CONTAINER' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='364320009' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='364320009' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:code[(@code='364320009' and @codeSystem='2.16.840.1.113883.6.96')] is mandatory [min 1x]. (count(hl7:code[(@code='364320009' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='364320009' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='364320009' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:code[(@code='364320009' and @codeSystem='2.16.840.1.113883.6.96')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='364320009' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:observation[hl7:code[(@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1')]]])&gt;=1 and not(hl7:component[hl7:observation[hl7:code[(@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1')]]]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:component[hl7:observation[hl7:code[(@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1')]]] is mandatory [min 1x]. (count(hl7:component[hl7:observation[hl7:code[(@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1')]]])&gt;=1 and not(hl7:component[hl7:observation[hl7:code[(@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1')]]]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:observation[hl7:code[(@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:component[hl7:observation[hl7:code[(@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1')]]] komt te vaak voor [max 1x]. (count(hl7:component[hl7:observation[hl7:code[(@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:observation[hl7:code[(@code='EindeZw' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:component[hl7:observation[hl7:code[(@code='EindeZw' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]] komt te vaak voor [max 1x]. (count(hl7:component[hl7:observation[hl7:code[(@code='EindeZw' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:observation[hl7:code[(@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:component[hl7:observation[hl7:code[(@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]] is required [min 1x]. (count(hl7:component[hl7:observation[hl7:code[(@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]])&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:observation[hl7:code[(@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:component[hl7:observation[hl7:code[(@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]] komt te vaak voor [max 1x]. (count(hl7:component[hl7:observation[hl7:code[(@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:observation[hl7:code[(@code='Parturit' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:component[hl7:observation[hl7:code[(@code='Parturit' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]] komt te vaak voor [max 1x]. (count(hl7:component[hl7:observation[hl7:code[(@code='Parturit' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:observation[hl7:code[(@code='AantalLevendeKinderen' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:component[hl7:observation[hl7:code[(@code='AantalLevendeKinderen' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]] komt te vaak voor [max 1x]. (count(hl7:component[hl7:observation[hl7:code[(@code='AantalLevendeKinderen' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:observation[hl7:code[(@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:component[hl7:observation[hl7:code[(@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]] is required [min 1x]. (count(hl7:component[hl7:observation[hl7:code[(@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]])&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:observation[hl7:code[(@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:component[hl7:observation[hl7:code[(@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]] komt te vaak voor [max 1x]. (count(hl7:component[hl7:observation[hl7:code[(@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:observation[hl7:code[(@code='Bevalplan' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:component[hl7:observation[hl7:code[(@code='Bevalplan' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]] komt te vaak voor [max 1x]. (count(hl7:component[hl7:observation[hl7:code[(@code='Bevalplan' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-586048-146680-930767-514058-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='364320009']/hl7:organizer[hl7:code[(@code='364320009' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:code"
                 priority="1231"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='364320009' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de elementwaarde MOET zijn code '364320009' codeSystem '2.16.840.1.113883.6.96'. (@nullFlavor or (@code='364320009' and @codeSystem='2.16.840.1.113883.6.96') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-120681-461682-552528-134997-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='364320009']/hl7:organizer[hl7:code[(@code='364320009' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1')]]]"
                 priority="1230"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@contextConductionInd)='true'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @contextConductionInd MOET 'true' zijn. (string(@contextConductionInd)='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-562295-350763-647643-411886-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='364320009']/hl7:organizer[hl7:code[(@code='364320009' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation"
                 priority="1229"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(Identificatievandezwangerschap_3): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900728-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(Identificatievandezwangerschap_3): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900728-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1')])&gt;=1 and not(hl7:code[(@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Identificatievandezwangerschap_3): element hl7:code[(@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1')] is mandatory [min 1x]. (count(hl7:code[(@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1')])&gt;=1 and not(hl7:code[(@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900728-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Identificatievandezwangerschap_3): element hl7:code[(@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900728-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Identificatievandezwangerschap_3): element hl7:value is mandatory [min 1x]. (count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900728-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Identificatievandezwangerschap_3): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900728-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-336198-722311-328468-277205-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='364320009']/hl7:organizer[hl7:code[(@code='364320009' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation/hl7:code[(@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1')]"
                 priority="1228"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <xsl:message>(Identificatievandezwangerschap_3): de elementwaarde MOET zijn code 'X_PREGNBR' codeSystem '2.16.840.1.113883.6.1'. (@nullFlavor or (@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900728-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-912235-570883-666354-740361-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='364320009']/hl7:organizer[hl7:code[(@code='364320009' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation/hl7:value"
                 priority="1227"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-902462-950809-978692-962392-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='364320009']/hl7:organizer[hl7:code[(@code='364320009' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='EindeZw' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]"
                 priority="1226"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@contextConductionInd)='true'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @contextConductionInd MOET 'true' zijn. (string(@contextConductionInd)='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-715531-943145-911113-922920-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='364320009']/hl7:organizer[hl7:code[(@code='364320009' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='EindeZw' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation"
                 priority="1225"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(WijzeEindeZwangerschap): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900876-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(WijzeEindeZwangerschap): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900876-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='EindeZw' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&gt;=1 and not(hl7:code[(@code='EindeZw' and @codeSystem='2.16.840.1.113883.2.4.4.13')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(WijzeEindeZwangerschap): element hl7:code[(@code='EindeZw' and @codeSystem='2.16.840.1.113883.2.4.4.13')] is mandatory [min 1x]. (count(hl7:code[(@code='EindeZw' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&gt;=1 and not(hl7:code[(@code='EindeZw' and @codeSystem='2.16.840.1.113883.2.4.4.13')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900876-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='EindeZw' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(WijzeEindeZwangerschap): element hl7:code[(@code='EindeZw' and @codeSystem='2.16.840.1.113883.2.4.4.13')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='EindeZw' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900876-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='21' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='22' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='23' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='31' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='32' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='4' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or @nullFlavor='NI'])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(WijzeEindeZwangerschap): element hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='21' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='22' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='23' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='31' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='32' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='4' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or @nullFlavor='NI'] is required [min 1x]. (count(hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='21' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='22' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='23' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='31' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='32' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='4' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or @nullFlavor='NI'])&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900876-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='21' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='22' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='23' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='31' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='32' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='4' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or @nullFlavor='NI'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(WijzeEindeZwangerschap): element hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='21' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='22' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='23' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='31' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='32' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='4' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or @nullFlavor='NI'] komt te vaak voor [max 1x]. (count(hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='21' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='22' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='23' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='31' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='32' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='4' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or @nullFlavor='NI'])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900876-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-249139-651958-486714-708040-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='364320009']/hl7:organizer[hl7:code[(@code='364320009' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='EindeZw' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:code[(@code='EindeZw' and @codeSystem='2.16.840.1.113883.2.4.4.13')]"
                 priority="1224"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='EindeZw' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>(WijzeEindeZwangerschap): de elementwaarde MOET zijn code 'EindeZw' codeSystem '2.16.840.1.113883.2.4.4.13'. (@nullFlavor or (@code='EindeZw' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900876-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-198894-708581-391421-494711-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='364320009']/hl7:organizer[hl7:code[(@code='364320009' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='EindeZw' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='21' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='22' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='23' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='31' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='32' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='4' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.4.13.46') or @nullFlavor='NI']"
                 priority="1223"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="validCodeOrCodeSystemFound"
                    select="concat(exists(document('include/voc-2.16.840.1.113883.2.4.11.171-2013-03-20T000000.xml')/*/valueSet[conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-2.16.840.1.113883.2.4.11.171-2013-03-20T000000.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>
      <xsl:variable name="explicitExceptions" select="''"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or contains($validCodeOrCodeSystemFound,'true')"/>
         <xsl:otherwise>
            <xsl:message>(WijzeEindeZwangerschap): de waarde van @code MOET worden gekozen uit waardenlijst WijzeEindeZwangerschap (2013-03-20T00:00:00). NB: codeSystemVersion MOET exact overeenkomen indien gespecificeerd in de waardenlijst. (@nullFlavor or contains($validCodeOrCodeSystemFound,'true') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900876-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|'))"/>
         <xsl:otherwise>
            <xsl:message>(WijzeEindeZwangerschap): de nulwaarde voor @code MOET komen uit de set die is gedefinieerd voor dit attribuut of zijn gekoppeld aan waardenlijst WijzeEindeZwangerschap (2013-03-20T00:00:00). (not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|')) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900876-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-817271-455603-954242-562933-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='364320009']/hl7:organizer[hl7:code[(@code='364320009' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]"
                 priority="1222"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@contextConductionInd)='true'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @contextConductionInd MOET 'true' zijn. (string(@contextConductionInd)='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-196597-262853-471076-602909-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='364320009']/hl7:organizer[hl7:code[(@code='364320009' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation"
                 priority="1221"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(Graviditeit): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900004-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(Graviditeit): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900004-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&gt;=1 and not(hl7:code[(@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Graviditeit): element hl7:code[(@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13')] is mandatory [min 1x]. (count(hl7:code[(@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&gt;=1 and not(hl7:code[(@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900004-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Graviditeit): element hl7:code[(@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900004-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(Graviditeit): element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900004-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Graviditeit): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900004-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-393777-490682-318416-942712-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='364320009']/hl7:organizer[hl7:code[(@code='364320009' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:code[(@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13')]"
                 priority="1220"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>(Graviditeit): de elementwaarde MOET zijn code 'Gravidity' codeSystem '2.16.840.1.113883.2.4.4.13'. (@nullFlavor or (@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900004-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-464209-542312-482112-503456-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='364320009']/hl7:organizer[hl7:code[(@code='364320009' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:value"
                 priority="1219"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (number($theValue)&gt;=0 and number($theValue)&lt;=75))"/>
         <xsl:otherwise>
            <xsl:message>(Graviditeit): value MOET in bereik [0..75] liggen   ((@nullFlavor or (number($theValue)&gt;=0 and number($theValue)&lt;=75)) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900004-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-187969-166906-242462-156326-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='364320009']/hl7:organizer[hl7:code[(@code='364320009' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='Parturit' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]"
                 priority="1218"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@contextConductionInd)='true'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @contextConductionInd MOET 'true' zijn. (string(@contextConductionInd)='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:observation/hl7:value/@value or ../hl7:component/hl7:observation[hl7:code/@code='Gravidity']/hl7:value/@value &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(acufov): Pariteit is verplicht wanneer Graviditeit &gt; 1. (hl7:observation/hl7:value/@value or ../hl7:component/hl7:observation[hl7:code/@code='Gravidity']/hl7:value/@value &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:observation/hl7:value/@value) or ../hl7:component/hl7:observation[hl7:code/@code='Gravidity']/hl7:value/@value &gt; 1"/>
         <xsl:otherwise>
            <xsl:message>(acufov): Pariteit niet opnemen wanneer Graviditeit = 1. (not(hl7:observation/hl7:value/@value) or ../hl7:component/hl7:observation[hl7:code/@code='Gravidity']/hl7:value/@value &gt; 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-886243-436622-781349-456866-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='364320009']/hl7:organizer[hl7:code[(@code='364320009' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='Parturit' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation"
                 priority="1217"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(Pariteit): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900090-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(Pariteit): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900090-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='Parturit' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&gt;=1 and not(hl7:code[(@code='Parturit' and @codeSystem='2.16.840.1.113883.2.4.4.13')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Pariteit): element hl7:code[(@code='Parturit' and @codeSystem='2.16.840.1.113883.2.4.4.13')] is mandatory [min 1x]. (count(hl7:code[(@code='Parturit' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&gt;=1 and not(hl7:code[(@code='Parturit' and @codeSystem='2.16.840.1.113883.2.4.4.13')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900090-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='Parturit' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Pariteit): element hl7:code[(@code='Parturit' and @codeSystem='2.16.840.1.113883.2.4.4.13')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='Parturit' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900090-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(Pariteit): element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900090-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Pariteit): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900090-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-130410-700178-587577-665650-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='364320009']/hl7:organizer[hl7:code[(@code='364320009' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='Parturit' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:code[(@code='Parturit' and @codeSystem='2.16.840.1.113883.2.4.4.13')]"
                 priority="1216"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='Parturit' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>(Pariteit): de elementwaarde MOET zijn code 'Parturit' codeSystem '2.16.840.1.113883.2.4.4.13'. (@nullFlavor or (@code='Parturit' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900090-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-599102-577719-547447-717009-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='364320009']/hl7:organizer[hl7:code[(@code='364320009' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='Parturit' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:value"
                 priority="1215"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (number($theValue)&gt;=0 and number($theValue)&lt;=30))"/>
         <xsl:otherwise>
            <xsl:message>(Pariteit): value MOET in bereik [0..30] liggen   ((@nullFlavor or (number($theValue)&gt;=0 and number($theValue)&lt;=30)) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900090-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-691316-902557-227813-119524-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='364320009']/hl7:organizer[hl7:code[(@code='364320009' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='AantalLevendeKinderen' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]"
                 priority="1214"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@contextConductionInd)='true'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @contextConductionInd MOET 'true' zijn. (string(@contextConductionInd)='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-907287-133209-905500-320050-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='364320009']/hl7:organizer[hl7:code[(@code='364320009' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='AantalLevendeKinderen' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation"
                 priority="1213"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(AantalLevendeKinderen): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900907-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(AantalLevendeKinderen): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900907-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='AantalLevendeKinderen' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&gt;=1 and not(hl7:code[(@code='AantalLevendeKinderen' and @codeSystem='2.16.840.1.113883.2.4.4.13')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(AantalLevendeKinderen): element hl7:code[(@code='AantalLevendeKinderen' and @codeSystem='2.16.840.1.113883.2.4.4.13')] is mandatory [min 1x]. (count(hl7:code[(@code='AantalLevendeKinderen' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&gt;=1 and not(hl7:code[(@code='AantalLevendeKinderen' and @codeSystem='2.16.840.1.113883.2.4.4.13')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900907-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='AantalLevendeKinderen' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(AantalLevendeKinderen): element hl7:code[(@code='AantalLevendeKinderen' and @codeSystem='2.16.840.1.113883.2.4.4.13')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='AantalLevendeKinderen' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900907-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(AantalLevendeKinderen): element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900907-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(AantalLevendeKinderen): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900907-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-423518-542323-551166-696995-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='364320009']/hl7:organizer[hl7:code[(@code='364320009' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='AantalLevendeKinderen' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:code[(@code='AantalLevendeKinderen' and @codeSystem='2.16.840.1.113883.2.4.4.13')]"
                 priority="1212"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='AantalLevendeKinderen' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>(AantalLevendeKinderen): de elementwaarde MOET zijn code 'AantalLevendeKinderen' codeSystem '2.16.840.1.113883.2.4.4.13'. (@nullFlavor or (@code='AantalLevendeKinderen' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900907-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-260693-179360-611992-222984-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='364320009']/hl7:organizer[hl7:code[(@code='364320009' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='AantalLevendeKinderen' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:value"
                 priority="1211"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="xsiLocalName"
                    select="if (contains(@xsi:type, ':')) then substring-after(@xsi:type,':') else @xsi:type"/>
      <xsl:variable name="xsiLocalNS"
                    select="if (contains(@xsi:type, ':')) then namespace-uri-for-prefix(substring-before(@xsi:type,':'),.) else namespace-uri-for-prefix('',.)"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or ($xsiLocalName='INT' and $xsiLocalNS='urn:hl7-org:v3')"/>
         <xsl:otherwise>
            <xsl:message>(AantalLevendeKinderen): indien er een @xsi:type instructie aanwezig is MOET deze de waarde "INT" bevatten, gevonden "{<xsl:text/>
               <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
               <xsl:text/>}:<xsl:text/>
               <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
               <xsl:text/>" (@nullFlavor or ($xsiLocalName='INT' and $xsiLocalNS='urn:hl7-org:v3') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900907-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-773994-757303-371931-868757-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='364320009']/hl7:organizer[hl7:code[(@code='364320009' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]"
                 priority="1210"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@contextConductionInd)='true'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @contextConductionInd MOET 'true' zijn. (string(@contextConductionInd)='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:observation/hl7:inboundRelationship/hl7:observation[hl7:code/@code='ActualEDD']/hl7:value/@value='true'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): Alleen de actuele à terme datum mag worden meegegeven. (hl7:observation/hl7:inboundRelationship/hl7:observation[hl7:code/@code='ActualEDD']/hl7:value/@value='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-929951-109752-905475-962916-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='364320009']/hl7:organizer[hl7:code[(@code='364320009' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation"
                 priority="1209"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(EDDminimal): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900730-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(EDDminimal): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900730-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="V_ActualCount"
                    select="count(../../*/hl7:observation[hl7:code[@code='EDD']]/*/hl7:observation[hl7:code[@code='ActualEDD'                      and @codeSystem='2.16.840.1.113883.2.4.4.13']]/hl7:value[@value='true'])"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$V_ActualCount &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EDDminimal): Er mag maar één A terme datum actueel zijn ($V_ActualCount &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900730-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&gt;=1 and not(hl7:code[(@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(EDDminimal): element hl7:code[(@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13')] is mandatory [min 1x]. (count(hl7:code[(@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&gt;=1 and not(hl7:code[(@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900730-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EDDminimal): element hl7:code[(@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900730-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(EDDminimal): element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900730-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EDDminimal): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900730-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship[hl7:observation[hl7:code[(@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]])&gt;=1 and not(hl7:inboundRelationship[hl7:observation[hl7:code[(@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(EDDminimal): element hl7:inboundRelationship[hl7:observation[hl7:code[(@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]] is mandatory [min 1x]. (count(hl7:inboundRelationship[hl7:observation[hl7:code[(@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]])&gt;=1 and not(hl7:inboundRelationship[hl7:observation[hl7:code[(@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900730-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship[hl7:observation[hl7:code[(@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EDDminimal): element hl7:inboundRelationship[hl7:observation[hl7:code[(@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]] komt te vaak voor [max 1x]. (count(hl7:inboundRelationship[hl7:observation[hl7:code[(@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900730-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-640743-701832-267466-732477-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='364320009']/hl7:organizer[hl7:code[(@code='364320009' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:code[(@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13')]"
                 priority="1208"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>(EDDminimal): de elementwaarde MOET zijn code 'EDD' codeSystem '2.16.840.1.113883.2.4.4.13'. (@nullFlavor or (@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900730-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-715520-377471-373449-191198-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='364320009']/hl7:organizer[hl7:code[(@code='364320009' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:value"
                 priority="1207"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-152779-989908-403960-358310-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='364320009']/hl7:organizer[hl7:code[(@code='364320009' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]"
                 priority="1206"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='PERT'"/>
         <xsl:otherwise>
            <xsl:message>(EDDminimal): de waarde van @typeCode MOET 'PERT' zijn. (string(@typeCode)='PERT' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900730-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-493830-487194-689754-338360-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='364320009']/hl7:organizer[hl7:code[(@code='364320009' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation"
                 priority="1205"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(ActualEDD): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900009-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(ActualEDD): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900009-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&gt;=1 and not(hl7:code[(@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(ActualEDD): element hl7:code[(@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13')] is mandatory [min 1x]. (count(hl7:code[(@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&gt;=1 and not(hl7:code[(@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900009-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ActualEDD): element hl7:code[(@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900009-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(ActualEDD): element hl7:value is mandatory [min 1x]. (count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900009-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ActualEDD): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900009-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-934159-417135-968790-830001-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='364320009']/hl7:organizer[hl7:code[(@code='364320009' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:code[(@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13')]"
                 priority="1204"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>(ActualEDD): de elementwaarde MOET zijn code 'ActualEDD' codeSystem '2.16.840.1.113883.2.4.4.13'. (@nullFlavor or (@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900009-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-223280-364847-580785-743968-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='364320009']/hl7:organizer[hl7:code[(@code='364320009' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:value"
                 priority="1203"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-458838-914855-775235-243640-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='364320009']/hl7:organizer[hl7:code[(@code='364320009' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='Bevalplan' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]"
                 priority="1202"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@contextConductionInd)='true'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @contextConductionInd MOET 'true' zijn. (string(@contextConductionInd)='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-892390-238271-881201-556938-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='364320009']/hl7:organizer[hl7:code[(@code='364320009' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='Bevalplan' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation"
                 priority="1201"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(BevalPlan): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900917-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(BevalPlan): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900917-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='Bevalplan' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&gt;=1 and not(hl7:code[(@code='Bevalplan' and @codeSystem='2.16.840.1.113883.2.4.4.13')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(BevalPlan): element hl7:code[(@code='Bevalplan' and @codeSystem='2.16.840.1.113883.2.4.4.13')] is mandatory [min 1x]. (count(hl7:code[(@code='Bevalplan' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&gt;=1 and not(hl7:code[(@code='Bevalplan' and @codeSystem='2.16.840.1.113883.2.4.4.13')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900917-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='Bevalplan' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(BevalPlan): element hl7:code[(@code='Bevalplan' and @codeSystem='2.16.840.1.113883.2.4.4.13')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='Bevalplan' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900917-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(BevalPlan): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900917-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-695232-586848-609723-332864-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='364320009']/hl7:organizer[hl7:code[(@code='364320009' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='Bevalplan' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:code[(@code='Bevalplan' and @codeSystem='2.16.840.1.113883.2.4.4.13')]"
                 priority="1200"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='Bevalplan' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>(BevalPlan): de elementwaarde MOET zijn code 'Bevalplan' codeSystem '2.16.840.1.113883.2.4.4.13'. (@nullFlavor or (@code='Bevalplan' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900917-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-204412-203485-167470-737630-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='364320009']/hl7:organizer[hl7:code[(@code='364320009' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='Bevalplan' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:value"
                 priority="1199"
                 mode="M6">
      <xsl:variable name="theValue" select="text()"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@representation)='B64' or not(@representation)"/>
         <xsl:otherwise>
            <xsl:message>(BevalPlan): de waarde van @representation MOET 'B64' zijn. (string(@representation)='B64' or not(@representation) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900917-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@mediaType)='application/pdf' or not(@mediaType)"/>
         <xsl:otherwise>
            <xsl:message>(BevalPlan): de waarde van @mediaType MOET 'application/pdf' zijn. (string(@mediaType)='application/pdf' or not(@mediaType) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900917-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-929039-511167-466637-370216-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='236973005']"
                 priority="1198"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='PERT'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @typeCode MOET 'PERT' zijn. (string(@typeCode)='PERT' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@contextConductionInd)='true'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @contextConductionInd MOET 'true' zijn. (string(@contextConductionInd)='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:organizer[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]])&gt;=1 and not(hl7:organizer[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:organizer[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]] is mandatory [min 1x]. (count(hl7:organizer[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]])&gt;=1 and not(hl7:organizer[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:organizer[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:organizer[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]] komt te vaak voor [max 1x]. (count(hl7:organizer[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-430411-476271-728874-402423-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='236973005']/hl7:organizer[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]"
                 priority="1197"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='CONTAINER'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @classCode MOET 'CONTAINER' zijn. (string(@classCode)='CONTAINER' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')] is mandatory [min 1x]. (count(hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:observation[hl7:code[(@code='BeginDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:component[hl7:observation[hl7:code[(@code='BeginDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]] komt te vaak voor [max 1x]. (count(hl7:component[hl7:observation[hl7:code[(@code='BeginDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:observation[hl7:code[(@code='249120008' and @codeSystem='2.16.840.1.113883.6.96')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:component[hl7:observation[hl7:code[(@code='249120008' and @codeSystem='2.16.840.1.113883.6.96')]]] komt te vaak voor [max 1x]. (count(hl7:component[hl7:observation[hl7:code[(@code='249120008' and @codeSystem='2.16.840.1.113883.6.96')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:observation[hl7:code[(@code='38386-9' and @codeSystem='2.16.840.1.113883.6.1')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:component[hl7:observation[hl7:code[(@code='38386-9' and @codeSystem='2.16.840.1.113883.6.1')]]] komt te vaak voor [max 1x]. (count(hl7:component[hl7:observation[hl7:code[(@code='38386-9' and @codeSystem='2.16.840.1.113883.6.1')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:observation[hl7:code[(@code='Medic3stage' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:component[hl7:observation[hl7:code[(@code='Medic3stage' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]] komt te vaak voor [max 1x]. (count(hl7:component[hl7:observation[hl7:code[(@code='Medic3stage' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:observation[hl7:code[(@code='AfterBirthMethod' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:component[hl7:observation[hl7:code[(@code='AfterBirthMethod' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]] komt te vaak voor [max 1x]. (count(hl7:component[hl7:observation[hl7:code[(@code='AfterBirthMethod' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:observation[hl7:code[(@code='364343000' and @codeSystem='2.16.840.1.113883.6.96')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:component[hl7:observation[hl7:code[(@code='364343000' and @codeSystem='2.16.840.1.113883.6.96')]]] komt te vaak voor [max 1x]. (count(hl7:component[hl7:observation[hl7:code[(@code='364343000' and @codeSystem='2.16.840.1.113883.6.96')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:observation[hl7:code[(@code='PRN5704' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(acufov): element hl7:component[hl7:observation[hl7:code[(@code='PRN5704' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')]]] komt te vaak voor [max 1x]. (count(hl7:component[hl7:observation[hl7:code[(@code='PRN5704' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-568731-588818-557024-296026-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='236973005']/hl7:organizer[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:code"
                 priority="1196"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de elementwaarde MOET zijn code '236973005' codeSystem '2.16.840.1.113883.6.96'. (@nullFlavor or (@code='236973005' and @codeSystem='2.16.840.1.113883.6.96') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-429861-937151-834209-116945-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='236973005']/hl7:organizer[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='BeginDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]"
                 priority="1195"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@contextConductionInd)='true'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @contextConductionInd MOET 'true' zijn. (string(@contextConductionInd)='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-862023-995857-304752-402930-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='236973005']/hl7:organizer[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='BeginDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation"
                 priority="1194"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(Wijzewaaropdebaringbegon_4): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900908-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(Wijzewaaropdebaringbegon_4): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900908-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='BeginDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&gt;=1 and not(hl7:code[(@code='BeginDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Wijzewaaropdebaringbegon_4): element hl7:code[(@code='BeginDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13')] is mandatory [min 1x]. (count(hl7:code[(@code='BeginDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&gt;=1 and not(hl7:code[(@code='BeginDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900908-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='BeginDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Wijzewaaropdebaringbegon_4): element hl7:code[(@code='BeginDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='BeginDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900908-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.46') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.46') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.46') or @nullFlavor='UNK' or @nullFlavor='NI'])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(Wijzewaaropdebaringbegon_4): element hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.46') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.46') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.46') or @nullFlavor='UNK' or @nullFlavor='NI'] is required [min 1x]. (count(hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.46') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.46') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.46') or @nullFlavor='UNK' or @nullFlavor='NI'])&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900908-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.46') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.46') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.46') or @nullFlavor='UNK' or @nullFlavor='NI'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Wijzewaaropdebaringbegon_4): element hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.46') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.46') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.46') or @nullFlavor='UNK' or @nullFlavor='NI'] komt te vaak voor [max 1x]. (count(hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.46') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.46') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.46') or @nullFlavor='UNK' or @nullFlavor='NI'])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900908-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-267195-984050-127376-828613-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='236973005']/hl7:organizer[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='BeginDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:code[(@code='BeginDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13')]"
                 priority="1193"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='BeginDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>(Wijzewaaropdebaringbegon_4): de elementwaarde MOET zijn code 'BeginDeliv' codeSystem '2.16.840.1.113883.2.4.4.13'. (@nullFlavor or (@code='BeginDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900908-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-849133-525347-764661-514272-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='236973005']/hl7:organizer[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='BeginDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.46') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.46') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.46') or @nullFlavor='UNK' or @nullFlavor='NI']"
                 priority="1192"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="validCodeOrCodeSystemFound"
                    select="concat(exists(document('include/voc-2.16.840.1.113883.2.4.11.16-DYNAMIC.xml')/*/valueSet[conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-2.16.840.1.113883.2.4.11.16-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>
      <xsl:variable name="explicitExceptions" select="''"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or contains($validCodeOrCodeSystemFound,'true')"/>
         <xsl:otherwise>
            <xsl:message>(Wijzewaaropdebaringbegon_4): de waarde van @code MOET worden gekozen uit waardenlijst WijzeBaringBegin (DYNAMISCH). NB: codeSystemVersion MOET exact overeenkomen indien gespecificeerd in de waardenlijst. (@nullFlavor or contains($validCodeOrCodeSystemFound,'true') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900908-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|'))"/>
         <xsl:otherwise>
            <xsl:message>(Wijzewaaropdebaringbegon_4): de nulwaarde voor @code MOET komen uit de set die is gedefinieerd voor dit attribuut of zijn gekoppeld aan waardenlijst WijzeBaringBegin (DYNAMISCH). (not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|')) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900908-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-701277-233702-467074-973702-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='236973005']/hl7:organizer[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='249120008' and @codeSystem='2.16.840.1.113883.6.96')]]]"
                 priority="1191"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@contextConductionInd)='true'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @contextConductionInd MOET 'true' zijn. (string(@contextConductionInd)='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-966323-241862-351769-774604-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='236973005']/hl7:organizer[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='249120008' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation"
                 priority="1190"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(Tijdstipbeginactieveontsluiting): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900197-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(Tijdstipbeginactieveontsluiting): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900197-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='249120008' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='249120008' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Tijdstipbeginactieveontsluiting): element hl7:code[(@code='249120008' and @codeSystem='2.16.840.1.113883.6.96')] is mandatory [min 1x]. (count(hl7:code[(@code='249120008' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='249120008' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900197-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='249120008' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Tijdstipbeginactieveontsluiting): element hl7:code[(@code='249120008' and @codeSystem='2.16.840.1.113883.6.96')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='249120008' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900197-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:effectiveTime)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(Tijdstipbeginactieveontsluiting): element hl7:effectiveTime is required [min 1x]. (count(hl7:effectiveTime)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900197-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:effectiveTime)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Tijdstipbeginactieveontsluiting): element hl7:effectiveTime komt te vaak voor [max 1x]. (count(hl7:effectiveTime)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900197-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-678201-743077-731234-351126-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='236973005']/hl7:organizer[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='249120008' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:code[(@code='249120008' and @codeSystem='2.16.840.1.113883.6.96')]"
                 priority="1189"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='249120008' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>(Tijdstipbeginactieveontsluiting): de elementwaarde MOET zijn code '249120008' codeSystem '2.16.840.1.113883.6.96'. (@nullFlavor or (@code='249120008' and @codeSystem='2.16.840.1.113883.6.96') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900197-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-432468-356144-780037-209120-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='236973005']/hl7:organizer[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='249120008' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:effectiveTime"
                 priority="1188"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-164915-735071-972768-266348-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='236973005']/hl7:organizer[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='38386-9' and @codeSystem='2.16.840.1.113883.6.1')]]]"
                 priority="1187"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@contextConductionInd)='true'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @contextConductionInd MOET 'true' zijn. (string(@contextConductionInd)='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-855115-112055-325584-961045-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='236973005']/hl7:organizer[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='38386-9' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation"
                 priority="1186"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(Kleurvruchtwater): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900199-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(Kleurvruchtwater): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900199-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='38386-9' and @codeSystem='2.16.840.1.113883.6.1')])&gt;=1 and not(hl7:code[(@code='38386-9' and @codeSystem='2.16.840.1.113883.6.1')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Kleurvruchtwater): element hl7:code[(@code='38386-9' and @codeSystem='2.16.840.1.113883.6.1')] is mandatory [min 1x]. (count(hl7:code[(@code='38386-9' and @codeSystem='2.16.840.1.113883.6.1')])&gt;=1 and not(hl7:code[(@code='38386-9' and @codeSystem='2.16.840.1.113883.6.1')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900199-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='38386-9' and @codeSystem='2.16.840.1.113883.6.1')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Kleurvruchtwater): element hl7:code[(@code='38386-9' and @codeSystem='2.16.840.1.113883.6.1')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='38386-9' and @codeSystem='2.16.840.1.113883.6.1')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900199-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.4.13.18') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.18') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.4.13.18') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI'])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(Kleurvruchtwater): element hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.4.13.18') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.18') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.4.13.18') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI'] is required [min 1x]. (count(hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.4.13.18') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.18') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.4.13.18') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI'])&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900199-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.4.13.18') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.18') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.4.13.18') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Kleurvruchtwater): element hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.4.13.18') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.18') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.4.13.18') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI'] komt te vaak voor [max 1x]. (count(hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.4.13.18') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.18') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.4.13.18') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI'])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900199-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-107245-727876-499862-327942-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='236973005']/hl7:organizer[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='38386-9' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation/hl7:code[(@code='38386-9' and @codeSystem='2.16.840.1.113883.6.1')]"
                 priority="1185"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='38386-9' and @codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <xsl:message>(Kleurvruchtwater): de elementwaarde MOET zijn code '38386-9' codeSystem '2.16.840.1.113883.6.1'. (@nullFlavor or (@code='38386-9' and @codeSystem='2.16.840.1.113883.6.1') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900199-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-809097-376177-643323-342211-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='236973005']/hl7:organizer[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='38386-9' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation/hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.4.13.18') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.18') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.4.13.18') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI']"
                 priority="1184"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="validCodeOrCodeSystemFound"
                    select="concat(exists(document('include/voc-2.16.840.1.113883.2.4.11.20-DYNAMIC.xml')/*/valueSet[conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-2.16.840.1.113883.2.4.11.20-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>
      <xsl:variable name="explicitExceptions" select="''"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or contains($validCodeOrCodeSystemFound,'true')"/>
         <xsl:otherwise>
            <xsl:message>(Kleurvruchtwater): de waarde van @code MOET worden gekozen uit waardenlijst KleurVruchtwater (DYNAMISCH). NB: codeSystemVersion MOET exact overeenkomen indien gespecificeerd in de waardenlijst. (@nullFlavor or contains($validCodeOrCodeSystemFound,'true') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900199-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|'))"/>
         <xsl:otherwise>
            <xsl:message>(Kleurvruchtwater): de nulwaarde voor @code MOET komen uit de set die is gedefinieerd voor dit attribuut of zijn gekoppeld aan waardenlijst KleurVruchtwater (DYNAMISCH). (not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|')) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900199-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-711393-452765-581487-992256-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='236973005']/hl7:organizer[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='Medic3stage' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]"
                 priority="1183"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@contextConductionInd)='true'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @contextConductionInd MOET 'true' zijn. (string(@contextConductionInd)='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-813582-773597-163903-837525-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='236973005']/hl7:organizer[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='Medic3stage' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation"
                 priority="1182"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(Medicatienageboortetijdperk_3): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900716-2012-04-22T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(Medicatienageboortetijdperk_3): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900716-2012-04-22T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:value/@value='false' or hl7:value/@nullFlavor or count(hl7:inboundRelationship[@typeCode='COMP'])&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Medicatienageboortetijdperk_3): If Medicatie nageboortetijdperk = true, a substanceAdministration as a component shall be present (hl7:value/@value='false' or hl7:value/@nullFlavor or count(hl7:inboundRelationship[@typeCode='COMP'])&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900716-2012-04-22T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='Medic3stage' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&gt;=1 and not(hl7:code[(@code='Medic3stage' and @codeSystem='2.16.840.1.113883.2.4.4.13')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Medicatienageboortetijdperk_3): element hl7:code[(@code='Medic3stage' and @codeSystem='2.16.840.1.113883.2.4.4.13')] is mandatory [min 1x]. (count(hl7:code[(@code='Medic3stage' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&gt;=1 and not(hl7:code[(@code='Medic3stage' and @codeSystem='2.16.840.1.113883.2.4.4.13')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900716-2012-04-22T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='Medic3stage' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Medicatienageboortetijdperk_3): element hl7:code[(@code='Medic3stage' and @codeSystem='2.16.840.1.113883.2.4.4.13')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='Medic3stage' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900716-2012-04-22T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(Medicatienageboortetijdperk_3): element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900716-2012-04-22T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Medicatienageboortetijdperk_3): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900716-2012-04-22T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-282514-632145-588654-473877-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='236973005']/hl7:organizer[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='Medic3stage' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:code[(@code='Medic3stage' and @codeSystem='2.16.840.1.113883.2.4.4.13')]"
                 priority="1181"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='Medic3stage' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>(Medicatienageboortetijdperk_3): de elementwaarde MOET zijn code 'Medic3stage' codeSystem '2.16.840.1.113883.2.4.4.13'. (@nullFlavor or (@code='Medic3stage' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900716-2012-04-22T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-255486-315101-355564-341794-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='236973005']/hl7:organizer[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='Medic3stage' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:value"
                 priority="1180"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-217227-655690-471430-427098-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='236973005']/hl7:organizer[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='Medic3stage' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:inboundRelationship"
                 priority="1179"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:substanceAdministration)&gt;=1 and not(hl7:substanceAdministration/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Soortmedicatienageboortetijdperk_3): element hl7:substanceAdministration is mandatory [min 1x]. (count(hl7:substanceAdministration)&gt;=1 and not(hl7:substanceAdministration/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900525-2012-12-04T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:substanceAdministration)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Soortmedicatienageboortetijdperk_3): element hl7:substanceAdministration komt te vaak voor [max 1x]. (count(hl7:substanceAdministration)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900525-2012-12-04T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(Medicatienageboortetijdperk_3): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900716-2012-04-22T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-499971-587105-265304-839998-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='236973005']/hl7:organizer[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='Medic3stage' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:inboundRelationship/hl7:substanceAdministration"
                 priority="1177"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='SBADM'"/>
         <xsl:otherwise>
            <xsl:message>(Soortmedicatienageboortetijdperk_3): de waarde van @classCode MOET 'SBADM' zijn. (string(@classCode)='SBADM' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900525-2012-12-04T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(Soortmedicatienageboortetijdperk_3): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900525-2012-12-04T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:consumable)&gt;=1 and not(hl7:consumable/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Soortmedicatienageboortetijdperk_3): element hl7:consumable is mandatory [min 1x]. (count(hl7:consumable)&gt;=1 and not(hl7:consumable/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900525-2012-12-04T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:consumable)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Soortmedicatienageboortetijdperk_3): element hl7:consumable komt te vaak voor [max 1x]. (count(hl7:consumable)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900525-2012-12-04T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-495550-575222-546678-364360-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='236973005']/hl7:organizer[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='Medic3stage' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:inboundRelationship/hl7:substanceAdministration/hl7:consumable"
                 priority="1176"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='CSM'"/>
         <xsl:otherwise>
            <xsl:message>(Soortmedicatienageboortetijdperk_3): de waarde van @typeCode MOET 'CSM' zijn. (string(@typeCode)='CSM' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900525-2012-12-04T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:manufacturedProduct[hl7:manufacturedProduct[hl7:code[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI']]])&gt;=1 and not(hl7:manufacturedProduct[hl7:manufacturedProduct[hl7:code[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI']]]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Soortmedicatienageboortetijdperk_3): element hl7:manufacturedProduct[hl7:manufacturedProduct[hl7:code[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI']]] is mandatory [min 1x]. (count(hl7:manufacturedProduct[hl7:manufacturedProduct[hl7:code[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI']]])&gt;=1 and not(hl7:manufacturedProduct[hl7:manufacturedProduct[hl7:code[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI']]]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900525-2012-12-04T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:manufacturedProduct[hl7:manufacturedProduct[hl7:code[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Soortmedicatienageboortetijdperk_3): element hl7:manufacturedProduct[hl7:manufacturedProduct[hl7:code[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI']]] komt te vaak voor [max 1x]. (count(hl7:manufacturedProduct[hl7:manufacturedProduct[hl7:code[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI']]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900525-2012-12-04T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-506651-524558-311621-200210-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='236973005']/hl7:organizer[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='Medic3stage' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:inboundRelationship/hl7:substanceAdministration/hl7:consumable/hl7:manufacturedProduct[hl7:manufacturedProduct[hl7:code[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI']]]"
                 priority="1175"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='MANU'"/>
         <xsl:otherwise>
            <xsl:message>(Soortmedicatienageboortetijdperk_3): de waarde van @classCode MOET 'MANU' zijn. (string(@classCode)='MANU' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900525-2012-12-04T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:manufacturedProduct[hl7:code[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI']])&gt;=1 and not(hl7:manufacturedProduct[hl7:code[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI']]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Soortmedicatienageboortetijdperk_3): element hl7:manufacturedProduct[hl7:code[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI']] is mandatory [min 1x]. (count(hl7:manufacturedProduct[hl7:code[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI']])&gt;=1 and not(hl7:manufacturedProduct[hl7:code[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI']]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900525-2012-12-04T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:manufacturedProduct[hl7:code[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI']])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Soortmedicatienageboortetijdperk_3): element hl7:manufacturedProduct[hl7:code[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI']] komt te vaak voor [max 1x]. (count(hl7:manufacturedProduct[hl7:code[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI']])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900525-2012-12-04T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-255809-966402-152266-301987-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='236973005']/hl7:organizer[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='Medic3stage' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:inboundRelationship/hl7:substanceAdministration/hl7:consumable/hl7:manufacturedProduct[hl7:manufacturedProduct[hl7:code[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI']]]/hl7:manufacturedProduct"
                 priority="1174"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='MMAT'"/>
         <xsl:otherwise>
            <xsl:message>(Soortmedicatienageboortetijdperk_3): de waarde van @classCode MOET 'MMAT' zijn. (string(@classCode)='MMAT' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900525-2012-12-04T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@determinerCode)='KIND'"/>
         <xsl:otherwise>
            <xsl:message>(Soortmedicatienageboortetijdperk_3): de waarde van @determinerCode MOET 'KIND' zijn. (string(@determinerCode)='KIND' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900525-2012-12-04T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI'])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(Soortmedicatienageboortetijdperk_3): element hl7:code[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI'] is required [min 1x]. (count(hl7:code[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI'])&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900525-2012-12-04T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Soortmedicatienageboortetijdperk_3): element hl7:code[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI'] komt te vaak voor [max 1x]. (count(hl7:code[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI'])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900525-2012-12-04T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-505620-587448-855247-775540-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='236973005']/hl7:organizer[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='Medic3stage' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:inboundRelationship/hl7:substanceAdministration/hl7:consumable/hl7:manufacturedProduct[hl7:manufacturedProduct[hl7:code[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI']]]/hl7:manufacturedProduct/hl7:code[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI']"
                 priority="1173"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="validCodeOrCodeSystemFound"
                    select="concat(exists(document('include/voc-2.16.840.1.113883.2.4.11.21-DYNAMIC.xml')/*/valueSet[conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-2.16.840.1.113883.2.4.11.21-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>
      <xsl:variable name="explicitExceptions" select="''"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or contains($validCodeOrCodeSystemFound,'true')"/>
         <xsl:otherwise>
            <xsl:message>(Soortmedicatienageboortetijdperk_3): de waarde van @code MOET worden gekozen uit waardenlijst SoortMedNageboorte (DYNAMISCH). NB: codeSystemVersion MOET exact overeenkomen indien gespecificeerd in de waardenlijst. (@nullFlavor or contains($validCodeOrCodeSystemFound,'true') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900525-2012-12-04T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|'))"/>
         <xsl:otherwise>
            <xsl:message>(Soortmedicatienageboortetijdperk_3): de nulwaarde voor @code MOET komen uit de set die is gedefinieerd voor dit attribuut of zijn gekoppeld aan waardenlijst SoortMedNageboorte (DYNAMISCH). (not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|')) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900525-2012-12-04T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-479459-391709-559281-869616-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='236973005']/hl7:organizer[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='AfterBirthMethod' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]"
                 priority="1172"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@contextConductionInd)='true'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @contextConductionInd MOET 'true' zijn. (string(@contextConductionInd)='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-139936-716176-573188-144361-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='236973005']/hl7:organizer[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='AfterBirthMethod' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation"
                 priority="1171"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(Geboorteplacenta): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900214-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(Geboorteplacenta): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900214-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='AfterBirthMethod' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&gt;=1 and not(hl7:code[(@code='AfterBirthMethod' and @codeSystem='2.16.840.1.113883.2.4.4.13')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Geboorteplacenta): element hl7:code[(@code='AfterBirthMethod' and @codeSystem='2.16.840.1.113883.2.4.4.13')] is mandatory [min 1x]. (count(hl7:code[(@code='AfterBirthMethod' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&gt;=1 and not(hl7:code[(@code='AfterBirthMethod' and @codeSystem='2.16.840.1.113883.2.4.4.13')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900214-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='AfterBirthMethod' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Geboorteplacenta): element hl7:code[(@code='AfterBirthMethod' and @codeSystem='2.16.840.1.113883.2.4.4.13')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='AfterBirthMethod' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900214-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value[(@code='0' and @codeSystem='2.16.840.1.113883.2.4.4.13.19') or (@code='1' and @codeSystem='2.16.840.1.113883.2.4.4.13.19') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.19') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.4.13.19') or (@code='4' and @codeSystem='2.16.840.1.113883.2.4.4.13.19') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI'])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(Geboorteplacenta): element hl7:value[(@code='0' and @codeSystem='2.16.840.1.113883.2.4.4.13.19') or (@code='1' and @codeSystem='2.16.840.1.113883.2.4.4.13.19') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.19') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.4.13.19') or (@code='4' and @codeSystem='2.16.840.1.113883.2.4.4.13.19') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI'] is required [min 1x]. (count(hl7:value[(@code='0' and @codeSystem='2.16.840.1.113883.2.4.4.13.19') or (@code='1' and @codeSystem='2.16.840.1.113883.2.4.4.13.19') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.19') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.4.13.19') or (@code='4' and @codeSystem='2.16.840.1.113883.2.4.4.13.19') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI'])&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900214-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value[(@code='0' and @codeSystem='2.16.840.1.113883.2.4.4.13.19') or (@code='1' and @codeSystem='2.16.840.1.113883.2.4.4.13.19') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.19') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.4.13.19') or (@code='4' and @codeSystem='2.16.840.1.113883.2.4.4.13.19') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Geboorteplacenta): element hl7:value[(@code='0' and @codeSystem='2.16.840.1.113883.2.4.4.13.19') or (@code='1' and @codeSystem='2.16.840.1.113883.2.4.4.13.19') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.19') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.4.13.19') or (@code='4' and @codeSystem='2.16.840.1.113883.2.4.4.13.19') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI'] komt te vaak voor [max 1x]. (count(hl7:value[(@code='0' and @codeSystem='2.16.840.1.113883.2.4.4.13.19') or (@code='1' and @codeSystem='2.16.840.1.113883.2.4.4.13.19') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.19') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.4.13.19') or (@code='4' and @codeSystem='2.16.840.1.113883.2.4.4.13.19') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI'])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900214-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-705188-207968-116978-841046-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='236973005']/hl7:organizer[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='AfterBirthMethod' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:code[(@code='AfterBirthMethod' and @codeSystem='2.16.840.1.113883.2.4.4.13')]"
                 priority="1170"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='AfterBirthMethod' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>(Geboorteplacenta): de elementwaarde MOET zijn code 'AfterBirthMethod' codeSystem '2.16.840.1.113883.2.4.4.13'. (@nullFlavor or (@code='AfterBirthMethod' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900214-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-548006-118849-179487-949229-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='236973005']/hl7:organizer[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='AfterBirthMethod' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:value[(@code='0' and @codeSystem='2.16.840.1.113883.2.4.4.13.19') or (@code='1' and @codeSystem='2.16.840.1.113883.2.4.4.13.19') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.19') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.4.13.19') or (@code='4' and @codeSystem='2.16.840.1.113883.2.4.4.13.19') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI']"
                 priority="1169"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="validCodeOrCodeSystemFound"
                    select="concat(exists(document('include/voc-2.16.840.1.113883.2.4.11.22-DYNAMIC.xml')/*/valueSet[conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-2.16.840.1.113883.2.4.11.22-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>
      <xsl:variable name="explicitExceptions" select="''"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or contains($validCodeOrCodeSystemFound,'true')"/>
         <xsl:otherwise>
            <xsl:message>(Geboorteplacenta): de waarde van @code MOET worden gekozen uit waardenlijst GeboortePlacenta (DYNAMISCH). NB: codeSystemVersion MOET exact overeenkomen indien gespecificeerd in de waardenlijst. (@nullFlavor or contains($validCodeOrCodeSystemFound,'true') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900214-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|'))"/>
         <xsl:otherwise>
            <xsl:message>(Geboorteplacenta): de nulwaarde voor @code MOET komen uit de set die is gedefinieerd voor dit attribuut of zijn gekoppeld aan waardenlijst GeboortePlacenta (DYNAMISCH). (not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|')) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900214-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-568473-450365-820993-712281-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='236973005']/hl7:organizer[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='364343000' and @codeSystem='2.16.840.1.113883.6.96')]]]"
                 priority="1168"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@contextConductionInd)='true'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @contextConductionInd MOET 'true' zijn. (string(@contextConductionInd)='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-406668-824142-777094-424347-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='236973005']/hl7:organizer[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='364343000' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation"
                 priority="1167"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(PlacentaCompleet): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900403-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(PlacentaCompleet): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900403-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='364343000' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='364343000' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(PlacentaCompleet): element hl7:code[(@code='364343000' and @codeSystem='2.16.840.1.113883.6.96')] is mandatory [min 1x]. (count(hl7:code[(@code='364343000' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='364343000' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900403-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='364343000' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PlacentaCompleet): element hl7:code[(@code='364343000' and @codeSystem='2.16.840.1.113883.6.96')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='364343000' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900403-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value[(@code='249170006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='268479002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='pdubc' and @codeSystem='2.16.840.1.113883.2.4.4.13.44') or @nullFlavor='UNK'])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(PlacentaCompleet): element hl7:value[(@code='249170006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='268479002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='pdubc' and @codeSystem='2.16.840.1.113883.2.4.4.13.44') or @nullFlavor='UNK'] is required [min 1x]. (count(hl7:value[(@code='249170006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='268479002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='pdubc' and @codeSystem='2.16.840.1.113883.2.4.4.13.44') or @nullFlavor='UNK'])&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900403-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value[(@code='249170006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='268479002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='pdubc' and @codeSystem='2.16.840.1.113883.2.4.4.13.44') or @nullFlavor='UNK'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PlacentaCompleet): element hl7:value[(@code='249170006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='268479002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='pdubc' and @codeSystem='2.16.840.1.113883.2.4.4.13.44') or @nullFlavor='UNK'] komt te vaak voor [max 1x]. (count(hl7:value[(@code='249170006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='268479002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='pdubc' and @codeSystem='2.16.840.1.113883.2.4.4.13.44') or @nullFlavor='UNK'])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900403-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-530445-300444-728298-853865-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='236973005']/hl7:organizer[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='364343000' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:code[(@code='364343000' and @codeSystem='2.16.840.1.113883.6.96')]"
                 priority="1166"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='364343000' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>(PlacentaCompleet): de elementwaarde MOET zijn code '364343000' codeSystem '2.16.840.1.113883.6.96'. (@nullFlavor or (@code='364343000' and @codeSystem='2.16.840.1.113883.6.96') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900403-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-692889-719290-359932-512523-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='236973005']/hl7:organizer[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='364343000' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:value[(@code='249170006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='268479002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='pdubc' and @codeSystem='2.16.840.1.113883.2.4.4.13.44') or @nullFlavor='UNK']"
                 priority="1165"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="validCodeOrCodeSystemFound"
                    select="concat(exists(document('include/voc-2.16.840.1.113883.2.4.11.160-DYNAMIC.xml')/*/valueSet[conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-2.16.840.1.113883.2.4.11.160-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>
      <xsl:variable name="explicitExceptions" select="''"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or contains($validCodeOrCodeSystemFound,'true')"/>
         <xsl:otherwise>
            <xsl:message>(PlacentaCompleet): de waarde van @code MOET worden gekozen uit waardenlijst Completenessplacenta Completeness placenta (DYNAMISCH). NB: codeSystemVersion MOET exact overeenkomen indien gespecificeerd in de waardenlijst. (@nullFlavor or contains($validCodeOrCodeSystemFound,'true') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900403-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|'))"/>
         <xsl:otherwise>
            <xsl:message>(PlacentaCompleet): de nulwaarde voor @code MOET komen uit de set die is gedefinieerd voor dit attribuut of zijn gekoppeld aan waardenlijst Completenessplacenta Completeness placenta (DYNAMISCH). (not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|')) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900403-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-666566-740363-206096-723195-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='236973005']/hl7:organizer[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='PRN5704' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')]]]"
                 priority="1164"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@contextConductionInd)='true'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @contextConductionInd MOET 'true' zijn. (string(@contextConductionInd)='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-589144-922163-946338-335271-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='236973005']/hl7:organizer[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='PRN5704' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')]]]/hl7:observation"
                 priority="1163"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(Conditieperineumpostpartum): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900262-2013-04-23T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(Conditieperineumpostpartum): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900262-2013-04-23T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='PRN5704' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')])&gt;=1 and not(hl7:code[(@code='PRN5704' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Conditieperineumpostpartum): element hl7:code[(@code='PRN5704' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')] is mandatory [min 1x]. (count(hl7:code[(@code='PRN5704' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')])&gt;=1 and not(hl7:code[(@code='PRN5704' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900262-2013-04-23T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='PRN5704' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Conditieperineumpostpartum): element hl7:code[(@code='PRN5704' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='PRN5704' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900262-2013-04-23T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value[(@code='A' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='B' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='C' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='D' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='E' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='F' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI'])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(Conditieperineumpostpartum): element hl7:value[(@code='A' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='B' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='C' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='D' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='E' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='F' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI'] is required [min 1x]. (count(hl7:value[(@code='A' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='B' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='C' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='D' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='E' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='F' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI'])&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900262-2013-04-23T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value[(@code='A' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='B' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='C' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='D' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='E' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='F' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Conditieperineumpostpartum): element hl7:value[(@code='A' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='B' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='C' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='D' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='E' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='F' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI'] komt te vaak voor [max 1x]. (count(hl7:value[(@code='A' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='B' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='C' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='D' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='E' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='F' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI'])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900262-2013-04-23T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-677142-236781-491370-255782-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='236973005']/hl7:organizer[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='PRN5704' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')]]]/hl7:observation/hl7:code[(@code='PRN5704' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')]"
                 priority="1162"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='PRN5704' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')"/>
         <xsl:otherwise>
            <xsl:message>(Conditieperineumpostpartum): de elementwaarde MOET zijn code 'PRN5704' codeSystem '2.16.840.1.113883.2.4.3.22.1.1'. (@nullFlavor or (@code='PRN5704' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900262-2013-04-23T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-134799-474375-701301-687468-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer/hl7:code/@code='236973005']/hl7:organizer[hl7:code[(@code='236973005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:component[hl7:observation[hl7:code[(@code='PRN5704' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')]]]/hl7:observation/hl7:value[(@code='A' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='B' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='C' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='D' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='E' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or (@code='F' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.62') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI']"
                 priority="1161"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="validCodeOrCodeSystemFound"
                    select="concat(exists(document('include/voc-2.16.840.1.113883.2.4.11.27-2013-04-23T000000.xml')/*/valueSet[conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-2.16.840.1.113883.2.4.11.27-2013-04-23T000000.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>
      <xsl:variable name="explicitExceptions" select="''"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or contains($validCodeOrCodeSystemFound,'true')"/>
         <xsl:otherwise>
            <xsl:message>(Conditieperineumpostpartum): de waarde van @code MOET worden gekozen uit waardenlijst ConditiePerineum (2013-04-23T00:00:00). NB: codeSystemVersion MOET exact overeenkomen indien gespecificeerd in de waardenlijst. (@nullFlavor or contains($validCodeOrCodeSystemFound,'true') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900262-2013-04-23T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|'))"/>
         <xsl:otherwise>
            <xsl:message>(Conditieperineumpostpartum): de nulwaarde voor @code MOET komen uit de set die is gedefinieerd voor dit attribuut of zijn gekoppeld aan waardenlijst ConditiePerineum (2013-04-23T00:00:00). (not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|')) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900262-2013-04-23T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-611765-255374-477072-762125-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:procedure/hl7:code/@code='Baring']"
                 priority="1160"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='PERT'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @typeCode MOET 'PERT' zijn. (string(@typeCode)='PERT' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@contextConductionInd)='false'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @contextConductionInd MOET 'false' zijn. (string(@contextConductionInd)='false' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-909468-171671-518660-579759-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:procedure/hl7:code/@code='Baring']/hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]"
                 priority="1159"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='PROC'"/>
         <xsl:otherwise>
            <xsl:message>(Uitkomstperkindsubjectkort): de waarde van @classCode MOET 'PROC' zijn. (string(@classCode)='PROC' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900624-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(Uitkomstperkindsubjectkort): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900624-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(Uitkomstperkindsubjectkort): element hl7:id is required [min 1x]. (count(hl7:id)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900624-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Uitkomstperkindsubjectkort): element hl7:id komt te vaak voor [max 1x]. (count(hl7:id)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900624-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')])&gt;=1 and not(hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Uitkomstperkindsubjectkort): element hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')] is mandatory [min 1x]. (count(hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')])&gt;=1 and not(hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900624-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Uitkomstperkindsubjectkort): element hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900624-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship[hl7:observation[hl7:code[(@code='46098-0' and @codeSystem='2.16.840.1.113883.6.1')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Uitkomstperkindsubjectkort): element hl7:inboundRelationship[hl7:observation[hl7:code[(@code='46098-0' and @codeSystem='2.16.840.1.113883.6.1')]]] komt te vaak voor [max 1x]. (count(hl7:inboundRelationship[hl7:observation[hl7:code[(@code='46098-0' and @codeSystem='2.16.840.1.113883.6.1')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900624-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship[hl7:observation[hl7:code[(@code='PRN810201' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Uitkomstperkindsubjectkort): element hl7:inboundRelationship[hl7:observation[hl7:code[(@code='PRN810201' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')]]] komt te vaak voor [max 1x]. (count(hl7:inboundRelationship[hl7:observation[hl7:code[(@code='PRN810201' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900624-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship[hl7:observation[hl7:code[(@code='289251005' and @codeSystem='2.16.840.1.113883.6.96')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Uitkomstperkindsubjectkort): element hl7:inboundRelationship[hl7:observation[hl7:code[(@code='289251005' and @codeSystem='2.16.840.1.113883.6.96')]]] komt te vaak voor [max 1x]. (count(hl7:inboundRelationship[hl7:observation[hl7:code[(@code='289251005' and @codeSystem='2.16.840.1.113883.6.96')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900624-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship[hl7:observation[hl7:code[(@code='249160009' and @codeSystem='2.16.840.1.113883.6.96')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Uitkomstperkindsubjectkort): element hl7:inboundRelationship[hl7:observation[hl7:code[(@code='249160009' and @codeSystem='2.16.840.1.113883.6.96')]]] komt te vaak voor [max 1x]. (count(hl7:inboundRelationship[hl7:observation[hl7:code[(@code='249160009' and @codeSystem='2.16.840.1.113883.6.96')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900624-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship[hl7:observation[hl7:code[(@code='289258004' and @codeSystem='2.16.840.1.113883.6.96')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Uitkomstperkindsubjectkort): element hl7:inboundRelationship[hl7:observation[hl7:code[(@code='289258004' and @codeSystem='2.16.840.1.113883.6.96')]]] komt te vaak voor [max 1x]. (count(hl7:inboundRelationship[hl7:observation[hl7:code[(@code='289258004' and @codeSystem='2.16.840.1.113883.6.96')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900624-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship[hl7:observation[hl7:code[(@code='8339-4' and @codeSystem='2.16.840.1.113883.6.1')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Uitkomstperkindsubjectkort): element hl7:inboundRelationship[hl7:observation[hl7:code[(@code='8339-4' and @codeSystem='2.16.840.1.113883.6.1')]]] komt te vaak voor [max 1x]. (count(hl7:inboundRelationship[hl7:observation[hl7:code[(@code='8339-4' and @codeSystem='2.16.840.1.113883.6.1')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900624-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship[hl7:observation[hl7:code[(@code='301334000' and @codeSystem='2.16.840.1.113883.6.96')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Uitkomstperkindsubjectkort): element hl7:inboundRelationship[hl7:observation[hl7:code[(@code='301334000' and @codeSystem='2.16.840.1.113883.6.96')]]] komt te vaak voor [max 1x]. (count(hl7:inboundRelationship[hl7:observation[hl7:code[(@code='301334000' and @codeSystem='2.16.840.1.113883.6.96')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900624-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship[hl7:observation[hl7:code[(@code='9274-2' and @codeSystem='2.16.840.1.113883.6.1')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Uitkomstperkindsubjectkort): element hl7:inboundRelationship[hl7:observation[hl7:code[(@code='9274-2' and @codeSystem='2.16.840.1.113883.6.1')]]] komt te vaak voor [max 1x]. (count(hl7:inboundRelationship[hl7:observation[hl7:code[(@code='9274-2' and @codeSystem='2.16.840.1.113883.6.1')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900624-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship[hl7:observation[hl7:code[(@code='66091009' and @codeSystem='2.16.840.1.113883.6.96')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Uitkomstperkindsubjectkort): element hl7:inboundRelationship[hl7:observation[hl7:code[(@code='66091009' and @codeSystem='2.16.840.1.113883.6.96')]]] komt te vaak voor [max 1x]. (count(hl7:inboundRelationship[hl7:observation[hl7:code[(@code='66091009' and @codeSystem='2.16.840.1.113883.6.96')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900624-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship[hl7:observation[hl7:code[(@code='LigGbrt' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Uitkomstperkindsubjectkort): element hl7:inboundRelationship[hl7:observation[hl7:code[(@code='LigGbrt' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')]]] komt te vaak voor [max 1x]. (count(hl7:inboundRelationship[hl7:observation[hl7:code[(@code='LigGbrt' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900624-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-752020-483604-996379-178046-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:procedure/hl7:code/@code='Baring']/hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]/hl7:id"
                 priority="1158"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-132550-396624-856883-668667-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:procedure/hl7:code/@code='Baring']/hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]/hl7:code"
                 priority="1157"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')"/>
         <xsl:otherwise>
            <xsl:message>(Uitkomstperkindsubjectkort): de elementwaarde MOET zijn code 'Baring' codeSystem '2.16.840.1.113883.2.4.3.22.1.3'. (@nullFlavor or (@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900624-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-491606-553913-477403-272606-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:procedure/hl7:code/@code='Baring']/hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]/hl7:subject[hl7:personalRelationship[hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')]]]"
                 priority="1156"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='SBJ'"/>
         <xsl:otherwise>
            <xsl:message>(Uitkomstperkindsubjectkort): de waarde van @typeCode MOET 'SBJ' zijn. (string(@typeCode)='SBJ' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900624-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:personalRelationship[hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')]])&gt;=1 and not(hl7:personalRelationship[hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')]]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Uitkomstperkindsubjectkort): element hl7:personalRelationship[hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')]] is mandatory [min 1x]. (count(hl7:personalRelationship[hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')]])&gt;=1 and not(hl7:personalRelationship[hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')]]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900624-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:personalRelationship[hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Uitkomstperkindsubjectkort): element hl7:personalRelationship[hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')]] komt te vaak voor [max 1x]. (count(hl7:personalRelationship[hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900624-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-947563-974922-151069-564914-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:procedure/hl7:code/@code='Baring']/hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]/hl7:subject[hl7:personalRelationship[hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')]]]/hl7:personalRelationship"
                 priority="1155"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='PRS'"/>
         <xsl:otherwise>
            <xsl:message>(Uitkomstperkindsubjectkort): de waarde van @classCode MOET 'PRS' zijn. (string(@classCode)='PRS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900624-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')])&gt;=1 and not(hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Uitkomstperkindsubjectkort): element hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')] is mandatory [min 1x]. (count(hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')])&gt;=1 and not(hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900624-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Uitkomstperkindsubjectkort): element hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900624-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:relationshipHolder)&gt;=1 and not(hl7:relationshipHolder/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Uitkomstperkindsubjectkort): element hl7:relationshipHolder is mandatory [min 1x]. (count(hl7:relationshipHolder)&gt;=1 and not(hl7:relationshipHolder/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900624-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:relationshipHolder)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Uitkomstperkindsubjectkort): element hl7:relationshipHolder komt te vaak voor [max 1x]. (count(hl7:relationshipHolder)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900624-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-530649-134083-919474-406765-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:procedure/hl7:code/@code='Baring']/hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]/hl7:subject[hl7:personalRelationship[hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')]]]/hl7:personalRelationship/hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')]"
                 priority="1154"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <xsl:message>(Uitkomstperkindsubjectkort): de elementwaarde MOET zijn code 'CHILD' codeSystem '2.16.840.1.113883.5.111'. (@nullFlavor or (@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900624-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-247980-621828-213954-255751-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:procedure/hl7:code/@code='Baring']/hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]/hl7:subject[hl7:personalRelationship[hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')]]]/hl7:personalRelationship/hl7:relationshipHolder"
                 priority="1153"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='PSN'"/>
         <xsl:otherwise>
            <xsl:message>(Uitkomstperkindsubjectkort): de waarde van @classCode MOET 'PSN' zijn. (string(@classCode)='PSN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900624-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@determinerCode)='INSTANCE'"/>
         <xsl:otherwise>
            <xsl:message>(Uitkomstperkindsubjectkort): de waarde van @determinerCode MOET 'INSTANCE' zijn. (string(@determinerCode)='INSTANCE' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900624-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:deceasedInd/@value='false' or hl7:deceasedInd/@nullFlavor or ../../../hl7:inboundRelationship/hl7:observation[hl7:code/@code='PRN810201']"/>
         <xsl:otherwise>
            <xsl:message>(Uitkomstperkindsubjectkort): Wanneer sprake is van perinatale sterfte, de fase perinatale sterfte verplicht opnemen. (hl7:deceasedInd/@value='false' or hl7:deceasedInd/@nullFlavor or ../../../hl7:inboundRelationship/hl7:observation[hl7:code/@code='PRN810201'] / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900624-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id[not(@root='2.16.840.1.113883.2.4.3.22.6.3') and not(@root='2.16.840.1.113883.2.4.6.3')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Uitkomstperkindsubjectkort): element hl7:id[not(@root='2.16.840.1.113883.2.4.3.22.6.3') and not(@root='2.16.840.1.113883.2.4.6.3')] komt te vaak voor [max 1x]. (count(hl7:id[not(@root='2.16.840.1.113883.2.4.3.22.6.3') and not(@root='2.16.840.1.113883.2.4.6.3')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900624-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id[@root='2.16.840.1.113883.2.4.3.22.6.3'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Uitkomstperkindsubjectkort): element hl7:id[@root='2.16.840.1.113883.2.4.3.22.6.3'] komt te vaak voor [max 1x]. (count(hl7:id[@root='2.16.840.1.113883.2.4.3.22.6.3'])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900624-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id[@root='2.16.840.1.113883.2.4.6.3'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Uitkomstperkindsubjectkort): element hl7:id[@root='2.16.840.1.113883.2.4.6.3'] komt te vaak voor [max 1x]. (count(hl7:id[@root='2.16.840.1.113883.2.4.6.3'])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900624-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:birthTime)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Uitkomstperkindsubjectkort): element hl7:birthTime komt te vaak voor [max 1x]. (count(hl7:birthTime)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900624-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:deceasedInd)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Uitkomstperkindsubjectkort): element hl7:deceasedInd komt te vaak voor [max 1x]. (count(hl7:deceasedInd)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900624-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-107032-769187-668762-307797-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:procedure/hl7:code/@code='Baring']/hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]/hl7:subject[hl7:personalRelationship[hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')]]]/hl7:personalRelationship/hl7:relationshipHolder/hl7:id[not(@root='2.16.840.1.113883.2.4.3.22.6.3') and not(@root='2.16.840.1.113883.2.4.6.3')]"
                 priority="1152"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-686922-830327-332523-777077-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:procedure/hl7:code/@code='Baring']/hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]/hl7:subject[hl7:personalRelationship[hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')]]]/hl7:personalRelationship/hl7:relationshipHolder/hl7:id[@root='2.16.840.1.113883.2.4.3.22.6.3']"
                 priority="1151"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@root)='2.16.840.1.113883.2.4.3.22.6.3'"/>
         <xsl:otherwise>
            <xsl:message>(Uitkomstperkindsubjectkort): @root MOET de waarde '2.16.840.1.113883.2.4.3.22.6.3' hebben. (string(@root)='2.16.840.1.113883.2.4.3.22.6.3' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900624-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-217143-992742-789677-424122-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:procedure/hl7:code/@code='Baring']/hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]/hl7:subject[hl7:personalRelationship[hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')]]]/hl7:personalRelationship/hl7:relationshipHolder/hl7:id[@root='2.16.840.1.113883.2.4.6.3']"
                 priority="1150"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@root)='2.16.840.1.113883.2.4.6.3'"/>
         <xsl:otherwise>
            <xsl:message>(Uitkomstperkindsubjectkort): @root MOET de waarde '2.16.840.1.113883.2.4.6.3' hebben. (string(@root)='2.16.840.1.113883.2.4.6.3' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900624-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-617294-315297-569030-903819-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:procedure/hl7:code/@code='Baring']/hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]/hl7:subject[hl7:personalRelationship[hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')]]]/hl7:personalRelationship/hl7:relationshipHolder/hl7:birthTime"
                 priority="1149"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-689391-725095-175592-751924-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:procedure/hl7:code/@code='Baring']/hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]/hl7:subject[hl7:personalRelationship[hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')]]]/hl7:personalRelationship/hl7:relationshipHolder/hl7:deceasedInd"
                 priority="1148"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-567779-995503-868721-392039-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:procedure/hl7:code/@code='Baring']/hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='46098-0' and @codeSystem='2.16.840.1.113883.6.1')]]]"
                 priority="1147"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(Uitkomstperkindsubjectkort): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900624-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-144067-289070-152861-101673-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:procedure/hl7:code/@code='Baring']/hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='46098-0' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation"
                 priority="1146"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(Geslachtmedischeobservatie): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900255-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(Geslachtmedischeobservatie): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900255-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='46098-0' and @codeSystem='2.16.840.1.113883.6.1')])&gt;=1 and not(hl7:code[(@code='46098-0' and @codeSystem='2.16.840.1.113883.6.1')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Geslachtmedischeobservatie): element hl7:code[(@code='46098-0' and @codeSystem='2.16.840.1.113883.6.1')] is mandatory [min 1x]. (count(hl7:code[(@code='46098-0' and @codeSystem='2.16.840.1.113883.6.1')])&gt;=1 and not(hl7:code[(@code='46098-0' and @codeSystem='2.16.840.1.113883.6.1')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900255-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='46098-0' and @codeSystem='2.16.840.1.113883.6.1')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Geslachtmedischeobservatie): element hl7:code[(@code='46098-0' and @codeSystem='2.16.840.1.113883.6.1')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='46098-0' and @codeSystem='2.16.840.1.113883.6.1')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900255-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.4.13.21') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.21') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.4.13.21') or @nullFlavor='UNK' or @nullFlavor='NI'])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(Geslachtmedischeobservatie): element hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.4.13.21') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.21') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.4.13.21') or @nullFlavor='UNK' or @nullFlavor='NI'] is required [min 1x]. (count(hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.4.13.21') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.21') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.4.13.21') or @nullFlavor='UNK' or @nullFlavor='NI'])&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900255-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.4.13.21') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.21') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.4.13.21') or @nullFlavor='UNK' or @nullFlavor='NI'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Geslachtmedischeobservatie): element hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.4.13.21') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.21') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.4.13.21') or @nullFlavor='UNK' or @nullFlavor='NI'] komt te vaak voor [max 1x]. (count(hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.4.13.21') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.21') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.4.13.21') or @nullFlavor='UNK' or @nullFlavor='NI'])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900255-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-879609-791496-956414-333622-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:procedure/hl7:code/@code='Baring']/hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='46098-0' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation/hl7:code[(@code='46098-0' and @codeSystem='2.16.840.1.113883.6.1')]"
                 priority="1145"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='46098-0' and @codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <xsl:message>(Geslachtmedischeobservatie): de elementwaarde MOET zijn code '46098-0' codeSystem '2.16.840.1.113883.6.1'. (@nullFlavor or (@code='46098-0' and @codeSystem='2.16.840.1.113883.6.1') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900255-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-814353-314719-520090-812680-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:procedure/hl7:code/@code='Baring']/hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='46098-0' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation/hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.4.13.21') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.21') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.4.13.21') or @nullFlavor='UNK' or @nullFlavor='NI']"
                 priority="1144"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="validCodeOrCodeSystemFound"
                    select="concat(exists(document('include/voc-2.16.840.1.113883.2.4.11.110-DYNAMIC.xml')/*/valueSet[conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-2.16.840.1.113883.2.4.11.110-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>
      <xsl:variable name="explicitExceptions" select="''"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or contains($validCodeOrCodeSystemFound,'true')"/>
         <xsl:otherwise>
            <xsl:message>(Geslachtmedischeobservatie): de waarde van @code MOET worden gekozen uit waardenlijst GenderMedisch (DYNAMISCH). NB: codeSystemVersion MOET exact overeenkomen indien gespecificeerd in de waardenlijst. (@nullFlavor or contains($validCodeOrCodeSystemFound,'true') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900255-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|'))"/>
         <xsl:otherwise>
            <xsl:message>(Geslachtmedischeobservatie): de nulwaarde voor @code MOET komen uit de set die is gedefinieerd voor dit attribuut of zijn gekoppeld aan waardenlijst GenderMedisch (DYNAMISCH). (not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|')) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900255-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-152121-445746-763888-181569-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:procedure/hl7:code/@code='Baring']/hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='PRN810201' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')]]]"
                 priority="1143"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(Uitkomstperkindsubjectkort): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900624-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="../hl7:subject/hl7:personalRelationship/hl7:relationshipHolder/hl7:deceasedInd/@value='true'"/>
         <xsl:otherwise>
            <xsl:message>(Uitkomstperkindsubjectkort): Wanneer geen sprake is van perinatale sterfte, de fase perinatale sterfte ook niet opnemen. (../hl7:subject/hl7:personalRelationship/hl7:relationshipHolder/hl7:deceasedInd/@value='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900624-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-897497-861669-297315-587679-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:procedure/hl7:code/@code='Baring']/hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='PRN810201' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')]]]/hl7:observation"
                 priority="1142"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(Faseperinatalesterfte): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900433-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(Faseperinatalesterfte): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900433-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='PRN810201' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')])&gt;=1 and not(hl7:code[(@code='PRN810201' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Faseperinatalesterfte): element hl7:code[(@code='PRN810201' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')] is mandatory [min 1x]. (count(hl7:code[(@code='PRN810201' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')])&gt;=1 and not(hl7:code[(@code='PRN810201' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900433-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='PRN810201' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Faseperinatalesterfte): element hl7:code[(@code='PRN810201' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='PRN810201' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900433-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or (@code='4' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or (@code='6' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or (@code='7' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or (@code='8' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or (@code='9' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or @nullFlavor='UNK' or @nullFlavor='NI'])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(Faseperinatalesterfte): element hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or (@code='4' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or (@code='6' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or (@code='7' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or (@code='8' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or (@code='9' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or @nullFlavor='UNK' or @nullFlavor='NI'] is required [min 1x]. (count(hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or (@code='4' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or (@code='6' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or (@code='7' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or (@code='8' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or (@code='9' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or @nullFlavor='UNK' or @nullFlavor='NI'])&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900433-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or (@code='4' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or (@code='6' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or (@code='7' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or (@code='8' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or (@code='9' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or @nullFlavor='UNK' or @nullFlavor='NI'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Faseperinatalesterfte): element hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or (@code='4' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or (@code='6' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or (@code='7' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or (@code='8' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or (@code='9' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or @nullFlavor='UNK' or @nullFlavor='NI'] komt te vaak voor [max 1x]. (count(hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or (@code='4' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or (@code='6' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or (@code='7' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or (@code='8' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or (@code='9' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or @nullFlavor='UNK' or @nullFlavor='NI'])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900433-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-112418-481970-419100-255450-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:procedure/hl7:code/@code='Baring']/hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='PRN810201' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')]]]/hl7:observation/hl7:code[(@code='PRN810201' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')]"
                 priority="1141"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='PRN810201' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')"/>
         <xsl:otherwise>
            <xsl:message>(Faseperinatalesterfte): de elementwaarde MOET zijn code 'PRN810201' codeSystem '2.16.840.1.113883.2.4.3.22.1.1'. (@nullFlavor or (@code='PRN810201' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900433-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-920444-378556-507890-805720-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:procedure/hl7:code/@code='Baring']/hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='PRN810201' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')]]]/hl7:observation/hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or (@code='4' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or (@code='6' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or (@code='7' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or (@code='8' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or (@code='9' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.79') or @nullFlavor='UNK' or @nullFlavor='NI']"
                 priority="1140"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="validCodeOrCodeSystemFound"
                    select="concat(exists(document('include/voc-2.16.840.1.113883.2.4.11.42-2013-01-10T000000.xml')/*/valueSet[conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-2.16.840.1.113883.2.4.11.42-2013-01-10T000000.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>
      <xsl:variable name="explicitExceptions" select="''"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or contains($validCodeOrCodeSystemFound,'true')"/>
         <xsl:otherwise>
            <xsl:message>(Faseperinatalesterfte): de waarde van @code MOET worden gekozen uit waardenlijst FasePerinatSterfte (2013-01-10T00:00:00). NB: codeSystemVersion MOET exact overeenkomen indien gespecificeerd in de waardenlijst. (@nullFlavor or contains($validCodeOrCodeSystemFound,'true') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900433-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|'))"/>
         <xsl:otherwise>
            <xsl:message>(Faseperinatalesterfte): de nulwaarde voor @code MOET komen uit de set die is gedefinieerd voor dit attribuut of zijn gekoppeld aan waardenlijst FasePerinatSterfte (2013-01-10T00:00:00). (not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|')) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900433-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-439453-972486-414663-177903-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:procedure/hl7:code/@code='Baring']/hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='289251005' and @codeSystem='2.16.840.1.113883.6.96')]]]"
                 priority="1139"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(Uitkomstperkindsubjectkort): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900624-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-577581-227704-919271-381127-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:procedure/hl7:code/@code='Baring']/hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='289251005' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation"
                 priority="1138"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(Tijdstipbrekenvliezen): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900198-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(Tijdstipbrekenvliezen): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900198-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='289251005' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='289251005' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Tijdstipbrekenvliezen): element hl7:code[(@code='289251005' and @codeSystem='2.16.840.1.113883.6.96')] is mandatory [min 1x]. (count(hl7:code[(@code='289251005' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='289251005' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900198-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='289251005' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Tijdstipbrekenvliezen): element hl7:code[(@code='289251005' and @codeSystem='2.16.840.1.113883.6.96')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='289251005' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900198-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:effectiveTime)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(Tijdstipbrekenvliezen): element hl7:effectiveTime is required [min 1x]. (count(hl7:effectiveTime)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900198-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:effectiveTime)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Tijdstipbrekenvliezen): element hl7:effectiveTime komt te vaak voor [max 1x]. (count(hl7:effectiveTime)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900198-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-627719-694145-220448-597167-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:procedure/hl7:code/@code='Baring']/hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='289251005' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:code[(@code='289251005' and @codeSystem='2.16.840.1.113883.6.96')]"
                 priority="1137"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='289251005' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>(Tijdstipbrekenvliezen): de elementwaarde MOET zijn code '289251005' codeSystem '2.16.840.1.113883.6.96'. (@nullFlavor or (@code='289251005' and @codeSystem='2.16.840.1.113883.6.96') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900198-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-996269-759271-142983-819622-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:procedure/hl7:code/@code='Baring']/hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='289251005' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:effectiveTime"
                 priority="1136"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-901751-582815-193785-484894-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:procedure/hl7:code/@code='Baring']/hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='249160009' and @codeSystem='2.16.840.1.113883.6.96')]]]"
                 priority="1135"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(Uitkomstperkindsubjectkort): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900624-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-840378-206669-393678-756246-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:procedure/hl7:code/@code='Baring']/hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='249160009' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation"
                 priority="1134"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(Tijdstipactiefmeepersen): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900261-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(Tijdstipactiefmeepersen): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900261-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='249160009' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='249160009' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Tijdstipactiefmeepersen): element hl7:code[(@code='249160009' and @codeSystem='2.16.840.1.113883.6.96')] is mandatory [min 1x]. (count(hl7:code[(@code='249160009' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='249160009' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900261-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='249160009' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Tijdstipactiefmeepersen): element hl7:code[(@code='249160009' and @codeSystem='2.16.840.1.113883.6.96')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='249160009' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900261-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:effectiveTime)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(Tijdstipactiefmeepersen): element hl7:effectiveTime is required [min 1x]. (count(hl7:effectiveTime)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900261-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:effectiveTime)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Tijdstipactiefmeepersen): element hl7:effectiveTime komt te vaak voor [max 1x]. (count(hl7:effectiveTime)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900261-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-888709-273482-806849-982363-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:procedure/hl7:code/@code='Baring']/hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='249160009' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:code[(@code='249160009' and @codeSystem='2.16.840.1.113883.6.96')]"
                 priority="1133"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='249160009' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>(Tijdstipactiefmeepersen): de elementwaarde MOET zijn code '249160009' codeSystem '2.16.840.1.113883.6.96'. (@nullFlavor or (@code='249160009' and @codeSystem='2.16.840.1.113883.6.96') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900261-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-336049-570874-394943-526056-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:procedure/hl7:code/@code='Baring']/hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='249160009' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:effectiveTime"
                 priority="1132"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-325770-880580-259993-876674-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:procedure/hl7:code/@code='Baring']/hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='289258004' and @codeSystem='2.16.840.1.113883.6.96')]]]"
                 priority="1131"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(Uitkomstperkindsubjectkort): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900624-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-959487-509551-569616-815133-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:procedure/hl7:code/@code='Baring']/hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='289258004' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation"
                 priority="1130"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(TypePartus): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900861-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(TypePartus): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900861-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='289258004' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='289258004' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TypePartus): element hl7:code[(@code='289258004' and @codeSystem='2.16.840.1.113883.6.96')] is mandatory [min 1x]. (count(hl7:code[(@code='289258004' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='289258004' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900861-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='289258004' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TypePartus): element hl7:code[(@code='289258004' and @codeSystem='2.16.840.1.113883.6.96')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='289258004' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900861-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value[(@code='48782003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='KuVerlng' and @codeSystem='2.16.840.1.113883.2.4.4.13') or (@code='200130005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='267278005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='271370008' and @codeSystem='2.16.840.1.113883.6.96') or (@code='200146002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='200148001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='200149009' and @codeSystem='2.16.840.1.113883.6.96') or (@code='39406005' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='NI'])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(TypePartus): element hl7:value[(@code='48782003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='KuVerlng' and @codeSystem='2.16.840.1.113883.2.4.4.13') or (@code='200130005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='267278005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='271370008' and @codeSystem='2.16.840.1.113883.6.96') or (@code='200146002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='200148001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='200149009' and @codeSystem='2.16.840.1.113883.6.96') or (@code='39406005' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='NI'] is required [min 1x]. (count(hl7:value[(@code='48782003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='KuVerlng' and @codeSystem='2.16.840.1.113883.2.4.4.13') or (@code='200130005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='267278005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='271370008' and @codeSystem='2.16.840.1.113883.6.96') or (@code='200146002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='200148001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='200149009' and @codeSystem='2.16.840.1.113883.6.96') or (@code='39406005' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='NI'])&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900861-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value[(@code='48782003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='KuVerlng' and @codeSystem='2.16.840.1.113883.2.4.4.13') or (@code='200130005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='267278005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='271370008' and @codeSystem='2.16.840.1.113883.6.96') or (@code='200146002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='200148001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='200149009' and @codeSystem='2.16.840.1.113883.6.96') or (@code='39406005' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='NI'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TypePartus): element hl7:value[(@code='48782003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='KuVerlng' and @codeSystem='2.16.840.1.113883.2.4.4.13') or (@code='200130005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='267278005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='271370008' and @codeSystem='2.16.840.1.113883.6.96') or (@code='200146002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='200148001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='200149009' and @codeSystem='2.16.840.1.113883.6.96') or (@code='39406005' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='NI'] komt te vaak voor [max 1x]. (count(hl7:value[(@code='48782003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='KuVerlng' and @codeSystem='2.16.840.1.113883.2.4.4.13') or (@code='200130005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='267278005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='271370008' and @codeSystem='2.16.840.1.113883.6.96') or (@code='200146002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='200148001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='200149009' and @codeSystem='2.16.840.1.113883.6.96') or (@code='39406005' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='NI'])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900861-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-178100-799655-877570-319030-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:procedure/hl7:code/@code='Baring']/hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='289258004' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:code[(@code='289258004' and @codeSystem='2.16.840.1.113883.6.96')]"
                 priority="1129"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='289258004' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>(TypePartus): de elementwaarde MOET zijn code '289258004' codeSystem '2.16.840.1.113883.6.96'. (@nullFlavor or (@code='289258004' and @codeSystem='2.16.840.1.113883.6.96') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900861-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-603141-482667-871173-807924-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:procedure/hl7:code/@code='Baring']/hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='289258004' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:value[(@code='48782003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='KuVerlng' and @codeSystem='2.16.840.1.113883.2.4.4.13') or (@code='200130005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='267278005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='271370008' and @codeSystem='2.16.840.1.113883.6.96') or (@code='200146002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='200148001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='200149009' and @codeSystem='2.16.840.1.113883.6.96') or (@code='39406005' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='NI']"
                 priority="1128"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="validCodeOrCodeSystemFound"
                    select="concat(exists(document('include/voc-2.16.840.1.113883.2.4.11.170-DYNAMIC.xml')/*/valueSet[conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-2.16.840.1.113883.2.4.11.170-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>
      <xsl:variable name="explicitExceptions" select="''"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or contains($validCodeOrCodeSystemFound,'true')"/>
         <xsl:otherwise>
            <xsl:message>(TypePartus): de waarde van @code MOET worden gekozen uit waardenlijst TypePartus (DYNAMISCH). NB: codeSystemVersion MOET exact overeenkomen indien gespecificeerd in de waardenlijst. (@nullFlavor or contains($validCodeOrCodeSystemFound,'true') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900861-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|'))"/>
         <xsl:otherwise>
            <xsl:message>(TypePartus): de nulwaarde voor @code MOET komen uit de set die is gedefinieerd voor dit attribuut of zijn gekoppeld aan waardenlijst TypePartus (DYNAMISCH). (not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|')) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900861-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-165064-382472-872010-795705-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:procedure/hl7:code/@code='Baring']/hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='8339-4' and @codeSystem='2.16.840.1.113883.6.1')]]]"
                 priority="1127"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(Uitkomstperkindsubjectkort): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900624-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-975586-764164-222257-268361-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:procedure/hl7:code/@code='Baring']/hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='8339-4' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation"
                 priority="1126"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(Geboortegewicht): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900425-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(Geboortegewicht): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900425-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='8339-4' and @codeSystem='2.16.840.1.113883.6.1')])&gt;=1 and not(hl7:code[(@code='8339-4' and @codeSystem='2.16.840.1.113883.6.1')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Geboortegewicht): element hl7:code[(@code='8339-4' and @codeSystem='2.16.840.1.113883.6.1')] is mandatory [min 1x]. (count(hl7:code[(@code='8339-4' and @codeSystem='2.16.840.1.113883.6.1')])&gt;=1 and not(hl7:code[(@code='8339-4' and @codeSystem='2.16.840.1.113883.6.1')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900425-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='8339-4' and @codeSystem='2.16.840.1.113883.6.1')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Geboortegewicht): element hl7:code[(@code='8339-4' and @codeSystem='2.16.840.1.113883.6.1')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='8339-4' and @codeSystem='2.16.840.1.113883.6.1')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900425-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(Geboortegewicht): element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900425-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Geboortegewicht): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900425-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-453840-851924-759966-266763-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:procedure/hl7:code/@code='Baring']/hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='8339-4' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation/hl7:code[(@code='8339-4' and @codeSystem='2.16.840.1.113883.6.1')]"
                 priority="1125"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='8339-4' and @codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <xsl:message>(Geboortegewicht): de elementwaarde MOET zijn code '8339-4' codeSystem '2.16.840.1.113883.6.1'. (@nullFlavor or (@code='8339-4' and @codeSystem='2.16.840.1.113883.6.1') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900425-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-991497-356060-481660-878677-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:procedure/hl7:code/@code='Baring']/hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='8339-4' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation/hl7:value"
                 priority="1124"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (@unit='g' and number($theValue)&gt;=0 and (matches(string($theValue), '^[-+]?[0-9]*$'))))"/>
         <xsl:otherwise>
            <xsl:message>(Geboortegewicht): value MOET eenheid 'g' gebruiken en in bereik [0..] liggen  en tot op minstens 0 decimalen nauwkeurig zijn  ((@nullFlavor or (@unit='g' and number($theValue)&gt;=0 and (matches(string($theValue), '^[-+]?[0-9]*$')))) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900425-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-828731-230218-479857-104852-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:procedure/hl7:code/@code='Baring']/hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='301334000' and @codeSystem='2.16.840.1.113883.6.96')]]]"
                 priority="1123"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(Uitkomstperkindsubjectkort): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900624-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-934746-382486-463251-934584-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:procedure/hl7:code/@code='Baring']/hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='301334000' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation"
                 priority="1122"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(PercentielGeboortegewicht): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900902-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(PercentielGeboortegewicht): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900902-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='301334000' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='301334000' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(PercentielGeboortegewicht): element hl7:code[(@code='301334000' and @codeSystem='2.16.840.1.113883.6.96')] is mandatory [min 1x]. (count(hl7:code[(@code='301334000' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='301334000' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900902-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='301334000' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PercentielGeboortegewicht): element hl7:code[(@code='301334000' and @codeSystem='2.16.840.1.113883.6.96')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='301334000' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900902-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='4' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='6' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or @nullFlavor='NI'])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(PercentielGeboortegewicht): element hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='4' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='6' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or @nullFlavor='NI'] is required [min 1x]. (count(hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='4' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='6' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or @nullFlavor='NI'])&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900902-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='4' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='6' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or @nullFlavor='NI'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PercentielGeboortegewicht): element hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='4' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='6' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or @nullFlavor='NI'] komt te vaak voor [max 1x]. (count(hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='4' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='6' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or @nullFlavor='NI'])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900902-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-729971-339809-231944-108568-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:procedure/hl7:code/@code='Baring']/hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='301334000' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:code[(@code='301334000' and @codeSystem='2.16.840.1.113883.6.96')]"
                 priority="1121"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='301334000' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>(PercentielGeboortegewicht): de elementwaarde MOET zijn code '301334000' codeSystem '2.16.840.1.113883.6.96'. (@nullFlavor or (@code='301334000' and @codeSystem='2.16.840.1.113883.6.96') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900902-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-229169-288848-966298-814755-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:procedure/hl7:code/@code='Baring']/hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='301334000' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='4' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or (@code='6' and @codeSystem='2.16.840.1.113883.2.4.4.13.50') or @nullFlavor='NI']"
                 priority="1120"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="validCodeOrCodeSystemFound"
                    select="concat(exists(document('include/voc-2.16.840.1.113883.2.4.11.176-2013-11-08T000000.xml')/*/valueSet[conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-2.16.840.1.113883.2.4.11.176-2013-11-08T000000.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>
      <xsl:variable name="explicitExceptions" select="''"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or contains($validCodeOrCodeSystemFound,'true')"/>
         <xsl:otherwise>
            <xsl:message>(PercentielGeboortegewicht): de waarde van @code MOET worden gekozen uit waardenlijst PercentielGeboortegewicht (2013-11-08T00:00:00). NB: codeSystemVersion MOET exact overeenkomen indien gespecificeerd in de waardenlijst. (@nullFlavor or contains($validCodeOrCodeSystemFound,'true') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900902-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|'))"/>
         <xsl:otherwise>
            <xsl:message>(PercentielGeboortegewicht): de nulwaarde voor @code MOET komen uit de set die is gedefinieerd voor dit attribuut of zijn gekoppeld aan waardenlijst PercentielGeboortegewicht (2013-11-08T00:00:00). (not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|')) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900902-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-115022-528208-333680-757352-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:procedure/hl7:code/@code='Baring']/hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='9274-2' and @codeSystem='2.16.840.1.113883.6.1')]]]"
                 priority="1119"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(Uitkomstperkindsubjectkort): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900624-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-268768-913928-987271-519516-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:procedure/hl7:code/@code='Baring']/hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='9274-2' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation"
                 priority="1118"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(Apgarscorena5min): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900294-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(Apgarscorena5min): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900294-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='9274-2' and @codeSystem='2.16.840.1.113883.6.1')])&gt;=1 and not(hl7:code[(@code='9274-2' and @codeSystem='2.16.840.1.113883.6.1')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Apgarscorena5min): element hl7:code[(@code='9274-2' and @codeSystem='2.16.840.1.113883.6.1')] is mandatory [min 1x]. (count(hl7:code[(@code='9274-2' and @codeSystem='2.16.840.1.113883.6.1')])&gt;=1 and not(hl7:code[(@code='9274-2' and @codeSystem='2.16.840.1.113883.6.1')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900294-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='9274-2' and @codeSystem='2.16.840.1.113883.6.1')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Apgarscorena5min): element hl7:code[(@code='9274-2' and @codeSystem='2.16.840.1.113883.6.1')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='9274-2' and @codeSystem='2.16.840.1.113883.6.1')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900294-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(Apgarscorena5min): element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900294-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Apgarscorena5min): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900294-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-761950-927438-629460-989439-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:procedure/hl7:code/@code='Baring']/hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='9274-2' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation/hl7:code[(@code='9274-2' and @codeSystem='2.16.840.1.113883.6.1')]"
                 priority="1117"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='9274-2' and @codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <xsl:message>(Apgarscorena5min): de elementwaarde MOET zijn code '9274-2' codeSystem '2.16.840.1.113883.6.1'. (@nullFlavor or (@code='9274-2' and @codeSystem='2.16.840.1.113883.6.1') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900294-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-365585-505372-777426-781256-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:procedure/hl7:code/@code='Baring']/hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='9274-2' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation/hl7:value"
                 priority="1116"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (number($theValue)&gt;=0 and number($theValue)&lt;=10))"/>
         <xsl:otherwise>
            <xsl:message>(Apgarscorena5min): value MOET in bereik [0..10] liggen   ((@nullFlavor or (number($theValue)&gt;=0 and number($theValue)&lt;=10)) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900294-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-566322-735776-877215-337385-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:procedure/hl7:code/@code='Baring']/hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='66091009' and @codeSystem='2.16.840.1.113883.6.96')]]]"
                 priority="1115"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(Uitkomstperkindsubjectkort): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900624-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-904586-839013-430395-940546-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:procedure/hl7:code/@code='Baring']/hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='66091009' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation"
                 priority="1114"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(CongenitaleafwijkingenJN): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900909-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(CongenitaleafwijkingenJN): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900909-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or hl7:value"/>
         <xsl:otherwise>
            <xsl:message>(CongenitaleafwijkingenJN): Value is verplicht bij congenitale afwijkingen. (@nullFlavor or hl7:value / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900909-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='66091009' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='66091009' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(CongenitaleafwijkingenJN): element hl7:code[(@code='66091009' and @codeSystem='2.16.840.1.113883.6.96')] is mandatory [min 1x]. (count(hl7:code[(@code='66091009' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='66091009' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900909-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='66091009' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CongenitaleafwijkingenJN): element hl7:code[(@code='66091009' and @codeSystem='2.16.840.1.113883.6.96')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='66091009' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900909-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CongenitaleafwijkingenJN): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900909-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-487641-678460-570433-792700-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:procedure/hl7:code/@code='Baring']/hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='66091009' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:code[(@code='66091009' and @codeSystem='2.16.840.1.113883.6.96')]"
                 priority="1113"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='66091009' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>(CongenitaleafwijkingenJN): de elementwaarde MOET zijn code '66091009' codeSystem '2.16.840.1.113883.6.96'. (@nullFlavor or (@code='66091009' and @codeSystem='2.16.840.1.113883.6.96') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900909-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-832330-873749-794861-528369-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:procedure/hl7:code/@code='Baring']/hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='66091009' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:value"
                 priority="1112"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-251389-404624-537736-921798-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:procedure/hl7:code/@code='Baring']/hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='LigGbrt' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')]]]"
                 priority="1111"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(Uitkomstperkindsubjectkort): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900624-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-111717-141595-235054-156297-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:procedure/hl7:code/@code='Baring']/hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='LigGbrt' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')]]]/hl7:observation"
                 priority="1110"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(Liggingbijgeboorte): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900359-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(Liggingbijgeboorte): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900359-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='LigGbrt' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')])&gt;=1 and not(hl7:code[(@code='LigGbrt' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Liggingbijgeboorte): element hl7:code[(@code='LigGbrt' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')] is mandatory [min 1x]. (count(hl7:code[(@code='LigGbrt' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')])&gt;=1 and not(hl7:code[(@code='LigGbrt' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900359-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='LigGbrt' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Liggingbijgeboorte): element hl7:code[(@code='LigGbrt' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='LigGbrt' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900359-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or (@code='4' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or (@code='6' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or (@code='11' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or (@code='12' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or (@code='13' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI'])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(Liggingbijgeboorte): element hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or (@code='4' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or (@code='6' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or (@code='11' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or (@code='12' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or (@code='13' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI'] is required [min 1x]. (count(hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or (@code='4' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or (@code='6' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or (@code='11' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or (@code='12' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or (@code='13' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI'])&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900359-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or (@code='4' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or (@code='6' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or (@code='11' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or (@code='12' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or (@code='13' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Liggingbijgeboorte): element hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or (@code='4' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or (@code='6' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or (@code='11' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or (@code='12' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or (@code='13' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI'] komt te vaak voor [max 1x]. (count(hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or (@code='4' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or (@code='6' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or (@code='11' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or (@code='12' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or (@code='13' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI'])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900359-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-754169-657874-268371-761227-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:procedure/hl7:code/@code='Baring']/hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='LigGbrt' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')]]]/hl7:observation/hl7:code[(@code='LigGbrt' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')]"
                 priority="1109"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='LigGbrt' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')"/>
         <xsl:otherwise>
            <xsl:message>(Liggingbijgeboorte): de elementwaarde MOET zijn code 'LigGbrt' codeSystem '2.16.840.1.113883.2.4.3.22.1.1'. (@nullFlavor or (@code='LigGbrt' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900359-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-933413-327592-878350-456082-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:procedure/hl7:code/@code='Baring']/hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='LigGbrt' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')]]]/hl7:observation/hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or (@code='4' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or (@code='6' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or (@code='11' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or (@code='12' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or (@code='13' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.2.50') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI']"
                 priority="1108"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="validCodeOrCodeSystemFound"
                    select="concat(exists(document('include/voc-2.16.840.1.113883.2.4.11.33-DYNAMIC.xml')/*/valueSet[conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-2.16.840.1.113883.2.4.11.33-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>
      <xsl:variable name="explicitExceptions" select="''"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or contains($validCodeOrCodeSystemFound,'true')"/>
         <xsl:otherwise>
            <xsl:message>(Liggingbijgeboorte): de waarde van @code MOET worden gekozen uit waardenlijst LiggingBijGeboorte (DYNAMISCH). NB: codeSystemVersion MOET exact overeenkomen indien gespecificeerd in de waardenlijst. (@nullFlavor or contains($validCodeOrCodeSystemFound,'true') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900359-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|'))"/>
         <xsl:otherwise>
            <xsl:message>(Liggingbijgeboorte): de nulwaarde voor @code MOET komen uit de set die is gedefinieerd voor dit attribuut of zijn gekoppeld aan waardenlijst LiggingBijGeboorte (DYNAMISCH). (not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|')) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900359-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-796195-160231-145293-119706-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:procedure/hl7:code/@code='Baring']/hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='Interv' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')]]]"
                 priority="1107"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(Uitkomstperkindsubjectkort): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900624-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="if (count(//hl7:inboundRelationship[hl7:observation[@negationInd='true' or @nullFlavor]/hl7:code/@code='Interv']) &gt;=1)                          then count(../hl7:inboundRelationship[hl7:observation/hl7:code/@code='Interv'])=1                          else 1=1"/>
         <xsl:otherwise>
            <xsl:message>(Uitkomstperkindsubjectkort): Als er geen overige interventies zijn, mag het element met overige interventies maar één maal voorkomen. (if (count(//hl7:inboundRelationship[hl7:observation[@negationInd='true' or @nullFlavor]/hl7:code/@code='Interv']) &gt;=1) then count(../hl7:inboundRelationship[hl7:observation/hl7:code/@code='Interv'])=1 else 1=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900624-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-209258-569227-907729-643548-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:procedure/hl7:code/@code='Baring']/hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='Interv' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')]]]/hl7:observation"
                 priority="1106"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(Overigeinterventies): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900893-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(Overigeinterventies): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900893-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@negationInd='true' or @nullFlavor or hl7:value"/>
         <xsl:otherwise>
            <xsl:message>(Overigeinterventies): If Overige interventies a value shall be present (@negationInd='true' or @nullFlavor or hl7:value / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900893-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:value) or (@negationInd='false' or not(@negationInd) and not(@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>(Overigeinterventies): Geen value opnemen wanneer er geen overige interventies zijn. (not(hl7:value) or (@negationInd='false' or not(@negationInd) and not(@nullFlavor)) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900893-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='Interv' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')])&gt;=1 and not(hl7:code[(@code='Interv' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Overigeinterventies): element hl7:code[(@code='Interv' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')] is mandatory [min 1x]. (count(hl7:code[(@code='Interv' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')])&gt;=1 and not(hl7:code[(@code='Interv' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900893-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='Interv' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Overigeinterventies): element hl7:code[(@code='Interv' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='Interv' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900893-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Overigeinterventies): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900893-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-601516-436692-653503-397954-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:procedure/hl7:code/@code='Baring']/hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='Interv' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')]]]/hl7:observation/hl7:code[(@code='Interv' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')]"
                 priority="1105"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='Interv' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')"/>
         <xsl:otherwise>
            <xsl:message>(Overigeinterventies): de elementwaarde MOET zijn code 'Interv' codeSystem '2.16.840.1.113883.2.4.3.22.1.1'. (@nullFlavor or (@code='Interv' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900893-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-640352-526143-923356-194733-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:procedure/hl7:code/@code='Baring']/hl7:procedure[hl7:code[(@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')]]/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='Interv' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')]]]/hl7:observation/hl7:value"
                 priority="1104"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="validCodeOrCodeSystemFound"
                    select="concat(exists(document('include/voc-2.16.840.1.113883.2.4.11.40-DYNAMIC.xml')/*/valueSet[conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-2.16.840.1.113883.2.4.11.40-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>
      <xsl:variable name="explicitExceptions" select="''"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or contains($validCodeOrCodeSystemFound,'true')"/>
         <xsl:otherwise>
            <xsl:message>(Overigeinterventies): de waarde van @code MOET worden gekozen uit waardenlijst OverigeInterventies (DYNAMISCH). NB: codeSystemVersion MOET exact overeenkomen indien gespecificeerd in de waardenlijst. (@nullFlavor or contains($validCodeOrCodeSystemFound,'true') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900893-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|'))"/>
         <xsl:otherwise>
            <xsl:message>(Overigeinterventies): de nulwaarde voor @code MOET komen uit de set die is gedefinieerd voor dit attribuut of zijn gekoppeld aan waardenlijst OverigeInterventies (DYNAMISCH). (not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|')) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900893-2009-10-01T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-244059-155462-347870-231854-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')]]]"
                 priority="1103"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:organizer[hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')]])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(FetusSpecificInformation): element hl7:organizer[hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')]] is required [min 1x]. (count(hl7:organizer[hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')]])&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900862-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:organizer[hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FetusSpecificInformation): element hl7:organizer[hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')]] komt te vaak voor [max 1x]. (count(hl7:organizer[hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900862-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='PERT'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @typeCode MOET 'PERT' zijn. (string(@typeCode)='PERT' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@contextConductionInd)='false'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @contextConductionInd MOET 'false' zijn. (string(@contextConductionInd)='false' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-602815-536730-742588-561792-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:organizer"
                 priority="1101"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='CONTAINER'"/>
         <xsl:otherwise>
            <xsl:message>(FetusSpecificInformation): de waarde van @classCode MOET 'CONTAINER' zijn. (string(@classCode)='CONTAINER' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900862-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(FetusSpecificInformation): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900862-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')])&gt;=1 and not(hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(FetusSpecificInformation): element hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')] is mandatory [min 1x]. (count(hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')])&gt;=1 and not(hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900862-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FetusSpecificInformation): element hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900862-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:effectiveTime)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(FetusSpecificInformation): element hl7:effectiveTime is required [min 1x]. (count(hl7:effectiveTime)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900862-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:effectiveTime)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FetusSpecificInformation): element hl7:effectiveTime komt te vaak voor [max 1x]. (count(hl7:effectiveTime)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900862-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:subject[hl7:personalRelationship[hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')]]])&gt;=1 and not(hl7:subject[hl7:personalRelationship[hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')]]]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(FetusSpecificInformation): element hl7:subject[hl7:personalRelationship[hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')]]] is mandatory [min 1x]. (count(hl7:subject[hl7:personalRelationship[hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')]]])&gt;=1 and not(hl7:subject[hl7:personalRelationship[hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')]]]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900862-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:subject[hl7:personalRelationship[hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FetusSpecificInformation): element hl7:subject[hl7:personalRelationship[hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')]]] komt te vaak voor [max 1x]. (count(hl7:subject[hl7:personalRelationship[hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900862-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:observation[hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FetusSpecificInformation): element hl7:component[hl7:observation[hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')]]] komt te vaak voor [max 1x]. (count(hl7:component[hl7:observation[hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900862-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:observation[hl7:code[(@code='11820-8' and @codeSystem='2.16.840.1.113883.6.1')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FetusSpecificInformation): element hl7:component[hl7:observation[hl7:code[(@code='11820-8' and @codeSystem='2.16.840.1.113883.6.1')]]] komt te vaak voor [max 1x]. (count(hl7:component[hl7:observation[hl7:code[(@code='11820-8' and @codeSystem='2.16.840.1.113883.6.1')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900862-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:observation[hl7:code[(@code='X_BPD_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FetusSpecificInformation): element hl7:component[hl7:observation[hl7:code[(@code='X_BPD_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')]]] komt te vaak voor [max 1x]. (count(hl7:component[hl7:observation[hl7:code[(@code='X_BPD_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900862-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:observation[hl7:code[(@code='11984-2' and @codeSystem='2.16.840.1.113883.6.1')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FetusSpecificInformation): element hl7:component[hl7:observation[hl7:code[(@code='11984-2' and @codeSystem='2.16.840.1.113883.6.1')]]] komt te vaak voor [max 1x]. (count(hl7:component[hl7:observation[hl7:code[(@code='11984-2' and @codeSystem='2.16.840.1.113883.6.1')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900862-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:observation[hl7:code[(@code='X_HC_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FetusSpecificInformation): element hl7:component[hl7:observation[hl7:code[(@code='X_HC_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')]]] komt te vaak voor [max 1x]. (count(hl7:component[hl7:observation[hl7:code[(@code='X_HC_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900862-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:observation[hl7:code[(@code='11979-2' and @codeSystem='2.16.840.1.113883.6.1')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FetusSpecificInformation): element hl7:component[hl7:observation[hl7:code[(@code='11979-2' and @codeSystem='2.16.840.1.113883.6.1')]]] komt te vaak voor [max 1x]. (count(hl7:component[hl7:observation[hl7:code[(@code='11979-2' and @codeSystem='2.16.840.1.113883.6.1')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900862-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:observation[hl7:code[(@code='X_AC_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FetusSpecificInformation): element hl7:component[hl7:observation[hl7:code[(@code='X_AC_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')]]] komt te vaak voor [max 1x]. (count(hl7:component[hl7:observation[hl7:code[(@code='X_AC_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900862-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:observation[hl7:code[(@code='11963-6' and @codeSystem='2.16.840.1.113883.6.1')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FetusSpecificInformation): element hl7:component[hl7:observation[hl7:code[(@code='11963-6' and @codeSystem='2.16.840.1.113883.6.1')]]] komt te vaak voor [max 1x]. (count(hl7:component[hl7:observation[hl7:code[(@code='11963-6' and @codeSystem='2.16.840.1.113883.6.1')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900862-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:observation[hl7:code[(@code='X_FL_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FetusSpecificInformation): element hl7:component[hl7:observation[hl7:code[(@code='X_FL_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')]]] komt te vaak voor [max 1x]. (count(hl7:component[hl7:observation[hl7:code[(@code='X_FL_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900862-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-108495-507490-238159-952101-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:organizer/hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')]"
                 priority="1100"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <xsl:message>(FetusSpecificInformation): de elementwaarde MOET zijn code '12130-1' codeSystem '2.16.840.1.113883.6.1'. (@nullFlavor or (@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900862-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-533790-380796-334442-775710-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:organizer/hl7:effectiveTime"
                 priority="1099"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-130654-717586-259055-858218-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:organizer/hl7:subject[hl7:personalRelationship[hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')]]]"
                 priority="1098"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='SBJ'"/>
         <xsl:otherwise>
            <xsl:message>(FetusSpecificInformation): de waarde van @typeCode MOET 'SBJ' zijn. (string(@typeCode)='SBJ' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900862-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:personalRelationship[hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')]])&gt;=1 and not(hl7:personalRelationship[hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')]]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(FetusSpecificInformation): element hl7:personalRelationship[hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')]] is mandatory [min 1x]. (count(hl7:personalRelationship[hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')]])&gt;=1 and not(hl7:personalRelationship[hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')]]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900862-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:personalRelationship[hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FetusSpecificInformation): element hl7:personalRelationship[hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')]] komt te vaak voor [max 1x]. (count(hl7:personalRelationship[hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900862-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-911388-738701-957122-703509-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:organizer/hl7:subject[hl7:personalRelationship[hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')]]]/hl7:personalRelationship"
                 priority="1097"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='PRS'"/>
         <xsl:otherwise>
            <xsl:message>(FetusSpecificInformation): de waarde van @classCode MOET 'PRS' zijn. (string(@classCode)='PRS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900862-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')])&gt;=1 and not(hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(FetusSpecificInformation): element hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')] is mandatory [min 1x]. (count(hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')])&gt;=1 and not(hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900862-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FetusSpecificInformation): element hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900862-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:relationshipHolder)&gt;=1 and not(hl7:relationshipHolder/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(FetusSpecificInformation): element hl7:relationshipHolder is mandatory [min 1x]. (count(hl7:relationshipHolder)&gt;=1 and not(hl7:relationshipHolder/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900862-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:relationshipHolder)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FetusSpecificInformation): element hl7:relationshipHolder komt te vaak voor [max 1x]. (count(hl7:relationshipHolder)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900862-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-984719-321010-793865-880805-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:organizer/hl7:subject[hl7:personalRelationship[hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')]]]/hl7:personalRelationship/hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')]"
                 priority="1096"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <xsl:message>(FetusSpecificInformation): de elementwaarde MOET zijn code 'CHILD' codeSystem '2.16.840.1.113883.5.111'. (@nullFlavor or (@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900862-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-753096-457402-530174-478181-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:organizer/hl7:subject[hl7:personalRelationship[hl7:code[(@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')]]]/hl7:personalRelationship/hl7:relationshipHolder"
                 priority="1095"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='PSN'"/>
         <xsl:otherwise>
            <xsl:message>(FetusSpecificInformation): de waarde van @classCode MOET 'PSN' zijn. (string(@classCode)='PSN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900862-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@determinerCode)='INSTANCE'"/>
         <xsl:otherwise>
            <xsl:message>(FetusSpecificInformation): de waarde van @determinerCode MOET 'INSTANCE' zijn. (string(@determinerCode)='INSTANCE' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900862-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-388351-755593-334986-558332-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')]]]"
                 priority="1094"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(FetusSpecificInformation): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900862-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@contextConductionInd)='true'"/>
         <xsl:otherwise>
            <xsl:message>(FetusSpecificInformation): de waarde van @contextConductionInd MOET 'true' zijn. (string(@contextConductionInd)='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900862-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-259724-734369-321202-346723-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation"
                 priority="1093"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(ZwangerschapsduurOpDatumOnderzoek): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900236-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(ZwangerschapsduurOpDatumOnderzoek): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900236-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(ZwangerschapsduurOpDatumOnderzoek): element hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')] is mandatory [min 1x]. (count(hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900236-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ZwangerschapsduurOpDatumOnderzoek): element hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900236-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(ZwangerschapsduurOpDatumOnderzoek): element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900236-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ZwangerschapsduurOpDatumOnderzoek): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900236-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-406636-995562-720928-704995-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')]"
                 priority="1092"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>(ZwangerschapsduurOpDatumOnderzoek): de elementwaarde MOET zijn code '445872007' codeSystem '2.16.840.1.113883.6.96'. (@nullFlavor or (@code='445872007' and @codeSystem='2.16.840.1.113883.6.96') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900236-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-485739-155457-491376-445416-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:value"
                 priority="1091"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (@unit='d' and number($theValue)&gt;=0))"/>
         <xsl:otherwise>
            <xsl:message>(ZwangerschapsduurOpDatumOnderzoek): value MOET eenheid 'd' gebruiken en in bereik [0..] liggen   ((@nullFlavor or (@unit='d' and number($theValue)&gt;=0)) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900236-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-353006-829940-302781-881487-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='11820-8' and @codeSystem='2.16.840.1.113883.6.1')]]]"
                 priority="1090"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(FetusSpecificInformation): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900862-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@contextConductionInd)='true'"/>
         <xsl:otherwise>
            <xsl:message>(FetusSpecificInformation): de waarde van @contextConductionInd MOET 'true' zijn. (string(@contextConductionInd)='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900862-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-924939-849944-964143-280323-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='11820-8' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation"
                 priority="1089"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(BiparitalDiameter): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900821-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(BiparitalDiameter): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900821-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='11820-8' and @codeSystem='2.16.840.1.113883.6.1')])&gt;=1 and not(hl7:code[(@code='11820-8' and @codeSystem='2.16.840.1.113883.6.1')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(BiparitalDiameter): element hl7:code[(@code='11820-8' and @codeSystem='2.16.840.1.113883.6.1')] is mandatory [min 1x]. (count(hl7:code[(@code='11820-8' and @codeSystem='2.16.840.1.113883.6.1')])&gt;=1 and not(hl7:code[(@code='11820-8' and @codeSystem='2.16.840.1.113883.6.1')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900821-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='11820-8' and @codeSystem='2.16.840.1.113883.6.1')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(BiparitalDiameter): element hl7:code[(@code='11820-8' and @codeSystem='2.16.840.1.113883.6.1')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='11820-8' and @codeSystem='2.16.840.1.113883.6.1')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900821-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(BiparitalDiameter): element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900821-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(BiparitalDiameter): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900821-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-705310-971476-124161-985564-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='11820-8' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation/hl7:code[(@code='11820-8' and @codeSystem='2.16.840.1.113883.6.1')]"
                 priority="1088"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='11820-8' and @codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <xsl:message>(BiparitalDiameter): de elementwaarde MOET zijn code '11820-8' codeSystem '2.16.840.1.113883.6.1'. (@nullFlavor or (@code='11820-8' and @codeSystem='2.16.840.1.113883.6.1') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900821-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-986268-415443-264798-150940-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='11820-8' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation/hl7:value"
                 priority="1087"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (@unit='mm' and (matches(string($theValue), '^[-+]?[0-9]*\.[0-9]{1,99}$'))))"/>
         <xsl:otherwise>
            <xsl:message>(BiparitalDiameter): value MOET eenheid 'mm' gebruiken en tot op minstens 1 decimalen nauwkeurig zijn  ((@nullFlavor or (@unit='mm' and (matches(string($theValue), '^[-+]?[0-9]*\.[0-9]{1,99}$')))) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900821-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-596377-822201-898655-668473-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='X_BPD_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')]]]"
                 priority="1086"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(FetusSpecificInformation): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900862-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@contextConductionInd)='true'"/>
         <xsl:otherwise>
            <xsl:message>(FetusSpecificInformation): de waarde van @contextConductionInd MOET 'true' zijn. (string(@contextConductionInd)='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900862-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-209041-848962-396406-330822-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='X_BPD_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation"
                 priority="1085"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(BiparitalDiameterPercentile): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900506-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(BiparitalDiameterPercentile): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900506-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='X_BPD_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')])&gt;=1 and not(hl7:code[(@code='X_BPD_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(BiparitalDiameterPercentile): element hl7:code[(@code='X_BPD_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')] is mandatory [min 1x]. (count(hl7:code[(@code='X_BPD_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')])&gt;=1 and not(hl7:code[(@code='X_BPD_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900506-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='X_BPD_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(BiparitalDiameterPercentile): element hl7:code[(@code='X_BPD_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='X_BPD_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900506-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(BiparitalDiameterPercentile): element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900506-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(BiparitalDiameterPercentile): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900506-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-113848-235541-409747-698411-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='X_BPD_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation/hl7:code[(@code='X_BPD_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')]"
                 priority="1084"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='X_BPD_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <xsl:message>(BiparitalDiameterPercentile): de elementwaarde MOET zijn code 'X_BPD_PRCTL' codeSystem '2.16.840.1.113883.6.1'. (@nullFlavor or (@code='X_BPD_PRCTL' and @codeSystem='2.16.840.1.113883.6.1') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900506-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-794249-259385-885290-313171-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='X_BPD_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation/hl7:value"
                 priority="1083"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (@unit='%' and number($theValue)&gt;=0))"/>
         <xsl:otherwise>
            <xsl:message>(BiparitalDiameterPercentile): value MOET eenheid '%' gebruiken en in bereik [0..] liggen   ((@nullFlavor or (@unit='%' and number($theValue)&gt;=0)) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900506-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-398823-254353-745050-168121-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='11984-2' and @codeSystem='2.16.840.1.113883.6.1')]]]"
                 priority="1082"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(FetusSpecificInformation): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900862-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@contextConductionInd)='true'"/>
         <xsl:otherwise>
            <xsl:message>(FetusSpecificInformation): de waarde van @contextConductionInd MOET 'true' zijn. (string(@contextConductionInd)='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900862-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-212261-102078-867763-326019-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='11984-2' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation"
                 priority="1081"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(HeadCircumference): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900533-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(HeadCircumference): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900533-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='11984-2' and @codeSystem='2.16.840.1.113883.6.1')])&gt;=1 and not(hl7:code[(@code='11984-2' and @codeSystem='2.16.840.1.113883.6.1')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(HeadCircumference): element hl7:code[(@code='11984-2' and @codeSystem='2.16.840.1.113883.6.1')] is mandatory [min 1x]. (count(hl7:code[(@code='11984-2' and @codeSystem='2.16.840.1.113883.6.1')])&gt;=1 and not(hl7:code[(@code='11984-2' and @codeSystem='2.16.840.1.113883.6.1')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900533-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='11984-2' and @codeSystem='2.16.840.1.113883.6.1')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HeadCircumference): element hl7:code[(@code='11984-2' and @codeSystem='2.16.840.1.113883.6.1')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='11984-2' and @codeSystem='2.16.840.1.113883.6.1')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900533-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(HeadCircumference): element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900533-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HeadCircumference): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900533-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-214956-937597-247506-566352-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='11984-2' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation/hl7:code[(@code='11984-2' and @codeSystem='2.16.840.1.113883.6.1')]"
                 priority="1080"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='11984-2' and @codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <xsl:message>(HeadCircumference): de elementwaarde MOET zijn code '11984-2' codeSystem '2.16.840.1.113883.6.1'. (@nullFlavor or (@code='11984-2' and @codeSystem='2.16.840.1.113883.6.1') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900533-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-953698-541812-433423-726844-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='11984-2' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation/hl7:value"
                 priority="1079"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (@unit='mm' and (matches(string($theValue), '^[-+]?[0-9]*\.[0-9]{1,99}$'))))"/>
         <xsl:otherwise>
            <xsl:message>(HeadCircumference): value MOET eenheid 'mm' gebruiken en tot op minstens 1 decimalen nauwkeurig zijn  ((@nullFlavor or (@unit='mm' and (matches(string($theValue), '^[-+]?[0-9]*\.[0-9]{1,99}$')))) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900533-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-567853-809919-873806-806099-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='X_HC_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')]]]"
                 priority="1078"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(FetusSpecificInformation): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900862-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@contextConductionInd)='true'"/>
         <xsl:otherwise>
            <xsl:message>(FetusSpecificInformation): de waarde van @contextConductionInd MOET 'true' zijn. (string(@contextConductionInd)='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900862-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-692798-989361-255554-919498-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='X_HC_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation"
                 priority="1077"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(HeadCircumferencePercentile): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900510-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(HeadCircumferencePercentile): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900510-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='X_HC_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')])&gt;=1 and not(hl7:code[(@code='X_HC_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(HeadCircumferencePercentile): element hl7:code[(@code='X_HC_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')] is mandatory [min 1x]. (count(hl7:code[(@code='X_HC_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')])&gt;=1 and not(hl7:code[(@code='X_HC_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900510-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='X_HC_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HeadCircumferencePercentile): element hl7:code[(@code='X_HC_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='X_HC_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900510-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(HeadCircumferencePercentile): element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900510-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HeadCircumferencePercentile): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900510-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-140207-627372-909155-269430-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='X_HC_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation/hl7:code[(@code='X_HC_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')]"
                 priority="1076"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='X_HC_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <xsl:message>(HeadCircumferencePercentile): de elementwaarde MOET zijn code 'X_HC_PRCTL' codeSystem '2.16.840.1.113883.6.1'. (@nullFlavor or (@code='X_HC_PRCTL' and @codeSystem='2.16.840.1.113883.6.1') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900510-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-834500-212916-691524-524735-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='X_HC_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation/hl7:value"
                 priority="1075"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (@unit='%' and number($theValue)&gt;=0))"/>
         <xsl:otherwise>
            <xsl:message>(HeadCircumferencePercentile): value MOET eenheid '%' gebruiken en in bereik [0..] liggen   ((@nullFlavor or (@unit='%' and number($theValue)&gt;=0)) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900510-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-201543-975040-950302-278751-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='11979-2' and @codeSystem='2.16.840.1.113883.6.1')]]]"
                 priority="1074"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(FetusSpecificInformation): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900862-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@contextConductionInd)='true'"/>
         <xsl:otherwise>
            <xsl:message>(FetusSpecificInformation): de waarde van @contextConductionInd MOET 'true' zijn. (string(@contextConductionInd)='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900862-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-848284-966702-705981-505011-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='11979-2' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation"
                 priority="1073"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(AbdominalCircumference): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900535-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(AbdominalCircumference): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900535-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='11979-2' and @codeSystem='2.16.840.1.113883.6.1')])&gt;=1 and not(hl7:code[(@code='11979-2' and @codeSystem='2.16.840.1.113883.6.1')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(AbdominalCircumference): element hl7:code[(@code='11979-2' and @codeSystem='2.16.840.1.113883.6.1')] is mandatory [min 1x]. (count(hl7:code[(@code='11979-2' and @codeSystem='2.16.840.1.113883.6.1')])&gt;=1 and not(hl7:code[(@code='11979-2' and @codeSystem='2.16.840.1.113883.6.1')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900535-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='11979-2' and @codeSystem='2.16.840.1.113883.6.1')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(AbdominalCircumference): element hl7:code[(@code='11979-2' and @codeSystem='2.16.840.1.113883.6.1')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='11979-2' and @codeSystem='2.16.840.1.113883.6.1')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900535-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(AbdominalCircumference): element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900535-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(AbdominalCircumference): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900535-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-871487-660950-226177-222340-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='11979-2' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation/hl7:code[(@code='11979-2' and @codeSystem='2.16.840.1.113883.6.1')]"
                 priority="1072"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='11979-2' and @codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <xsl:message>(AbdominalCircumference): de elementwaarde MOET zijn code '11979-2' codeSystem '2.16.840.1.113883.6.1'. (@nullFlavor or (@code='11979-2' and @codeSystem='2.16.840.1.113883.6.1') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900535-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-705869-192359-148277-398964-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='11979-2' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation/hl7:value"
                 priority="1071"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (@unit='mm' and number($theValue)&gt;=0 and (matches(string($theValue), '^[-+]?[0-9]*\.[0-9]{1,99}$'))))"/>
         <xsl:otherwise>
            <xsl:message>(AbdominalCircumference): value MOET eenheid 'mm' gebruiken en in bereik [0..] liggen  en tot op minstens 1 decimalen nauwkeurig zijn  ((@nullFlavor or (@unit='mm' and number($theValue)&gt;=0 and (matches(string($theValue), '^[-+]?[0-9]*\.[0-9]{1,99}$')))) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900535-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-866386-650207-424140-217645-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='X_AC_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')]]]"
                 priority="1070"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(FetusSpecificInformation): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900862-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@contextConductionInd)='true'"/>
         <xsl:otherwise>
            <xsl:message>(FetusSpecificInformation): de waarde van @contextConductionInd MOET 'true' zijn. (string(@contextConductionInd)='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900862-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-346341-307274-248258-389565-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='X_AC_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation"
                 priority="1069"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(AbdominalCircumferencePercentile): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900513-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(AbdominalCircumferencePercentile): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900513-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='X_AC_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')])&gt;=1 and not(hl7:code[(@code='X_AC_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(AbdominalCircumferencePercentile): element hl7:code[(@code='X_AC_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')] is mandatory [min 1x]. (count(hl7:code[(@code='X_AC_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')])&gt;=1 and not(hl7:code[(@code='X_AC_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900513-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='X_AC_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(AbdominalCircumferencePercentile): element hl7:code[(@code='X_AC_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='X_AC_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900513-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(AbdominalCircumferencePercentile): element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900513-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(AbdominalCircumferencePercentile): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900513-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-244539-811119-284557-333489-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='X_AC_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation/hl7:code[(@code='X_AC_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')]"
                 priority="1068"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='X_AC_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <xsl:message>(AbdominalCircumferencePercentile): de elementwaarde MOET zijn code 'X_AC_PRCTL' codeSystem '2.16.840.1.113883.6.1'. (@nullFlavor or (@code='X_AC_PRCTL' and @codeSystem='2.16.840.1.113883.6.1') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900513-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-300789-202269-780114-136920-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='X_AC_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation/hl7:value"
                 priority="1067"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (@unit='%' and number($theValue)&gt;=0))"/>
         <xsl:otherwise>
            <xsl:message>(AbdominalCircumferencePercentile): value MOET eenheid '%' gebruiken en in bereik [0..] liggen   ((@nullFlavor or (@unit='%' and number($theValue)&gt;=0)) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900513-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-453121-117267-977836-114287-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='11963-6' and @codeSystem='2.16.840.1.113883.6.1')]]]"
                 priority="1066"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(FetusSpecificInformation): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900862-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@contextConductionInd)='true'"/>
         <xsl:otherwise>
            <xsl:message>(FetusSpecificInformation): de waarde van @contextConductionInd MOET 'true' zijn. (string(@contextConductionInd)='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900862-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-250114-686408-914469-619503-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='11963-6' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation"
                 priority="1065"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(FemurLength): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900536-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(FemurLength): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900536-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='11963-6' and @codeSystem='2.16.840.1.113883.6.1')])&gt;=1 and not(hl7:code[(@code='11963-6' and @codeSystem='2.16.840.1.113883.6.1')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(FemurLength): element hl7:code[(@code='11963-6' and @codeSystem='2.16.840.1.113883.6.1')] is mandatory [min 1x]. (count(hl7:code[(@code='11963-6' and @codeSystem='2.16.840.1.113883.6.1')])&gt;=1 and not(hl7:code[(@code='11963-6' and @codeSystem='2.16.840.1.113883.6.1')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900536-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='11963-6' and @codeSystem='2.16.840.1.113883.6.1')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FemurLength): element hl7:code[(@code='11963-6' and @codeSystem='2.16.840.1.113883.6.1')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='11963-6' and @codeSystem='2.16.840.1.113883.6.1')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900536-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(FemurLength): element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900536-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FemurLength): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900536-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-409173-165325-999925-991079-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='11963-6' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation/hl7:code[(@code='11963-6' and @codeSystem='2.16.840.1.113883.6.1')]"
                 priority="1064"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='11963-6' and @codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <xsl:message>(FemurLength): de elementwaarde MOET zijn code '11963-6' codeSystem '2.16.840.1.113883.6.1'. (@nullFlavor or (@code='11963-6' and @codeSystem='2.16.840.1.113883.6.1') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900536-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-162188-747849-284907-354780-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='11963-6' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation/hl7:value"
                 priority="1063"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (@unit='mm' and (matches(string($theValue), '^[-+]?[0-9]*\.[0-9]{1,99}$'))))"/>
         <xsl:otherwise>
            <xsl:message>(FemurLength): value MOET eenheid 'mm' gebruiken en tot op minstens 1 decimalen nauwkeurig zijn  ((@nullFlavor or (@unit='mm' and (matches(string($theValue), '^[-+]?[0-9]*\.[0-9]{1,99}$')))) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900536-2011-01-28T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-684580-369437-757000-787296-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='X_FL_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')]]]"
                 priority="1062"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(FetusSpecificInformation): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900862-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@contextConductionInd)='true'"/>
         <xsl:otherwise>
            <xsl:message>(FetusSpecificInformation): de waarde van @contextConductionInd MOET 'true' zijn. (string(@contextConductionInd)='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900862-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-394913-424206-580574-580758-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='X_FL_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation"
                 priority="1061"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(FemurLengthPercentile): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900515-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(FemurLengthPercentile): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900515-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='X_FL_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')])&gt;=1 and not(hl7:code[(@code='X_FL_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(FemurLengthPercentile): element hl7:code[(@code='X_FL_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')] is mandatory [min 1x]. (count(hl7:code[(@code='X_FL_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')])&gt;=1 and not(hl7:code[(@code='X_FL_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900515-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='X_FL_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FemurLengthPercentile): element hl7:code[(@code='X_FL_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='X_FL_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900515-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(FemurLengthPercentile): element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900515-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FemurLengthPercentile): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900515-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-625828-396577-365698-556144-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='X_FL_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation/hl7:code[(@code='X_FL_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')]"
                 priority="1060"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='X_FL_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <xsl:message>(FemurLengthPercentile): de elementwaarde MOET zijn code 'X_FL_PRCTL' codeSystem '2.16.840.1.113883.6.1'. (@nullFlavor or (@code='X_FL_PRCTL' and @codeSystem='2.16.840.1.113883.6.1') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900515-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-454267-507693-974601-257440-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='X_FL_PRCTL' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation/hl7:value"
                 priority="1059"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (@unit='%' and number($theValue)&gt;=0))"/>
         <xsl:otherwise>
            <xsl:message>(FemurLengthPercentile): value MOET eenheid '%' gebruiken en in bereik [0..] liggen   ((@nullFlavor or (@unit='%' and number($theValue)&gt;=0)) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900515-2011-12-06T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-137957-490113-929518-129721-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='Echoparameters' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]"
                 priority="1058"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(FetusSpecificInformation): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900862-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@contextConductionInd)='true'"/>
         <xsl:otherwise>
            <xsl:message>(FetusSpecificInformation): de waarde van @contextConductionInd MOET 'true' zijn. (string(@contextConductionInd)='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900862-2013-03-14T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-481067-448046-452242-481901-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='Echoparameters' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation"
                 priority="1057"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(Echoparameters): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900910-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(Echoparameters): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900910-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='Echoparameters' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&gt;=1 and not(hl7:code[(@code='Echoparameters' and @codeSystem='2.16.840.1.113883.2.4.4.13')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(Echoparameters): element hl7:code[(@code='Echoparameters' and @codeSystem='2.16.840.1.113883.2.4.4.13')] is mandatory [min 1x]. (count(hl7:code[(@code='Echoparameters' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&gt;=1 and not(hl7:code[(@code='Echoparameters' and @codeSystem='2.16.840.1.113883.2.4.4.13')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900910-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='Echoparameters' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Echoparameters): element hl7:code[(@code='Echoparameters' and @codeSystem='2.16.840.1.113883.2.4.4.13')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='Echoparameters' and @codeSystem='2.16.840.1.113883.2.4.4.13')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900910-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(Echoparameters): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900910-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-431311-695171-983212-715786-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='Echoparameters' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:code[(@code='Echoparameters' and @codeSystem='2.16.840.1.113883.2.4.4.13')]"
                 priority="1056"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='Echoparameters' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>(Echoparameters): de elementwaarde MOET zijn code 'Echoparameters' codeSystem '2.16.840.1.113883.2.4.4.13'. (@nullFlavor or (@code='Echoparameters' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900910-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-265964-432332-509257-408423-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code[(@code='12130-1' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[(@code='Echoparameters' and @codeSystem='2.16.840.1.113883.2.4.4.13')]]]/hl7:observation/hl7:value"
                 priority="1055"
                 mode="M6">
      <xsl:variable name="theValue" select="text()"/>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-709788-703264-527200-665059-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code/@code='12131-9']]"
                 priority="1054"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(MaternaalOnderzoek): element hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]] is required [min 1x]. (count(hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]])&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900919-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MaternaalOnderzoek): element hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]] komt te vaak voor [max 1x]. (count(hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900919-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='PERT'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @typeCode MOET 'PERT' zijn. (string(@typeCode)='PERT' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@contextConductionInd)='true'"/>
         <xsl:otherwise>
            <xsl:message>(acufov): de waarde van @contextConductionInd MOET 'true' zijn. (string(@contextConductionInd)='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.63-2013-11-08T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-618443-805783-367162-226398-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code/@code='12131-9']]/hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]]"
                 priority="1052"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='CONTAINER'"/>
         <xsl:otherwise>
            <xsl:message>(MaternaalOnderzoek): de waarde van @classCode MOET 'CONTAINER' zijn. (string(@classCode)='CONTAINER' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900919-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(MaternaalOnderzoek): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900919-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')])&gt;=1 and not(hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(MaternaalOnderzoek): element hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')] is mandatory [min 1x]. (count(hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')])&gt;=1 and not(hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900919-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MaternaalOnderzoek): element hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900919-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:observation[hl7:code[(@code='59260-0' and @codeSystem='2.16.840.1.113883.6.1')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MaternaalOnderzoek): element hl7:component[hl7:observation[hl7:code[(@code='59260-0' and @codeSystem='2.16.840.1.113883.6.1')]]] komt te vaak voor [max 1x]. (count(hl7:component[hl7:observation[hl7:code[(@code='59260-0' and @codeSystem='2.16.840.1.113883.6.1')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900919-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:observation[hl7:code[(@code='X_RHFETBM' and @codeSystem='2.16.840.1.113883.6.1')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MaternaalOnderzoek): element hl7:component[hl7:observation[hl7:code[(@code='X_RHFETBM' and @codeSystem='2.16.840.1.113883.6.1')]]] komt te vaak voor [max 1x]. (count(hl7:component[hl7:observation[hl7:code[(@code='X_RHFETBM' and @codeSystem='2.16.840.1.113883.6.1')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900919-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-981904-558428-357376-331636-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code/@code='12131-9']]/hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]]/hl7:code"
                 priority="1051"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <xsl:message>(MaternaalOnderzoek): de elementwaarde MOET zijn code '12131-9' codeSystem '2.16.840.1.113883.6.1'. (@nullFlavor or (@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900919-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-988645-297521-688198-343145-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code/@code='12131-9']]/hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]]/hl7:component[hl7:observation[hl7:code[(@code='59260-0' and @codeSystem='2.16.840.1.113883.6.1')]]]"
                 priority="1050"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(MaternaalOnderzoek): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900919-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@contextConductionInd)='true'"/>
         <xsl:otherwise>
            <xsl:message>(MaternaalOnderzoek): de waarde van @contextConductionInd MOET 'true' zijn. (string(@contextConductionInd)='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900919-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-401644-976111-633023-392148-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code/@code='12131-9']]/hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]]/hl7:component[hl7:observation[hl7:code[(@code='59260-0' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation"
                 priority="1049"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(MtrnlHb): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900920-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(MtrnlHb): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900920-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='59260-0' and @codeSystem='2.16.840.1.113883.6.1')])&gt;=1 and not(hl7:code[(@code='59260-0' and @codeSystem='2.16.840.1.113883.6.1')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(MtrnlHb): element hl7:code[(@code='59260-0' and @codeSystem='2.16.840.1.113883.6.1')] is mandatory [min 1x]. (count(hl7:code[(@code='59260-0' and @codeSystem='2.16.840.1.113883.6.1')])&gt;=1 and not(hl7:code[(@code='59260-0' and @codeSystem='2.16.840.1.113883.6.1')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900920-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='59260-0' and @codeSystem='2.16.840.1.113883.6.1')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MtrnlHb): element hl7:code[(@code='59260-0' and @codeSystem='2.16.840.1.113883.6.1')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='59260-0' and @codeSystem='2.16.840.1.113883.6.1')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900920-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:effectiveTime)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MtrnlHb): element hl7:effectiveTime komt te vaak voor [max 1x]. (count(hl7:effectiveTime)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900920-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(MtrnlHb): element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900920-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MtrnlHb): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900920-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship[hl7:observation[hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MtrnlHb): element hl7:inboundRelationship[hl7:observation[hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')]]] komt te vaak voor [max 1x]. (count(hl7:inboundRelationship[hl7:observation[hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900920-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-713989-452059-347463-138893-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code/@code='12131-9']]/hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]]/hl7:component[hl7:observation[hl7:code[(@code='59260-0' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation/hl7:code[(@code='59260-0' and @codeSystem='2.16.840.1.113883.6.1')]"
                 priority="1048"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='59260-0' and @codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <xsl:message>(MtrnlHb): de elementwaarde MOET zijn code '59260-0' codeSystem '2.16.840.1.113883.6.1'. (@nullFlavor or (@code='59260-0' and @codeSystem='2.16.840.1.113883.6.1') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900920-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-731917-837508-671566-154572-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code/@code='12131-9']]/hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]]/hl7:component[hl7:observation[hl7:code[(@code='59260-0' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation/hl7:effectiveTime"
                 priority="1047"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-490029-443567-641332-193900-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code/@code='12131-9']]/hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]]/hl7:component[hl7:observation[hl7:code[(@code='59260-0' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation/hl7:value"
                 priority="1046"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (@unit='mmol/L' and (matches(string($theValue), '^[-+]?[0-9]*\.[0-9]{1,1}$'))))"/>
         <xsl:otherwise>
            <xsl:message>(MtrnlHb): value MOET eenheid 'mmol/L' gebruiken en exact op 1 decimalen nauwkeurig zijn  ((@nullFlavor or (@unit='mmol/L' and (matches(string($theValue), '^[-+]?[0-9]*\.[0-9]{1,1}$')))) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900920-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-172190-655124-967290-407534-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code/@code='12131-9']]/hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]]/hl7:component[hl7:observation[hl7:code[(@code='59260-0' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')]]]"
                 priority="1045"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='PERT'"/>
         <xsl:otherwise>
            <xsl:message>(MtrnlHb): de waarde van @typeCode MOET 'PERT' zijn. (string(@typeCode)='PERT' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900920-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@contextConductionInd)='true'"/>
         <xsl:otherwise>
            <xsl:message>(MtrnlHb): de waarde van @contextConductionInd MOET 'true' zijn. (string(@contextConductionInd)='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900920-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-970265-605972-767834-799170-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code/@code='12131-9']]/hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]]/hl7:component[hl7:observation[hl7:code[(@code='59260-0' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation"
                 priority="1044"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(ZwangerschapsduurOpDatumOnderzoek): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900236-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(ZwangerschapsduurOpDatumOnderzoek): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900236-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(ZwangerschapsduurOpDatumOnderzoek): element hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')] is mandatory [min 1x]. (count(hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900236-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ZwangerschapsduurOpDatumOnderzoek): element hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900236-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(ZwangerschapsduurOpDatumOnderzoek): element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900236-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ZwangerschapsduurOpDatumOnderzoek): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900236-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-646270-256057-124045-502347-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code/@code='12131-9']]/hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]]/hl7:component[hl7:observation[hl7:code[(@code='59260-0' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')]"
                 priority="1043"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>(ZwangerschapsduurOpDatumOnderzoek): de elementwaarde MOET zijn code '445872007' codeSystem '2.16.840.1.113883.6.96'. (@nullFlavor or (@code='445872007' and @codeSystem='2.16.840.1.113883.6.96') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900236-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-968928-177752-885117-757511-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code/@code='12131-9']]/hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]]/hl7:component[hl7:observation[hl7:code[(@code='59260-0' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:value"
                 priority="1042"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (@unit='d' and number($theValue)&gt;=0))"/>
         <xsl:otherwise>
            <xsl:message>(ZwangerschapsduurOpDatumOnderzoek): value MOET eenheid 'd' gebruiken en in bereik [0..] liggen   ((@nullFlavor or (@unit='d' and number($theValue)&gt;=0)) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900236-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-477563-364652-536625-735291-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code/@code='12131-9']]/hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]]/hl7:component[hl7:observation[hl7:code[(@code='X_RHFETBM' and @codeSystem='2.16.840.1.113883.6.1')]]]"
                 priority="1041"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(MaternaalOnderzoek): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900919-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@contextConductionInd)='true'"/>
         <xsl:otherwise>
            <xsl:message>(MaternaalOnderzoek): de waarde van @contextConductionInd MOET 'true' zijn. (string(@contextConductionInd)='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900919-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-429703-869045-999068-543551-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code/@code='12131-9']]/hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]]/hl7:component[hl7:observation[hl7:code[(@code='X_RHFETBM' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation"
                 priority="1040"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(MtrnlRhDFoetus): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900921-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(MtrnlRhDFoetus): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900921-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='X_RHFETBM' and @codeSystem='2.16.840.1.113883.6.1')])&gt;=1 and not(hl7:code[(@code='X_RHFETBM' and @codeSystem='2.16.840.1.113883.6.1')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(MtrnlRhDFoetus): element hl7:code[(@code='X_RHFETBM' and @codeSystem='2.16.840.1.113883.6.1')] is mandatory [min 1x]. (count(hl7:code[(@code='X_RHFETBM' and @codeSystem='2.16.840.1.113883.6.1')])&gt;=1 and not(hl7:code[(@code='X_RHFETBM' and @codeSystem='2.16.840.1.113883.6.1')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900921-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='X_RHFETBM' and @codeSystem='2.16.840.1.113883.6.1')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MtrnlRhDFoetus): element hl7:code[(@code='X_RHFETBM' and @codeSystem='2.16.840.1.113883.6.1')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='X_RHFETBM' and @codeSystem='2.16.840.1.113883.6.1')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900921-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:effectiveTime)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MtrnlRhDFoetus): element hl7:effectiveTime komt te vaak voor [max 1x]. (count(hl7:effectiveTime)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900921-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value[(@code='165747007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='165746003' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='NI'])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(MtrnlRhDFoetus): element hl7:value[(@code='165747007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='165746003' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='NI'] is required [min 1x]. (count(hl7:value[(@code='165747007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='165746003' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='NI'])&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900921-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value[(@code='165747007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='165746003' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='NI'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MtrnlRhDFoetus): element hl7:value[(@code='165747007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='165746003' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='NI'] komt te vaak voor [max 1x]. (count(hl7:value[(@code='165747007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='165746003' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='NI'])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900921-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship[hl7:observation[hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MtrnlRhDFoetus): element hl7:inboundRelationship[hl7:observation[hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')]]] komt te vaak voor [max 1x]. (count(hl7:inboundRelationship[hl7:observation[hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900921-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-655433-309841-833832-696338-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code/@code='12131-9']]/hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]]/hl7:component[hl7:observation[hl7:code[(@code='X_RHFETBM' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation/hl7:code[(@code='X_RHFETBM' and @codeSystem='2.16.840.1.113883.6.1')]"
                 priority="1039"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='X_RHFETBM' and @codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <xsl:message>(MtrnlRhDFoetus): de elementwaarde MOET zijn code 'X_RHFETBM' codeSystem '2.16.840.1.113883.6.1'. (@nullFlavor or (@code='X_RHFETBM' and @codeSystem='2.16.840.1.113883.6.1') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900921-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-978724-893356-649516-728384-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code/@code='12131-9']]/hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]]/hl7:component[hl7:observation[hl7:code[(@code='X_RHFETBM' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation/hl7:effectiveTime"
                 priority="1038"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-678988-638434-440151-972839-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code/@code='12131-9']]/hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]]/hl7:component[hl7:observation[hl7:code[(@code='X_RHFETBM' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation/hl7:value[(@code='165747007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='165746003' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='NI']"
                 priority="1037"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="validCodeOrCodeSystemFound"
                    select="concat(exists(document('include/voc-2.16.840.1.113883.2.4.11.156-DYNAMIC.xml')/*/valueSet[conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-2.16.840.1.113883.2.4.11.156-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>
      <xsl:variable name="explicitExceptions" select="''"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or contains($validCodeOrCodeSystemFound,'true')"/>
         <xsl:otherwise>
            <xsl:message>(MtrnlRhDFoetus): de waarde van @code MOET worden gekozen uit waardenlijst RhesusDBloodGroup Rhesus D Blood Group (DYNAMISCH). NB: codeSystemVersion MOET exact overeenkomen indien gespecificeerd in de waardenlijst. (@nullFlavor or contains($validCodeOrCodeSystemFound,'true') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900921-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|'))"/>
         <xsl:otherwise>
            <xsl:message>(MtrnlRhDFoetus): de nulwaarde voor @code MOET komen uit de set die is gedefinieerd voor dit attribuut of zijn gekoppeld aan waardenlijst RhesusDBloodGroup Rhesus D Blood Group (DYNAMISCH). (not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|')) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900921-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-581398-620618-680971-294062-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code/@code='12131-9']]/hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]]/hl7:component[hl7:observation[hl7:code[(@code='X_RHFETBM' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')]]]"
                 priority="1036"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='PERT'"/>
         <xsl:otherwise>
            <xsl:message>(MtrnlRhDFoetus): de waarde van @typeCode MOET 'PERT' zijn. (string(@typeCode)='PERT' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900921-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@contextConductionInd)='true'"/>
         <xsl:otherwise>
            <xsl:message>(MtrnlRhDFoetus): de waarde van @contextConductionInd MOET 'true' zijn. (string(@contextConductionInd)='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900921-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-497727-977726-958120-980137-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code/@code='12131-9']]/hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]]/hl7:component[hl7:observation[hl7:code[(@code='X_RHFETBM' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation"
                 priority="1035"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(ZwangerschapsduurOpDatumOnderzoek): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900236-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(ZwangerschapsduurOpDatumOnderzoek): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900236-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(ZwangerschapsduurOpDatumOnderzoek): element hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')] is mandatory [min 1x]. (count(hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900236-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ZwangerschapsduurOpDatumOnderzoek): element hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900236-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(ZwangerschapsduurOpDatumOnderzoek): element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900236-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ZwangerschapsduurOpDatumOnderzoek): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900236-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-492017-652262-530382-470145-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code/@code='12131-9']]/hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]]/hl7:component[hl7:observation[hl7:code[(@code='X_RHFETBM' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')]"
                 priority="1034"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>(ZwangerschapsduurOpDatumOnderzoek): de elementwaarde MOET zijn code '445872007' codeSystem '2.16.840.1.113883.6.96'. (@nullFlavor or (@code='445872007' and @codeSystem='2.16.840.1.113883.6.96') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900236-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-419418-454566-605464-484331-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code/@code='12131-9']]/hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]]/hl7:component[hl7:observation[hl7:code[(@code='X_RHFETBM' and @codeSystem='2.16.840.1.113883.6.1')]]]/hl7:observation/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:value"
                 priority="1033"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (@unit='d' and number($theValue)&gt;=0))"/>
         <xsl:otherwise>
            <xsl:message>(ZwangerschapsduurOpDatumOnderzoek): value MOET eenheid 'd' gebruiken en in bereik [0..] liggen   ((@nullFlavor or (@unit='d' and number($theValue)&gt;=0)) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900236-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-460758-476366-643928-531097-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code/@code='12131-9']]/hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]]/hl7:component[hl7:procedure[hl7:code[(@code='51597003' and @codeSystem='2.16.840.1.113883.6.96')]]]"
                 priority="1032"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(MaternaalOnderzoek): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900919-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@contextConductionInd)='true'"/>
         <xsl:otherwise>
            <xsl:message>(MaternaalOnderzoek): de waarde van @contextConductionInd MOET 'true' zijn. (string(@contextConductionInd)='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900919-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-599531-603375-708164-790774-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code/@code='12131-9']]/hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]]/hl7:component[hl7:procedure[hl7:code[(@code='51597003' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:procedure"
                 priority="1031"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='PROC'"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): de waarde van @classCode MOET 'PROC' zijn. (string(@classCode)='PROC' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): element hl7:id is required [min 1x]. (count(hl7:id)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): element hl7:id komt te vaak voor [max 1x]. (count(hl7:id)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='51597003' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='51597003' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): element hl7:code[(@code='51597003' and @codeSystem='2.16.840.1.113883.6.96')] is mandatory [min 1x]. (count(hl7:code[(@code='51597003' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='51597003' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='51597003' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): element hl7:code[(@code='51597003' and @codeSystem='2.16.840.1.113883.6.96')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='51597003' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:effectiveTime)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): element hl7:effectiveTime komt te vaak voor [max 1x]. (count(hl7:effectiveTime)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship[hl7:observation[hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): element hl7:inboundRelationship[hl7:observation[hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')]]] komt te vaak voor [max 1x]. (count(hl7:inboundRelationship[hl7:observation[hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')]]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship[hl7:observation/hl7:code[@code='249021005']])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): element hl7:inboundRelationship[hl7:observation/hl7:code[@code='249021005']] is required [min 1x]. (count(hl7:inboundRelationship[hl7:observation/hl7:code[@code='249021005']])&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship[hl7:observation/hl7:code[@code='249021005']])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): element hl7:inboundRelationship[hl7:observation/hl7:code[@code='249021005']] komt te vaak voor [max 1x]. (count(hl7:inboundRelationship[hl7:observation/hl7:code[@code='249021005']])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship[hl7:observation/hl7:code[@code='289761004']])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): element hl7:inboundRelationship[hl7:observation/hl7:code[@code='289761004']] is required [min 1x]. (count(hl7:inboundRelationship[hl7:observation/hl7:code[@code='289761004']])&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship[hl7:observation/hl7:code[@code='289761004']])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): element hl7:inboundRelationship[hl7:observation/hl7:code[@code='289761004']] komt te vaak voor [max 1x]. (count(hl7:inboundRelationship[hl7:observation/hl7:code[@code='289761004']])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship[hl7:observation/hl7:code[@code='112074005']])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): element hl7:inboundRelationship[hl7:observation/hl7:code[@code='112074005']] is required [min 1x]. (count(hl7:inboundRelationship[hl7:observation/hl7:code[@code='112074005']])&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship[hl7:observation/hl7:code[@code='112074005']])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): element hl7:inboundRelationship[hl7:observation/hl7:code[@code='112074005']] komt te vaak voor [max 1x]. (count(hl7:inboundRelationship[hl7:observation/hl7:code[@code='112074005']])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship[hl7:observation/hl7:code[@code='364611006']])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): element hl7:inboundRelationship[hl7:observation/hl7:code[@code='364611006']] komt te vaak voor [max 1x]. (count(hl7:inboundRelationship[hl7:observation/hl7:code[@code='364611006']])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship[hl7:observation/hl7:code[@code='364612004']])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): element hl7:inboundRelationship[hl7:observation/hl7:code[@code='364612004']] komt te vaak voor [max 1x]. (count(hl7:inboundRelationship[hl7:observation/hl7:code[@code='364612004']])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship[hl7:observation/hl7:code[@code='163520002']])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): element hl7:inboundRelationship[hl7:observation/hl7:code[@code='163520002']] komt te vaak voor [max 1x]. (count(hl7:inboundRelationship[hl7:observation/hl7:code[@code='163520002']])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-666386-350031-737257-105346-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code/@code='12131-9']]/hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]]/hl7:component[hl7:procedure[hl7:code[(@code='51597003' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:procedure/hl7:id"
                 priority="1030"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@nullFlavor)='NI' or not(@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): de waarde van @nullFlavor MOET 'NI' zijn. (string(@nullFlavor)='NI' or not(@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-670054-486470-276388-882596-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code/@code='12131-9']]/hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]]/hl7:component[hl7:procedure[hl7:code[(@code='51597003' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:procedure/hl7:code[(@code='51597003' and @codeSystem='2.16.840.1.113883.6.96')]"
                 priority="1029"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='51597003' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): de elementwaarde MOET zijn code '51597003' codeSystem '2.16.840.1.113883.6.96'. (@nullFlavor or (@code='51597003' and @codeSystem='2.16.840.1.113883.6.96') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-100122-839478-915122-848328-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code/@code='12131-9']]/hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]]/hl7:component[hl7:procedure[hl7:code[(@code='51597003' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:procedure/hl7:effectiveTime"
                 priority="1028"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-648385-713214-178125-852735-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code/@code='12131-9']]/hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]]/hl7:component[hl7:procedure[hl7:code[(@code='51597003' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')]]]"
                 priority="1027"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='PERT'"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): de waarde van @typeCode MOET 'PERT' zijn. (string(@typeCode)='PERT' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@contextConductionInd)='true'"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): de waarde van @contextConductionInd MOET 'true' zijn. (string(@contextConductionInd)='true' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-336813-464535-606813-689339-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code/@code='12131-9']]/hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]]/hl7:component[hl7:procedure[hl7:code[(@code='51597003' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation"
                 priority="1026"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(ZwangerschapsduurOpDatumOnderzoek): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900236-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(ZwangerschapsduurOpDatumOnderzoek): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900236-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(ZwangerschapsduurOpDatumOnderzoek): element hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')] is mandatory [min 1x]. (count(hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900236-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ZwangerschapsduurOpDatumOnderzoek): element hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900236-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(ZwangerschapsduurOpDatumOnderzoek): element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900236-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ZwangerschapsduurOpDatumOnderzoek): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900236-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-829717-725071-759012-587349-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code/@code='12131-9']]/hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]]/hl7:component[hl7:procedure[hl7:code[(@code='51597003' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')]"
                 priority="1025"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>(ZwangerschapsduurOpDatumOnderzoek): de elementwaarde MOET zijn code '445872007' codeSystem '2.16.840.1.113883.6.96'. (@nullFlavor or (@code='445872007' and @codeSystem='2.16.840.1.113883.6.96') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900236-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-920595-905267-647158-703121-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code/@code='12131-9']]/hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]]/hl7:component[hl7:procedure[hl7:code[(@code='51597003' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[(@code='445872007' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:observation/hl7:value"
                 priority="1024"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (@unit='d' and number($theValue)&gt;=0))"/>
         <xsl:otherwise>
            <xsl:message>(ZwangerschapsduurOpDatumOnderzoek): value MOET eenheid 'd' gebruiken en in bereik [0..] liggen   ((@nullFlavor or (@unit='d' and number($theValue)&gt;=0)) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900236-2013-03-20T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-363486-721994-446149-841362-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code/@code='12131-9']]/hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]]/hl7:component[hl7:procedure[hl7:code[(@code='51597003' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:procedure/hl7:inboundRelationship[hl7:observation/hl7:code[@code='249021005']]"
                 priority="1023"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:observation[hl7:code[(@code='249021005' and @codeSystem='2.16.840.1.113883.6.96')]])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): element hl7:observation[hl7:code[(@code='249021005' and @codeSystem='2.16.840.1.113883.6.96')]] is required [min 1x]. (count(hl7:observation[hl7:code[(@code='249021005' and @codeSystem='2.16.840.1.113883.6.96')]])&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:observation[hl7:code[(@code='249021005' and @codeSystem='2.16.840.1.113883.6.96')]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): element hl7:observation[hl7:code[(@code='249021005' and @codeSystem='2.16.840.1.113883.6.96')]] komt te vaak voor [max 1x]. (count(hl7:observation[hl7:code[(@code='249021005' and @codeSystem='2.16.840.1.113883.6.96')]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-591973-624434-234349-822671-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code/@code='12131-9']]/hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]]/hl7:component[hl7:procedure[hl7:code[(@code='51597003' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:procedure/hl7:inboundRelationship[hl7:observation/hl7:code[@code='249021005']]/hl7:observation[hl7:code[(@code='249021005' and @codeSystem='2.16.840.1.113883.6.96')]]"
                 priority="1022"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='249021005' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='249021005' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): element hl7:code[(@code='249021005' and @codeSystem='2.16.840.1.113883.6.96')] is mandatory [min 1x]. (count(hl7:code[(@code='249021005' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='249021005' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='249021005' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): element hl7:code[(@code='249021005' and @codeSystem='2.16.840.1.113883.6.96')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='249021005' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value[(@code='278056007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='278058008' and @codeSystem='2.16.840.1.113883.6.96') or (@code='19337000' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='NI'])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): element hl7:value[(@code='278056007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='278058008' and @codeSystem='2.16.840.1.113883.6.96') or (@code='19337000' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='NI'] is required [min 1x]. (count(hl7:value[(@code='278056007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='278058008' and @codeSystem='2.16.840.1.113883.6.96') or (@code='19337000' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='NI'])&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value[(@code='278056007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='278058008' and @codeSystem='2.16.840.1.113883.6.96') or (@code='19337000' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='NI'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): element hl7:value[(@code='278056007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='278058008' and @codeSystem='2.16.840.1.113883.6.96') or (@code='19337000' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='NI'] komt te vaak voor [max 1x]. (count(hl7:value[(@code='278056007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='278058008' and @codeSystem='2.16.840.1.113883.6.96') or (@code='19337000' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='NI'])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-170489-216352-648864-614806-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code/@code='12131-9']]/hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]]/hl7:component[hl7:procedure[hl7:code[(@code='51597003' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:procedure/hl7:inboundRelationship[hl7:observation/hl7:code[@code='249021005']]/hl7:observation[hl7:code[(@code='249021005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:code"
                 priority="1021"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='249021005' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): de elementwaarde MOET zijn code '249021005' codeSystem '2.16.840.1.113883.6.96'. (@nullFlavor or (@code='249021005' and @codeSystem='2.16.840.1.113883.6.96') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-696629-803571-552232-196898-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code/@code='12131-9']]/hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]]/hl7:component[hl7:procedure[hl7:code[(@code='51597003' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:procedure/hl7:inboundRelationship[hl7:observation/hl7:code[@code='249021005']]/hl7:observation[hl7:code[(@code='249021005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:value[(@code='278056007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='278058008' and @codeSystem='2.16.840.1.113883.6.96') or (@code='19337000' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='NI']"
                 priority="1020"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="validCodeOrCodeSystemFound"
                    select="concat(exists(document('include/voc-2.16.840.1.113883.2.4.11.158-2012-03-17T000000.xml')/*/valueSet[conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-2.16.840.1.113883.2.4.11.158-2012-03-17T000000.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>
      <xsl:variable name="explicitExceptions" select="''"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or contains($validCodeOrCodeSystemFound,'true')"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): de waarde van @code MOET worden gekozen uit waardenlijst CervixEffacement Cervix Effacement (2012-03-17T00:00:00). NB: codeSystemVersion MOET exact overeenkomen indien gespecificeerd in de waardenlijst. (@nullFlavor or contains($validCodeOrCodeSystemFound,'true') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|'))"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): de nulwaarde voor @code MOET komen uit de set die is gedefinieerd voor dit attribuut of zijn gekoppeld aan waardenlijst CervixEffacement Cervix Effacement (2012-03-17T00:00:00). (not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|')) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(../../../@negationInd='true')"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): Als er géén VT gedaan is, ook geen waarde opnemen voor Portio. (not(../../../@negationInd='true') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-540620-420046-684905-267976-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code/@code='12131-9']]/hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]]/hl7:component[hl7:procedure[hl7:code[(@code='51597003' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:procedure/hl7:inboundRelationship[hl7:observation/hl7:code[@code='289761004']]"
                 priority="1019"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:observation[hl7:code[(@code='289761004' and @codeSystem='2.16.840.1.113883.6.96')]])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): element hl7:observation[hl7:code[(@code='289761004' and @codeSystem='2.16.840.1.113883.6.96')]] is required [min 1x]. (count(hl7:observation[hl7:code[(@code='289761004' and @codeSystem='2.16.840.1.113883.6.96')]])&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:observation[hl7:code[(@code='289761004' and @codeSystem='2.16.840.1.113883.6.96')]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): element hl7:observation[hl7:code[(@code='289761004' and @codeSystem='2.16.840.1.113883.6.96')]] komt te vaak voor [max 1x]. (count(hl7:observation[hl7:code[(@code='289761004' and @codeSystem='2.16.840.1.113883.6.96')]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-210622-694859-214120-684094-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code/@code='12131-9']]/hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]]/hl7:component[hl7:procedure[hl7:code[(@code='51597003' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:procedure/hl7:inboundRelationship[hl7:observation/hl7:code[@code='289761004']]/hl7:observation[hl7:code[(@code='289761004' and @codeSystem='2.16.840.1.113883.6.96')]]"
                 priority="1018"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='289761004' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='289761004' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): element hl7:code[(@code='289761004' and @codeSystem='2.16.840.1.113883.6.96')] is mandatory [min 1x]. (count(hl7:code[(@code='289761004' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='289761004' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='289761004' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): element hl7:code[(@code='289761004' and @codeSystem='2.16.840.1.113883.6.96')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='289761004' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value[(@code='289764007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='320003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='58699001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='23652008' and @codeSystem='2.16.840.1.113883.6.96') or (@code='43808007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='23128002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='66895001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='74522004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='39333005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='62774004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='62472004' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='NI'])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): element hl7:value[(@code='289764007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='320003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='58699001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='23652008' and @codeSystem='2.16.840.1.113883.6.96') or (@code='43808007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='23128002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='66895001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='74522004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='39333005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='62774004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='62472004' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='NI'] is required [min 1x]. (count(hl7:value[(@code='289764007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='320003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='58699001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='23652008' and @codeSystem='2.16.840.1.113883.6.96') or (@code='43808007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='23128002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='66895001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='74522004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='39333005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='62774004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='62472004' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='NI'])&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value[(@code='289764007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='320003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='58699001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='23652008' and @codeSystem='2.16.840.1.113883.6.96') or (@code='43808007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='23128002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='66895001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='74522004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='39333005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='62774004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='62472004' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='NI'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): element hl7:value[(@code='289764007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='320003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='58699001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='23652008' and @codeSystem='2.16.840.1.113883.6.96') or (@code='43808007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='23128002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='66895001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='74522004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='39333005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='62774004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='62472004' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='NI'] komt te vaak voor [max 1x]. (count(hl7:value[(@code='289764007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='320003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='58699001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='23652008' and @codeSystem='2.16.840.1.113883.6.96') or (@code='43808007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='23128002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='66895001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='74522004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='39333005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='62774004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='62472004' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='NI'])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-425117-511021-701100-240138-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code/@code='12131-9']]/hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]]/hl7:component[hl7:procedure[hl7:code[(@code='51597003' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:procedure/hl7:inboundRelationship[hl7:observation/hl7:code[@code='289761004']]/hl7:observation[hl7:code[(@code='289761004' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:code"
                 priority="1017"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='289761004' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): de elementwaarde MOET zijn code '289761004' codeSystem '2.16.840.1.113883.6.96'. (@nullFlavor or (@code='289761004' and @codeSystem='2.16.840.1.113883.6.96') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-393553-133095-366975-365762-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code/@code='12131-9']]/hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]]/hl7:component[hl7:procedure[hl7:code[(@code='51597003' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:procedure/hl7:inboundRelationship[hl7:observation/hl7:code[@code='289761004']]/hl7:observation[hl7:code[(@code='289761004' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:value[(@code='289764007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='320003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='58699001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='23652008' and @codeSystem='2.16.840.1.113883.6.96') or (@code='43808007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='23128002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='66895001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='74522004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='39333005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='62774004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='62472004' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='NI']"
                 priority="1016"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="validCodeOrCodeSystemFound"
                    select="concat(exists(document('include/voc-2.16.840.1.113883.2.4.11.175-2013-04-22T173433.xml')/*/valueSet[conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-2.16.840.1.113883.2.4.11.175-2013-04-22T173433.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>
      <xsl:variable name="explicitExceptions" select="''"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or contains($validCodeOrCodeSystemFound,'true')"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): de waarde van @code MOET worden gekozen uit waardenlijst CervicalDilatation Cervical dilatation (2013-04-22T17:34:33). NB: codeSystemVersion MOET exact overeenkomen indien gespecificeerd in de waardenlijst. (@nullFlavor or contains($validCodeOrCodeSystemFound,'true') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|'))"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): de nulwaarde voor @code MOET komen uit de set die is gedefinieerd voor dit attribuut of zijn gekoppeld aan waardenlijst CervicalDilatation Cervical dilatation (2013-04-22T17:34:33). (not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|')) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(../../../@negationInd='true')"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): Als er géén VT gedaan is, ook geen waarde opnemen voor Ontsluiting. (not(../../../@negationInd='true') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-212307-707666-172441-282043-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code/@code='12131-9']]/hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]]/hl7:component[hl7:procedure[hl7:code[(@code='51597003' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:procedure/hl7:inboundRelationship[hl7:observation/hl7:code[@code='112074005']]"
                 priority="1015"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:observation[hl7:code[(@code='112074005' and @codeSystem='2.16.840.1.113883.6.96')]])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): element hl7:observation[hl7:code[(@code='112074005' and @codeSystem='2.16.840.1.113883.6.96')]] is required [min 1x]. (count(hl7:observation[hl7:code[(@code='112074005' and @codeSystem='2.16.840.1.113883.6.96')]])&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:observation[hl7:code[(@code='112074005' and @codeSystem='2.16.840.1.113883.6.96')]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): element hl7:observation[hl7:code[(@code='112074005' and @codeSystem='2.16.840.1.113883.6.96')]] komt te vaak voor [max 1x]. (count(hl7:observation[hl7:code[(@code='112074005' and @codeSystem='2.16.840.1.113883.6.96')]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-289711-478753-703509-222896-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code/@code='12131-9']]/hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]]/hl7:component[hl7:procedure[hl7:code[(@code='51597003' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:procedure/hl7:inboundRelationship[hl7:observation/hl7:code[@code='112074005']]/hl7:observation[hl7:code[(@code='112074005' and @codeSystem='2.16.840.1.113883.6.96')]]"
                 priority="1014"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='112074005' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='112074005' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): element hl7:code[(@code='112074005' and @codeSystem='2.16.840.1.113883.6.96')] is mandatory [min 1x]. (count(hl7:code[(@code='112074005' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='112074005' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='112074005' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): element hl7:code[(@code='112074005' and @codeSystem='2.16.840.1.113883.6.96')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='112074005' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value[(@code='46914009' and @codeSystem='2.16.840.1.113883.6.96') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.47') or (@code='237264000' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='NI'])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): element hl7:value[(@code='46914009' and @codeSystem='2.16.840.1.113883.6.96') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.47') or (@code='237264000' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='NI'] is required [min 1x]. (count(hl7:value[(@code='46914009' and @codeSystem='2.16.840.1.113883.6.96') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.47') or (@code='237264000' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='NI'])&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value[(@code='46914009' and @codeSystem='2.16.840.1.113883.6.96') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.47') or (@code='237264000' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='NI'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): element hl7:value[(@code='46914009' and @codeSystem='2.16.840.1.113883.6.96') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.47') or (@code='237264000' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='NI'] komt te vaak voor [max 1x]. (count(hl7:value[(@code='46914009' and @codeSystem='2.16.840.1.113883.6.96') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.47') or (@code='237264000' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='NI'])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-467287-164099-684538-891778-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code/@code='12131-9']]/hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]]/hl7:component[hl7:procedure[hl7:code[(@code='51597003' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:procedure/hl7:inboundRelationship[hl7:observation/hl7:code[@code='112074005']]/hl7:observation[hl7:code[(@code='112074005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:code"
                 priority="1013"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='112074005' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): de elementwaarde MOET zijn code '112074005' codeSystem '2.16.840.1.113883.6.96'. (@nullFlavor or (@code='112074005' and @codeSystem='2.16.840.1.113883.6.96') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-150863-172844-708300-523427-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code/@code='12131-9']]/hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]]/hl7:component[hl7:procedure[hl7:code[(@code='51597003' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:procedure/hl7:inboundRelationship[hl7:observation/hl7:code[@code='112074005']]/hl7:observation[hl7:code[(@code='112074005' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:value[(@code='46914009' and @codeSystem='2.16.840.1.113883.6.96') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.47') or (@code='237264000' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='NI']"
                 priority="1012"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="validCodeOrCodeSystemFound"
                    select="concat(exists(document('include/voc-2.16.840.1.113883.2.4.11.173-2013-03-20T000000.xml')/*/valueSet[conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-2.16.840.1.113883.2.4.11.173-2013-03-20T000000.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>
      <xsl:variable name="explicitExceptions" select="''"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or contains($validCodeOrCodeSystemFound,'true')"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): de waarde van @code MOET worden gekozen uit waardenlijst Vliezen (2013-03-20T00:00:00). NB: codeSystemVersion MOET exact overeenkomen indien gespecificeerd in de waardenlijst. (@nullFlavor or contains($validCodeOrCodeSystemFound,'true') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|'))"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): de nulwaarde voor @code MOET komen uit de set die is gedefinieerd voor dit attribuut of zijn gekoppeld aan waardenlijst Vliezen (2013-03-20T00:00:00). (not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|')) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(../../../@negationInd='true')"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): Als er géén VT gedaan is, ook geen waarde opnemen voor Vliezen. (not(../../../@negationInd='true') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-125023-839309-251939-814989-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code/@code='12131-9']]/hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]]/hl7:component[hl7:procedure[hl7:code[(@code='51597003' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:procedure/hl7:inboundRelationship[hl7:observation/hl7:code[@code='364611006']]"
                 priority="1011"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:observation[hl7:code[(@code='364611006' and @codeSystem='2.16.840.1.113883.6.96')]])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): element hl7:observation[hl7:code[(@code='364611006' and @codeSystem='2.16.840.1.113883.6.96')]] is required [min 1x]. (count(hl7:observation[hl7:code[(@code='364611006' and @codeSystem='2.16.840.1.113883.6.96')]])&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:observation[hl7:code[(@code='364611006' and @codeSystem='2.16.840.1.113883.6.96')]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): element hl7:observation[hl7:code[(@code='364611006' and @codeSystem='2.16.840.1.113883.6.96')]] komt te vaak voor [max 1x]. (count(hl7:observation[hl7:code[(@code='364611006' and @codeSystem='2.16.840.1.113883.6.96')]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-661555-741132-685627-507313-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code/@code='12131-9']]/hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]]/hl7:component[hl7:procedure[hl7:code[(@code='51597003' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:procedure/hl7:inboundRelationship[hl7:observation/hl7:code[@code='364611006']]/hl7:observation[hl7:code[(@code='364611006' and @codeSystem='2.16.840.1.113883.6.96')]]"
                 priority="1010"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='364611006' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='364611006' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): element hl7:code[(@code='364611006' and @codeSystem='2.16.840.1.113883.6.96')] is mandatory [min 1x]. (count(hl7:code[(@code='364611006' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='364611006' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='364611006' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): element hl7:code[(@code='364611006' and @codeSystem='2.16.840.1.113883.6.96')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='364611006' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value[(@code='289377000' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289379002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289381000' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289382007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289385009' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): element hl7:value[(@code='289377000' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289379002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289381000' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289382007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289385009' and @codeSystem='2.16.840.1.113883.6.96')] is required [min 1x]. (count(hl7:value[(@code='289377000' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289379002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289381000' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289382007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289385009' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value[(@code='289377000' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289379002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289381000' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289382007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289385009' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): element hl7:value[(@code='289377000' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289379002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289381000' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289382007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289385009' and @codeSystem='2.16.840.1.113883.6.96')] komt te vaak voor [max 1x]. (count(hl7:value[(@code='289377000' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289379002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289381000' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289382007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289385009' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-256946-525305-826760-766232-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code/@code='12131-9']]/hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]]/hl7:component[hl7:procedure[hl7:code[(@code='51597003' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:procedure/hl7:inboundRelationship[hl7:observation/hl7:code[@code='364611006']]/hl7:observation[hl7:code[(@code='364611006' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:code"
                 priority="1009"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='364611006' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): de elementwaarde MOET zijn code '364611006' codeSystem '2.16.840.1.113883.6.96'. (@nullFlavor or (@code='364611006' and @codeSystem='2.16.840.1.113883.6.96') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-784313-775021-520677-737603-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code/@code='12131-9']]/hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]]/hl7:component[hl7:procedure[hl7:code[(@code='51597003' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:procedure/hl7:inboundRelationship[hl7:observation/hl7:code[@code='364611006']]/hl7:observation[hl7:code[(@code='364611006' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:value[(@code='289377000' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289379002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289381000' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289382007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289385009' and @codeSystem='2.16.840.1.113883.6.96')]"
                 priority="1008"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="validCodeOrCodeSystemFound"
                    select="concat(exists(document('include/voc-2.16.840.1.113883.2.4.11.159-2012-03-17T000000.xml')/*/valueSet[conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-2.16.840.1.113883.2.4.11.159-2012-03-17T000000.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>
      <xsl:variable name="explicitExceptions" select="''"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or contains($validCodeOrCodeSystemFound,'true')"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): de waarde van @code MOET worden gekozen uit waardenlijst HodgePlanes Hodge Planes (2012-03-17T00:00:00). NB: codeSystemVersion MOET exact overeenkomen indien gespecificeerd in de waardenlijst. (@nullFlavor or contains($validCodeOrCodeSystemFound,'true') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|'))"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): de nulwaarde voor @code MOET komen uit de set die is gedefinieerd voor dit attribuut of zijn gekoppeld aan waardenlijst HodgePlanes Hodge Planes (2012-03-17T00:00:00). (not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|')) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(../../../@negationInd='true')"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): Als er géén VT gedaan is, ook geen waarde opnemen voor Indaling. (not(../../../@negationInd='true') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-846054-432902-999555-322541-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code/@code='12131-9']]/hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]]/hl7:component[hl7:procedure[hl7:code[(@code='51597003' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:procedure/hl7:inboundRelationship[hl7:observation/hl7:code[@code='364612004']]"
                 priority="1007"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:observation[hl7:code[(@code='364612004' and @codeSystem='2.16.840.1.113883.6.96')]])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): element hl7:observation[hl7:code[(@code='364612004' and @codeSystem='2.16.840.1.113883.6.96')]] is required [min 1x]. (count(hl7:observation[hl7:code[(@code='364612004' and @codeSystem='2.16.840.1.113883.6.96')]])&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:observation[hl7:code[(@code='364612004' and @codeSystem='2.16.840.1.113883.6.96')]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): element hl7:observation[hl7:code[(@code='364612004' and @codeSystem='2.16.840.1.113883.6.96')]] komt te vaak voor [max 1x]. (count(hl7:observation[hl7:code[(@code='364612004' and @codeSystem='2.16.840.1.113883.6.96')]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-585581-737488-219829-108890-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code/@code='12131-9']]/hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]]/hl7:component[hl7:procedure[hl7:code[(@code='51597003' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:procedure/hl7:inboundRelationship[hl7:observation/hl7:code[@code='364612004']]/hl7:observation[hl7:code[(@code='364612004' and @codeSystem='2.16.840.1.113883.6.96')]]"
                 priority="1006"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='364612004' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='364612004' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): element hl7:code[(@code='364612004' and @codeSystem='2.16.840.1.113883.6.96')] is mandatory [min 1x]. (count(hl7:code[(@code='364612004' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='364612004' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='364612004' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): element hl7:code[(@code='364612004' and @codeSystem='2.16.840.1.113883.6.96')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='364612004' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value[(@code='70028003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='249083005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='249081007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='249082000' and @codeSystem='2.16.840.1.113883.6.96') or (@code='21882006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='14058000' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289398000' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289396001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='288203005' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI'])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): element hl7:value[(@code='70028003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='249083005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='249081007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='249082000' and @codeSystem='2.16.840.1.113883.6.96') or (@code='21882006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='14058000' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289398000' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289396001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='288203005' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI'] is required [min 1x]. (count(hl7:value[(@code='70028003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='249083005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='249081007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='249082000' and @codeSystem='2.16.840.1.113883.6.96') or (@code='21882006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='14058000' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289398000' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289396001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='288203005' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI'])&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value[(@code='70028003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='249083005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='249081007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='249082000' and @codeSystem='2.16.840.1.113883.6.96') or (@code='21882006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='14058000' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289398000' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289396001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='288203005' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): element hl7:value[(@code='70028003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='249083005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='249081007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='249082000' and @codeSystem='2.16.840.1.113883.6.96') or (@code='21882006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='14058000' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289398000' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289396001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='288203005' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI'] komt te vaak voor [max 1x]. (count(hl7:value[(@code='70028003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='249083005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='249081007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='249082000' and @codeSystem='2.16.840.1.113883.6.96') or (@code='21882006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='14058000' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289398000' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289396001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='288203005' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI'])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-288336-759557-819157-741711-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code/@code='12131-9']]/hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]]/hl7:component[hl7:procedure[hl7:code[(@code='51597003' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:procedure/hl7:inboundRelationship[hl7:observation/hl7:code[@code='364612004']]/hl7:observation[hl7:code[(@code='364612004' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:code"
                 priority="1005"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='364612004' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): de elementwaarde MOET zijn code '364612004' codeSystem '2.16.840.1.113883.6.96'. (@nullFlavor or (@code='364612004' and @codeSystem='2.16.840.1.113883.6.96') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-853573-752006-321492-180344-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code/@code='12131-9']]/hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]]/hl7:component[hl7:procedure[hl7:code[(@code='51597003' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:procedure/hl7:inboundRelationship[hl7:observation/hl7:code[@code='364612004']]/hl7:observation[hl7:code[(@code='364612004' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:value[(@code='70028003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='249083005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='249081007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='249082000' and @codeSystem='2.16.840.1.113883.6.96') or (@code='21882006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='14058000' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289398000' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289396001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='288203005' and @codeSystem='2.16.840.1.113883.6.96') or @nullFlavor='UNK' or @nullFlavor='OTH' or @nullFlavor='NI']"
                 priority="1004"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="validCodeOrCodeSystemFound"
                    select="concat(exists(document('include/voc-2.16.840.1.113883.2.4.11.172-2013-03-20T000000.xml')/*/valueSet[conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-2.16.840.1.113883.2.4.11.172-2013-03-20T000000.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>
      <xsl:variable name="explicitExceptions" select="''"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or contains($validCodeOrCodeSystemFound,'true')"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): de waarde van @code MOET worden gekozen uit waardenlijst PresentationOfFetus Presentation of fetus (2013-03-20T00:00:00). NB: codeSystemVersion MOET exact overeenkomen indien gespecificeerd in de waardenlijst. (@nullFlavor or contains($validCodeOrCodeSystemFound,'true') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|'))"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): de nulwaarde voor @code MOET komen uit de set die is gedefinieerd voor dit attribuut of zijn gekoppeld aan waardenlijst PresentationOfFetus Presentation of fetus (2013-03-20T00:00:00). (not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|')) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(../../../@negationInd='true')"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): Als er géén VT gedaan is, ook geen waarde opnemen voor Aard van het voorliggend deel. (not(../../../@negationInd='true') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-765400-205092-125822-719561-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code/@code='12131-9']]/hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]]/hl7:component[hl7:procedure[hl7:code[(@code='51597003' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:procedure/hl7:inboundRelationship[hl7:observation/hl7:code[@code='163520002']]"
                 priority="1003"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@typeCode)='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): de waarde van @typeCode MOET 'COMP' zijn. (string(@typeCode)='COMP' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:observation[hl7:code[(@code='163520002' and @codeSystem='2.16.840.1.113883.6.96')]])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): element hl7:observation[hl7:code[(@code='163520002' and @codeSystem='2.16.840.1.113883.6.96')]] is required [min 1x]. (count(hl7:observation[hl7:code[(@code='163520002' and @codeSystem='2.16.840.1.113883.6.96')]])&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:observation[hl7:code[(@code='163520002' and @codeSystem='2.16.840.1.113883.6.96')]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): element hl7:observation[hl7:code[(@code='163520002' and @codeSystem='2.16.840.1.113883.6.96')]] komt te vaak voor [max 1x]. (count(hl7:observation[hl7:code[(@code='163520002' and @codeSystem='2.16.840.1.113883.6.96')]])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-764768-217558-843319-809147-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code/@code='12131-9']]/hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]]/hl7:component[hl7:procedure[hl7:code[(@code='51597003' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:procedure/hl7:inboundRelationship[hl7:observation/hl7:code[@code='163520002']]/hl7:observation[hl7:code[(@code='163520002' and @codeSystem='2.16.840.1.113883.6.96')]]"
                 priority="1002"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@classCode)='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): de waarde van @classCode MOET 'OBS' zijn. (string(@classCode)='OBS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string(@moodCode)='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): de waarde van @moodCode MOET 'EVN' zijn. (string(@moodCode)='EVN' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='163520002' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='163520002' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): element hl7:code[(@code='163520002' and @codeSystem='2.16.840.1.113883.6.96')] is mandatory [min 1x]. (count(hl7:code[(@code='163520002' and @codeSystem='2.16.840.1.113883.6.96')])&gt;=1 and not(hl7:code[(@code='163520002' and @codeSystem='2.16.840.1.113883.6.96')]/@nullFlavor) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code[(@code='163520002' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): element hl7:code[(@code='163520002' and @codeSystem='2.16.840.1.113883.6.96')] komt te vaak voor [max 1x]. (count(hl7:code[(@code='163520002' and @codeSystem='2.16.840.1.113883.6.96')])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.4.13.48') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.48') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.4.13.48') or (@code='4' and @codeSystem='2.16.840.1.113883.2.4.4.13.48') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.4.13.48') or (@code='6' and @codeSystem='2.16.840.1.113883.2.4.4.13.48') or (@code='7' and @codeSystem='2.16.840.1.113883.2.4.4.13.48') or (@code='8' and @codeSystem='2.16.840.1.113883.2.4.4.13.48') or @nullFlavor='NI'])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): element hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.4.13.48') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.48') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.4.13.48') or (@code='4' and @codeSystem='2.16.840.1.113883.2.4.4.13.48') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.4.13.48') or (@code='6' and @codeSystem='2.16.840.1.113883.2.4.4.13.48') or (@code='7' and @codeSystem='2.16.840.1.113883.2.4.4.13.48') or (@code='8' and @codeSystem='2.16.840.1.113883.2.4.4.13.48') or @nullFlavor='NI'] is required [min 1x]. (count(hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.4.13.48') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.48') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.4.13.48') or (@code='4' and @codeSystem='2.16.840.1.113883.2.4.4.13.48') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.4.13.48') or (@code='6' and @codeSystem='2.16.840.1.113883.2.4.4.13.48') or (@code='7' and @codeSystem='2.16.840.1.113883.2.4.4.13.48') or (@code='8' and @codeSystem='2.16.840.1.113883.2.4.4.13.48') or @nullFlavor='NI'])&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.4.13.48') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.48') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.4.13.48') or (@code='4' and @codeSystem='2.16.840.1.113883.2.4.4.13.48') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.4.13.48') or (@code='6' and @codeSystem='2.16.840.1.113883.2.4.4.13.48') or (@code='7' and @codeSystem='2.16.840.1.113883.2.4.4.13.48') or (@code='8' and @codeSystem='2.16.840.1.113883.2.4.4.13.48') or @nullFlavor='NI'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): element hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.4.13.48') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.48') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.4.13.48') or (@code='4' and @codeSystem='2.16.840.1.113883.2.4.4.13.48') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.4.13.48') or (@code='6' and @codeSystem='2.16.840.1.113883.2.4.4.13.48') or (@code='7' and @codeSystem='2.16.840.1.113883.2.4.4.13.48') or (@code='8' and @codeSystem='2.16.840.1.113883.2.4.4.13.48') or @nullFlavor='NI'] komt te vaak voor [max 1x]. (count(hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.4.13.48') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.48') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.4.13.48') or (@code='4' and @codeSystem='2.16.840.1.113883.2.4.4.13.48') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.4.13.48') or (@code='6' and @codeSystem='2.16.840.1.113883.2.4.4.13.48') or (@code='7' and @codeSystem='2.16.840.1.113883.2.4.4.13.48') or (@code='8' and @codeSystem='2.16.840.1.113883.2.4.4.13.48') or @nullFlavor='NI'])&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-207923-830930-154437-251829-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code/@code='12131-9']]/hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]]/hl7:component[hl7:procedure[hl7:code[(@code='51597003' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:procedure/hl7:inboundRelationship[hl7:observation/hl7:code[@code='163520002']]/hl7:observation[hl7:code[(@code='163520002' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:code"
                 priority="1001"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='163520002' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): de elementwaarde MOET zijn code '163520002' codeSystem '2.16.840.1.113883.6.96'. (@nullFlavor or (@code='163520002' and @codeSystem='2.16.840.1.113883.6.96') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE tmp-r-883369-354540-229039-460426-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.63']/hl7:pertinentInformation3[hl7:organizer[hl7:code/@code='12131-9']]/hl7:organizer[hl7:code[(@code='12131-9' and @codeSystem='2.16.840.1.113883.6.1')]]/hl7:component[hl7:procedure[hl7:code[(@code='51597003' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:procedure/hl7:inboundRelationship[hl7:observation/hl7:code[@code='163520002']]/hl7:observation[hl7:code[(@code='163520002' and @codeSystem='2.16.840.1.113883.6.96')]]/hl7:value[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.4.13.48') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.48') or (@code='3' and @codeSystem='2.16.840.1.113883.2.4.4.13.48') or (@code='4' and @codeSystem='2.16.840.1.113883.2.4.4.13.48') or (@code='5' and @codeSystem='2.16.840.1.113883.2.4.4.13.48') or (@code='6' and @codeSystem='2.16.840.1.113883.2.4.4.13.48') or (@code='7' and @codeSystem='2.16.840.1.113883.2.4.4.13.48') or (@code='8' and @codeSystem='2.16.840.1.113883.2.4.4.13.48') or @nullFlavor='NI']"
                 priority="1000"
                 mode="M6">
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="validCodeOrCodeSystemFound"
                    select="concat(exists(document('include/voc-2.16.840.1.113883.2.4.11.174-2013-03-20T000000.xml')/*/valueSet[conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-2.16.840.1.113883.2.4.11.174-2013-03-20T000000.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>
      <xsl:variable name="explicitExceptions" select="''"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or contains($validCodeOrCodeSystemFound,'true')"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): de waarde van @code MOET worden gekozen uit waardenlijst Stand (2013-03-20T00:00:00). NB: codeSystemVersion MOET exact overeenkomen indien gespecificeerd in de waardenlijst. (@nullFlavor or contains($validCodeOrCodeSystemFound,'true') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|'))"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): de nulwaarde voor @code MOET komen uit de set die is gedefinieerd voor dit attribuut of zijn gekoppeld aan waardenlijst Stand (2013-03-20T00:00:00). (not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 or contains($explicitExceptions, concat('|', $theNullFlavor, '|')) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(../../../@negationInd='true')"/>
         <xsl:otherwise>
            <xsl:message>(VagTouch): Als er géén VT gedaan is, ook geen waarde opnemen voor Stand. (not(../../../@negationInd='true') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/perinatologie/peri20-html-20131112T143226/tmp-2.16.840.1.113883.2.4.6.10.90.900922-2013-07-29T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M6"/>
   <xsl:template match="@*|node()" priority="-2" mode="M6">
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>
</xsl:stylesheet>
